<?php

namespace Modules\Autenticacion\Http\Controllers\Auth;

use Auth;
use App\Http\Controllers\Controller;
use Illuminate\Foundation\Auth\AuthenticatesUsers;
use Illuminate\Http\Request;
use Modules\Usuarios\Entities\Usuario as User;
class LoginController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Login Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles authenticating users for the application and
    | redirecting them to your home screen. The controller uses a trait
    | to conveniently provide its functionality to your applications.
    |
    */

    use AuthenticatesUsers;

    /**
     * Where to redirect users after login.
     *
     * @var string
     */
    protected $redirectTo = 'admin.dashboard';

    /**
     * Show the application's login form.
     *
     * @return \Illuminate\Http\Response
     */
    public function showLoginForm()
    {
        return view('autenticacion::auth.login');
    }



    public function login(Request $request)
    {
        // Validate the form data
        $this->validate($request, [
            'email'   => 'required|email',
            'password' => [
                'required',
                // 'regex:' . config('autenticacion.password_regex'),
                'string',
                'min:8'
            ]
        ]);

        // Attempt to log the user in
        if (Auth::guard('acceso')->attempt([
            'email' => $request->email,
            'password' => $request->password,
            'activo' => 1
        ], $request->remember))
        {
            $usuario = Auth::user();
            if($usuario->hasRole('Candidato')){
                return $this->logout($request); 
            }else if($usuario->hasRole('Empresa')){
                return $this->logout($request);
            }else if($usuario->hasRole('Admin')){
                return redirect()->intended(route('staff.admin.index'));
            }else if($usuario->hasRole('Reclutamiento')){
                return redirect()->intended(route('staff.reclutamiento.index'));
            }else if($usuario->hasRole('Ventas')){
                return redirect()->intended(route('staff.ventas.index'));
            }else if($usuario->hasRole('Base de datos')){
                return redirect()->intended(route('staff.database.index'));
            }
            // if successful, then redirect to their intended location
            return redirect()->intended(route($this->redirectTo));
        }

        // if unsuccessful, then redirect back to the login with the form data
        return redirect()->back()
            ->with('alert_error',__('auth.failed'))
            ->withInput($request->only('email', 'remember'));
    }


    public function loginEmpresa(Request $request)
    {
        // Validate the form data
        $this->validate($request, [
            'email'   => 'required|email',
            'password' => [
                'required',
                // 'regex:' . config('autenticacion.password_regex'),
                'string',
                'min:8'
            ]
        ]);

        // Attempt to log the user in
        if (Auth::guard('acceso')->attempt([
            'email' => $request->email,
            'password' => $request->password,
            'activo' => 1
        ],$request->remember))
        {
            $usuario = Auth::user();
            if($usuario->hasRole('Empresa')){
                return redirect()->intended(route('private.empresas.perfil')); 
            }else{
                return $this->logout($request)->with('alert_error', 'El rol de usuario no es reclutador/empresa');
            }
            // if successful, then redirect to their intended location
            return redirect()->intended(route($this->redirectTo));
        }

        // if unsuccessful, then redirect back to the login with the form data
        return redirect()->back()
            ->with('alert_error',__('auth.failed'))
            ->withInput($request->only('email', 'remember'));
    }

    public function loginCandidato(Request $request)
    {
        // Validate the form data
        $this->validate($request, [
            'email'   => 'required|email',
            'password' => [
                'required',
                // 'regex:' . config('autenticacion.password_regex'),
                'string',
                'min:8'
            ]
        ]);

        // Attempt to log the user in
        if (Auth::guard('acceso')->attempt([
            'email' => $request->email,
            'password' => $request->password,
            'activo' => 1
        ],$request->remember))
        {
            $usuario = Auth::user();

            if($usuario->hasRole('Candidato')){
                $candidato = Auth::user()->candidato;
                $personales = 1;
                $otros = $candidato->otros()->count() == 0? 0:1;
                $experiencia = $candidato->experiencia()->count() == 0? 0:1;
                $referencia = $candidato->referencia()->count() == 0? 0:1;
                $estudios = $candidato->estudios()->count() == 0? 0:1;
                $habilidades = $candidato->habilidades()->count() == 0? 0:1;
                $fotografia = isset($candidato->fotografia)?1:0;
                $cv = isset($candidato->cv)?1:0;
                $total = $personales + $experiencia + $referencia + $estudios + $habilidades + $otros + $fotografia + $cv;
                $porcentaje = intval(($total/8) * 100);

                if($candidato->fotografia == null | $candidato->cv == null){
                    return redirect()->route('private.candidatos.perfil')->with('alert_success','Suba su fotografía y currículum completar su peril al 100%');
                }elseif($candidato->estado_civil == null){
                    return redirect()->route('private.candidatos.personales')->with('alert_success','Actualice esta sección para poder completar su peril al 100%');
                }elseif($otros == 0){
                    return redirect()->route('private.candidatos.otros')->with('alert_success','Actualice esta sección para poder completar su peril al 100%');
                }elseif($referencia == 0){
                    return redirect()->route('private.candidatos.experiencia')->with('alert_success','Actualice esta sección para poder completar su peril al 100%');
                }elseif($experiencia == 0){
                    return redirect()->route('private.candidatos.referencia')->with('alert_success','Actualice esta sección para poder completar su peril al 100%');
                }elseif($estudios == 0){
                    return redirect()->route('private.candidatos.estudios')->with('alert_success','Actualice esta sección para poder completar su peril al 100%');
                }elseif($habilidades == 0){
                    return redirect()->route('private.candidatos.habilidades')->with('alert_success','Actualice esta sección para poder completar su peril al 100%');
                }
                elseif($porcentaje == 100){
                    return redirect()->intended(route('private.candidatos.perfil'));
                }
            }else{
                return $this->logout($request)->with('alert_error', 'El rol de usuario no es candidato');
            }  
            // if successful, then redirect to their intended location
            return redirect()->intended(route($this->redirectTo));
        }

        // if unsuccessful, then redirect back to the login with the form data
        return redirect()->back()
            ->with('alert_error',__('auth.failed'))
            ->withInput($request->only('email', 'remember'));
    }

    public function loginReclutamiento(Request $request)
    {
        // Validate the form data
        $this->validate($request, [
            'email'   => 'required|email',
            'password' => [
                'required',
                // 'regex:' . config('autenticacion.password_regex'),
                'string',
                'min:8'
            ]
        ]);

        // Attempt to log the user in
        if (Auth::guard('acceso')->attempt([
            'email' => $request->email,
            'password' => $request->password,
            'activo' => 1
        ],$request->remember))
        {
            $usuario = Auth::user();
            if($usuario->hasRole('Reclutamiento')){
                return redirect()->intended(route('staff.reclutamiento.index'));
            }else{
                return $this->logout($request);
            }
            // if successful, then redirect to their intended location
            return redirect()->intended(route($this->redirectTo));
        }

        // if unsuccessful, then redirect back to the login with the form data
        return redirect()->back()
            ->with('alert_error',__('auth.failed'))
            ->withInput($request->only('email', 'remember'));
    }


    /**
     * Log the user out of the application.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function logout(Request $request)
    {
        Auth::guard()->logout();

        $request->session()->invalidate();

        return redirect('/');
    }

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest')->except('logout');
    }
}
