<?php

namespace Modules\Candidatos\Entities;

use Illuminate\Database\Eloquent\Model;

class Candidato extends Model
{
    protected $fillable = [
        'nombre', 
        'apellido', 
        'email',
        'usuario_id',
        'cv',
        'fotografia',
        'fecha_nacimiento',
        'lugar_nacimiento',
        'edad',
        'genero',
        'pretension_salarial',
        'nit',
        'telefono_fijo',
        'telefono_celular',
        'profesion',
        'anios_experiencia',
        'area_experiencia',
        'dpi',
        'direccion',
        'pais',
        'departamento',
        'municipio',
        'zona',
        'direccion_otros',
        'igss',
        'tipo_licencia',
        'otro_tipo_licencia',
        'licencia',
        'estado_civil',
        'nacionalidad',
        'datos_conyugue',
        'hijos',
        'edad_hijos',
        'datos_padre',
        'datos_madre',
        'hermanos',
        'info_hermanos',
        'estudia',
        'carrera',
        'establecimineto',
        'horario',
        'estado_pruebas',
        'fecha_pruebas',
        'competencias',
        'edad_conyugue',
        'ocupacion_conyugue',
        'ocupacion_hermanos',
        'ocupacion_padre',
        'ocupacion_madre',
        'descripcion',
        'estado_entrevista',
        'apellido_casada',
        'video',
        'archivo_informe',
        'observaciones_informe',
        'interpretacion_informe',
        'verificacion_informe',
        'boletin_semanal',
        'fecha_baja_boletin',
        'motivo_baja_boletin'
    ];
    protected $dates = [
        'fecha_nacimiento',
        'fecha_baja_boletin'
    ];

    public function getNombreCompletoAttribute()
    {
        return $this->nombre . ' ' . $this->apellido;
    }

    public function usuario()
    {
        return $this->belongsTo(\Modules\Usuarios\Entities\Usuario::class,'usuario_id','id'); 
    }

    public function otros()
    {
        return $this->hasOne(\Modules\Candidatos\Entities\CandidatoOtrosDatos::class,'candidato_id','id')->orderBy('id','desc');
    }

    public function experiencia()
    {
        return $this->hasMany(\Modules\Candidatos\Entities\CandidatoExperiencia::class,'candidato_id','id');
    }

    public function referencia()
    {
        return $this->hasMany(\Modules\Candidatos\Entities\CandidatoReferencia::class,'candidato_id','id');
    }

    public function estudios()
    {
        return $this->hasOne(\Modules\Candidatos\Entities\CandidatoEstudio::class,'candidato_id','id')->orderBy('id','desc');
    }

    public function habilidades()
    {
        return $this->hasOne(\Modules\Candidatos\Entities\CandidatoHabilidades::class,'candidato_id','id')->orderBy('id','desc');
    }

    public function empleos()
    {
        return $this->belongsToMany(\Modules\Empleos\Entities\Empleo::class, 'empleo_candidatos');
    }

    public function pruebas()
    {
        return $this->hasOne(\Modules\Pruebas\Entities\PruebaCandidato::class, 'candidato_id','id');
    }

    public function entrevista()
    {
        return $this->hasOne(\Modules\Candidatos\Entities\CandidatoEntrevista::class, 'candidato_id','id')->orderBy('id','desc');
    }
}
