<?php

namespace Modules\Candidatos\Http\Controllers;

use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Validator;
use Modules\Candidatos\Entities\Candidato;
use Modules\Empleos\Entities\EmpleoCandidato;
use Modules\Candidatos\Http\Requests\CandidatoRegistroStoreRequest;
use Modules\Usuarios\Entities\Usuario;

class CandidatosController extends Controller
{

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */

    public function gracias()
    {
        return view('candidatos::privado.perfil.gracias-registro');
    }
     
    public function store(CandidatoRegistroStoreRequest $request)
    {
        $usuario = Usuario::create($request->except('_token','password_confirmation','id')+['activo' =>1]) ;
        $usuario->assignRole('Candidato');
        session(['public.candidato.created' => true]);
        $usuario->candidato()->create($request->only('nombre','apellido','email','boletin_semanal'));
        return view('candidatos::privado.perfil.gracias-registro')->with('alert_success', 'El usuario ha sido creado.');
    } 

    public function getAjaxCandidatos(Request $request)
    {
        $term = $request->term ?: '';
        $empleo = $request->empleo ?: '';
        $tags = Candidato::selectRaw("candidatos.*");
        if($term != ''){
            $tags = $tags->where('nombre', 'like', $term.'%')->orWhere('apellido', 'like', $term.'%');
        }
        if($empleo != ''){
            $tags = $tags->join('empleo_candidatos','candidatos.id','=','empleo_candidatos.candidato_id')->where('empleo_id',$empleo);
        }
        // return response()->json(['query' => $tags->toSql()]);
        // $tags = $tags->pluck('nombre_completo','id');
        $tags = $tags->get();
        $valid_tags = [];
        foreach ($tags as $id => $tag) {
            $valid_tags[] = ['id' => $tag->id, 'text' => $tag->nombre_completo];
        }
        return response()->json($valid_tags);
    }


    public function getAjaxCandidato(Request $request)
    {
        $candidato = Candidato::whereId($request->id)->first();
        return response()->json($candidato);
    }
    public function getAjaxCandidatoReferenciasLaborales(Request $request)
    {
        $candidato = Candidato::whereId($request->id)->first();
        $html = view('candidatos::reclutamiento.referencias_laborales', compact('candidato'))->render();
        return response($html);
    }
    
    public function getAjaxCandidatoReferenciasLaboralesGuardar(Request $request, Candidato $candidato)
    {
        $validator = Validator::make($request->all(), [
            'candidato_id' => 'required',
            'empresa' => 'required',
            'nombre_puesto_referencia' => 'nullable',
            'puesto_jefe_inmediato_referencia' => 'nullable',
            'tiempo_laboro_referencia' => 'nullable',
            'fortalezas_debilidades_referencia' => 'nullable',
            'actitud_candidato_referencia' => 'nullable',
            'realciones_interpersonales_referencia' => 'nullable',
            'contrataria_de_nuevo_referencia' => 'nullable',
            'confiable_referencia' => 'nullable',
            'funciones_referencia' => 'nullable',
            'desempeno_referencia' => 'nullable',
            'llamada_atenciona_referencia' => 'nullable',
            'observacion_referencia' => 'nullable',
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => false,'mensaje' => $validator->messages()->first()],200);
        }
        $data = $request->except('id','_method','_token');
        $candidato->experiencia()->where('id',$request->id)->update($data);
        return response()->json(['status' => true, 'mensaje' => 'Referencia guardada']);
    }

    public function getAjaxCandidatoReferenciasPersonales(Request $request)
    {
        $candidato = Candidato::whereId($request->id)->first();
        $html = view('candidatos::reclutamiento.referencias_personales', compact('candidato'))->render();
        return response($html);
    }
    
    public function getAjaxCandidatoReferenciasPersonalesGuardar(Request $request, Candidato $candidato)
    {
        $validator = Validator::make($request->all(), [
            'candidato_id' => 'required',
            'nombre' => 'required',
            'relacion' => 'required',

            'donde_trabaja_referencia' => 'nullable',
            'con_quien_vive_referencia' => 'nullable',
            'relaciona_referencia' => 'nullable',
            'vecindario_referencia' => 'nullable',
            'vicio_referencia' => 'nullable',
            'tiempo_conocer_referencia' => 'nullable',
            'comentarios_referencia' => 'nullable',
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => false,'mensaje' => $validator->messages()->first()],200);
        }
        $data = $request->except('id','_method','_token');
        $candidato->referencia()->where('id',$request->id)->update($data);
        return response()->json(['status' => true, 'mensaje' => 'Referencia guardada']);
    }

    public function getAjaxCandidatoInterpretacion(Request $request)
    {
        $candidato = Candidato::whereId($request->id)->first();

        $empleo_candidato = EmpleoCandidato::where('candidato_id', $request->id)->where('empleo_id', $request->empleo_id)->first();

        $html = view('candidatos::reclutamiento.interpretacion_candidato', compact('candidato','empleo_candidato'))->render();
        return response($html);
    }

    public function getAjaxCandidatoInterpretacionGuardar(Request $request, Candidato $candidato)
    {
        $validator = Validator::make($request->all(), [
            'observaciones_informe'   => 'nullable',
            'interpretacion_informe'  => 'nullable',
            'verificacion_informe'    => 'nullable'
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => false,'mensaje' => $validator->messages()->first()],200);
        }
        $data = $request->except('id','_method','_token');
        $candidato->update($data);
        return response()->json(['status' => true, 'mensaje' => 'Datos guardados correctamente.']);
    }

    public function bajaBoletin (Candidato $candidato)
    {

        return view('candidatos::privado.perfil.baja_boletin')->with(compact('candidato'));

    }

    public function boletinUpdate(Request $request, Candidato $candidato)
    {
        $fecha_actual = Carbon::now();

        $data = ['fecha_baja_boletin' => $fecha_actual, 'boletin_semanal' => 0];

        $candidato->update($request->only('motivo_baja_boletin')+$data);

        return redirect()->route('public.home');
    } 
}
