<?php

namespace Modules\Candidatos\Http\Controllers\Privado;

use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use Modules\Candidatos\Entities\Candidato;
use Modules\Candidatos\Entities\CandidatoReferencia;
use Modules\Candidatos\Http\Requests\Privado\CandidatoArchivosRequest;
use Modules\Candidatos\Http\Requests\Privado\CandidatoEstudiosRequest;
use Modules\Candidatos\Http\Requests\Privado\CandidatoExperienciaRequest;
use Modules\Candidatos\Http\Requests\Privado\CandidatoHabilidadesRequest;
use Modules\Candidatos\Http\Requests\Privado\CandidatoOtrosRequest;
use Modules\Candidatos\Http\Requests\Privado\CandidatoPersonalesRequest;
use Modules\Candidatos\Http\Requests\Privado\CandidatoReferenciaRequest;
use Modules\Usuarios\Entities\Usuario;
use Modules\Pruebas\Entities\PreguntaPrueba;
use Modules\Pruebas\Entities\RespuestaPregunta;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;
use Modules\Empleos\Entities\EmpleoCandidato;

class CandidatosController extends Controller
{
    public function index(Request $request)
    {
        if(isset($request->candidato)){
            $candidato = Candidato::whereId($request->candidato)->first();
        }else{
            $candidato = Auth::user()->candidato;
        }

        $otros = $candidato->otros()->count() == 0? 0:1;
        $experiencia = $candidato->experiencia()->count() == 0? 0:1;
        $referencia = $candidato->referencia()->count() == 0? 0:1;
        $estudios = $candidato->estudios()->count() == 0? 0:1;
        $habilidades = $candidato->habilidades()->count() == 0? 0:1;
        $fotografia = $candidato->fotografia?1:0;
        $cv = $candidato->cv?1:0;
        $fecha_nacimiento = $candidato->fecha_nacimiento?1:0;
        $dpi = $candidato->dpi?1:0;
        $igss = ( isset($candidato->igss) && $candidato->igss != null )?1:0; 
        $direccion = $candidato->direccion?1:0;
        $pais = $candidato->pais?1:0;
        $departamento = $candidato->departamento?1:0;
        $municipio = $candidato->municipio?1:0;
        $zona = (isset($candidato->zona) || $candidato->zona != 0)?1:0;

        $total = $otros + $experiencia + $referencia + $estudios + $habilidades + $fotografia + $cv + $fecha_nacimiento + $dpi + $igss + $direccion + $pais + $departamento +
        $municipio + $zona;

        $porcentaje = intval(($total/15) * 100);

        return view('candidatos::privado.perfil.perfil')->with(compact('candidato','porcentaje')); 
    }

    public function pruebas()
    {
        $preguntaspruebaA = PreguntaPrueba::all();
        return view('pruebas::candidatos.a.pregunta')->with(compact('preguntaspruebaA','respuestapreguntaA'));
    }

    public function preguntasA()
    {
        $preguntasA = PreguntaPrueba::all();
        return view('pruebas::candidatos.a.pregunta')->with(compact('preguntasA','preguntasA'));
    }

    public function personales(Request $request)
    {
        if(isset($request->candidato)){
            $candidato = Candidato::whereId($request->candidato)->first();
        }else{
            $candidato = Auth::user()->candidato;
        }
        
        return view('candidatos::privado.perfil.personales')->with(compact('candidato'));
    }
    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function personalesUpdate(CandidatoPersonalesRequest $request, Candidato $candidato)
    {
        $fecha_actual = Carbon::now();

        if (isset($request->password) ) {
            $data   = $request->only('nombre','apellido','email','password');
            $data['password'] = Hash::make($data['password']);
        } else {
            $data   = $request->only('nombre','apellido','email'); 
        }

        if (isset($request->boletin_semanal) && $request->boletin_semanal == 0 ) {

            $data2 = ['fecha_baja_boletin' => $fecha_actual];

        } else {

            $data2 = ['fecha_baja_boletin' => null];

        }

        $candidato->update($request->except('_token','_method','password','password_confirmation')+$data2);
        $candidato->usuario()->update($data);
        return redirect()
            ->route('private.candidatos.otros',['candidato' => $candidato])
            ->with('alert_success', 'Tu perfil ha sido actualizado correctamente.');
    } 

    public function descripcionUpdate(Request $request, Candidato $candidato)
    {
        $data = $request->except('_method','_token');
        $candidato->update($data);
        //dd($candidato);
        return redirect()
            ->route('private.candidatos.perfil', ['candidato' => $candidato])
            ->with('alert_success', 'Tu perfil ha sido actualizado correctamente.');
    }

    public function otros(Request $request)
    {
        if(isset($request->candidato)){
            $candidato = Candidato::whereId($request->candidato)->first();
        }else{
            $candidato = Auth::user()->candidato;
        }

        return view('candidatos::privado.perfil.otros')->with(compact('candidato'));
    }
    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function otrosUpdate(CandidatoOtrosRequest $request, Candidato $candidato)
    {
        $data = $request->except('id','_method','_token');
        $otros_datos = $candidato->otros()->count();
        if($otros_datos == 0){
            $candidato->otros()->create($data);
        }else{
            $candidato->otros()->update($data);
        }
        return redirect()
            ->route('private.candidatos.otros')
            ->with('alert_success', 'Tu perfil ha sido actualizado correctamente.');
    }


    public function experiencia(Request $request)
    {
        if(isset($request->candidato)){
            $candidato = Candidato::whereId($request->candidato)->first();
        }else{
            $candidato = Auth::user()->candidato;
        }

        return view('candidatos::privado.perfil.experiencia')->with(compact('candidato'));
    }
    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function experienciaUpdate(CandidatoExperienciaRequest $request, Candidato $candidato)
    {
        $data = $request->except('id','_method','_token');
        if(!isset($request->id)){
            $candidato->experiencia()->create($data);
        }else{
            $candidato->experiencia()->where('id',$request->id)->update($data);
        }
        return redirect()
            ->route('private.candidatos.experiencia')
            ->with('alert_success', 'Tu perfil ha sido actualizado correctamente.');
    }

    public function referencia(Request $request)
    {
        if(isset($request->candidato)){
            $candidato = Candidato::whereId($request->candidato)->first();
        }else{
            $candidato = Auth::user()->candidato;
        }

        return view('candidatos::privado.perfil.referencia')->with(compact('candidato'));
    }
    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function referenciaUpdate(CandidatoReferenciaRequest $request, Candidato $candidato)
    {
        $data = $request->except('id','_method','_token');
        if(!isset($request->id)){
            $candidato->referencia()->create($data);
        }else{
            $candidato->referencia()->where('id',$request->id)->update($data);
        }
        return redirect()
            ->route('private.candidatos.referencia')
            ->with('alert_success', 'Tu perfil ha sido actualizado correctamente.');
    }
    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function referenciaDestroy(Request $request, CandidatoReferencia $referencia)
    {
        $referencia->delete();
        return redirect()
            ->route('private.candidatos.referencia')
            ->with('alert_success', 'Tu perfil ha sido actualizado correctamente.');
    }
    public function estudios(Request $request)
    {
        if(isset($request->candidato)){
            $candidato = Candidato::whereId($request->candidato)->first();
        }else{
            $candidato = Auth::user()->candidato;
        }

        return view('candidatos::privado.perfil.estudios')->with(compact('candidato'));
    }
    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function estudiosUpdate(CandidatoEstudiosRequest $request, Candidato $candidato)
    {
        $data = $request->except('id','_method','_token');
        //dd($data);
        $estudios_datos = $candidato->estudios()->count();
        if($estudios_datos == 0){
            $candidato->estudios()->create($data);
        }else{
            $candidato->estudios()->update($data);
        }
        return redirect()
            ->route('private.candidatos.estudios')
            ->with('alert_success', 'Tu perfil ha sido actualizado correctamente.');
    }


    public function habilidades(Request $request)
    {
        if(isset($request->candidato)){
            $candidato = Candidato::whereId($request->candidato)->first();
        }else{
            $candidato = Auth::user()->candidato;
        }

        return view('candidatos::privado.perfil.habilidades')->with(compact('candidato'));
    }
    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function habilidadesUpdate(CandidatoHabilidadesRequest $request, Candidato $candidato)
    {
        $data = $request->except('id','_method','_token');
        $habilidades_datos = $candidato->habilidades()->count();
        if($habilidades_datos == 0){
            $candidato->habilidades()->create($data);
        }else{
            $candidato->habilidades()->update($data);
        }
        return redirect()
            ->route('private.candidatos.perfil', ['candidato' => $candidato]) 
            ->with('alert_success', 'Tu perfil ha sido actualizado correctamente.');
    }
    public function fileUpdate(CandidatoArchivosRequest $request, Candidato $candidato) 
    {
        if(isset($request->fotografia)){ 

            $validator = Validator::make($request->all(), [
                'fotografia'         => 'max:2560', 
            ]);
            if ($validator->fails()) {
                return redirect()->back()->with('alert_error', 'La fotografía no puede pesar mas de 2.5MB');
            } 

            $extension = $request->fotografia->extension();
            $filename = sha1(time().time()).".$extension";
            $request->fotografia->move(public_path('storage/uploads/images'),$filename);
            $candidato->update(['fotografia' => $filename]);

            return redirect()
            ->route('private.candidatos.perfil', ['candidato' => $candidato])
            ->with('alert_success', 'Tu perfil ha sido actualizado correctamente.');

        }else if(isset($request->cv)){

            $validator = Validator::make($request->all(), [
                'cv'         => 'max:2560', 
            ]);
            if ($validator->fails()) {
                return redirect()->back()->with('alert_error', 'El archivo no puede pesar mas de 2.5MB');
            }

            $extension = $request->cv->extension();
            $filename = sha1(time().time()).".$extension";
            $request->cv->move(public_path('storage/uploads/docs'),$filename);
            $candidato->update(['cv' => $filename]); 

            return redirect()
            ->route('private.candidatos.perfil', ['candidato' => $candidato])
            ->with('alert_success', 'Tu CV ha sido cargado exitosamente.');

        }else if(isset($request->video)){

            $validator = Validator::make($request->all(), [
                'video'         => 'max:10000', 
            ]);
            if ($validator->fails()) {
                return redirect()->back()->with('alert_error', 'La video no puede pesar mas de 10MB');
            }

            $extension = $request->video->extension(); 
            $filename = sha1(time().time()).".$extension";
            $request->video->move(public_path('storage/uploads/videos'),$filename); 
            $candidato->update(['video' => $filename]);
            //dd($filename);
            return redirect()
            ->route('private.candidatos.perfil', ['candidato' => $candidato])
            ->with('alert_success', 'Tu video ha sido cargado exitosamente.');
        }
        
    } 

    public function retirarmeEmpleo(EmpleoCandidato $empleocandidato)
    { 
        try {

            $empleocandidato->delete();

            return redirect()->back()->with('alert_success','Se ha retirado del empleo existosamente!');

              } catch (\Exception $e)  {
            return redirect()->back()

            ->with('alert_error', 'Registro relacionado, imposible de eliminar');
        }        
    }
}
