<?php

namespace Modules\Candidatos\Http\Controllers\Privado;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Modules\Empleos\Entities\Empleo;
use Modules\Empleos\Http\Requests\EmpleoStoreRequest;
use Yajra\DataTables\DataTables;
use Modules\Candidatos\Entities\Candidato;
use Modules\Candidatos\Entities\CandidatoEstudio;
use Modules\Candidatos\Entities\CandidatoExperiencia;
use Modules\Candidatos\Entities\CandidatoHabilidades;
use Modules\Candidatos\Entities\CandidatoOtrosDatos;
use Modules\Candidatos\Entities\CandidatoReferencia;
use Modules\Candidatos\Entities\CandidatoEntrevista;
use Modules\Pruebas\Entities\PruebaResultado;

class EmpleosController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index()
    {
        $candidato = Auth::user()->candidato;
        $prueba_candidato = $candidato->pruebas()->first();
        if(isset($prueba_candidato)){
            $pruebas_resultado = PruebaResultado::where('prueba_candidato_id',$prueba_candidato->id)->get();
        }else{
            $pruebas_resultado = null;
        }
        return view('candidatos::privado.portafolio.index')->with(compact('candidato','pruebas_resultado'));
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        $empresa = Auth::user()->empresa;
        return view('candidatos::privado.portafolio.empresas.empleos.create')->with(compact('empresa'));
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function store(EmpleoStoreRequest $request)
    {
        $empleo = Empleo::create($request->except('_method','_token','id'));
        return redirect()->route('private.empresas.empleos.edit',$empleo->id)->with('alert_success','Empleo registrado exitosamente');
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show(Empleo $empleo)
    {
        return view('candidatos::privado.portafolio.show')->with(compact('empleo'));
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function edit(Empleo $empleo)
    {
        $empresa = Auth::user()->empresa;
        return view('candidatos::privado.portafolio.empresas.empleos.edit')->with(compact('empresa','empleo'));
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(EmpleoStoreRequest $request, Empleo $empleo)
    {
        $data = $request->except('_method','_token','id','hacer_preguntas');
        if(!isset($request->hacer_preguntas)){
            $data += ['hacer_preguntas' => 0];
        }
        $empleo->update($data);
        return redirect()->route('private.empresas.empleos.edit',$empleo->id)->with('alert_success','Empleo actualizado exitosamente');
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Response
     */
    public function destroy(Empleo $empleo)
    {
        $empleo->delete();
        return redirect()->route('private.empresas.empleos.edit',$empleo->id)->with('alert_success','Empleo actualizado exitosamente');
    }

    public function candidatosPortafolioList(Request $request)
    { 
        $usuario = Auth::user()->candidato;
        $candidato_id = $request->get('candidato',''); 
        
        $empleos = Empleo::select('empleos.*')
                        //->addSelect('dropdowns.value as salario') 
                        ->addSelect(DB::raw('DATE_FORMAT(empleos.created_at, "%d/%m/%Y") as fecha'))
                        ->addSelect(DB::raw('empleo_candidatos.aplica as aplica'))
                        ->addSelect(DB::raw('empleo_candidatos.fecha_cita as fecha_cita_candidato'))
                        ->addSelect(DB::raw('empleo_candidatos.contratado as contratado'))
                        ->addSelect(DB::raw('DATE_FORMAT(empleo_candidatos.created_at, "%d/%m/%Y") as fecha_aplico'))
                        //->addSelect(DB::raw('empleo_candidatos.id as empleo_candidatos_id'))
                        //->leftJoin('dropdowns','empleos.sueldo','=','dropdowns.id')
                        ->join('empleo_candidatos','empleos.id','=','empleo_candidatos.empleo_id');
        if($candidato_id != ''){
            //$candidatos = $candidatos->where('empleo_candidatos.empleo_id',$request->empleo);
            //$candidatos = $candidatos->addSelect('empleo_candidatos.id as empleo_candidatos_id')->where('empleo_candidatos.empleo_id',$request->empleo);
            $empleos = $empleos->addSelect('empleo_candidatos.id as empleo_candidatos_id')->where('empleo_candidatos.candidato_id',$candidato_id); 
        }
        $empleos = $empleos->get();
        return DataTables::of($empleos)
        ->addColumn('action', function($empleo) use($usuario){
            $button = '<a class="btn btn-warning btn-block btn-sm rounded" href="'.route('public.empleos.show',$empleo->id).'" role="button">Ver empleo</a>
                       <a class="btn btn-primary btn-block btn-sm rounded" type="button" data-toggle="modal" data-target="#empleocandidato-destroy-retirarme-'.$empleo->empleo_candidatos_id.'">Retirarme del empleo</a>'; 
            $button .= view('candidatos::privado.portafolio.retirarme-modal',['candidato' => $usuario, 'empleo' => $empleo])->render();           
            return $button;
        })
        ->addColumn('proceso', function($empleo) use($usuario){
            
            $entrevista = $usuario->entrevista()->count() == 0? 0:1;
            $pruebas = $usuario->pruebas()->first(); 
            $a = '';
            if(isset($pruebas)){
                $prueba_resultado = PruebaResultado::where('prueba_candidato_id',$pruebas->id)->get();
                if($prueba_resultado->count() >= 3){
                    $a = 3;
                }
            }else{
                $a = 0;
            }

            if($empleo->aplica == 2){
                $button = '<p class="help-block"><small>Lamentamos informarte que ha sido otro el candidato seleccionado para el puesto, muchos ánimos aún te quedan 
                oportunidades en proceso.</small></p>';
            }else{
                if($empleo->aplica == 1){ 
                    $button = '
                    <ul>
                        <li><span class="indi-color active"></span><span class="indi-text">Aplica</span></li> 
                    </ul>'; 
                } else{
                    $button = '
                    <ul>
                        <li><span class="indi-color inactive"></span><span class="indi-text">Aplica</span></li> 
                    </ul>'; 
                    }     
                if($a == 3){ 
                    $button .= '
                    <ul>
                        <li><span class="indi-color active"></span><span class="indi-text">Pruebas</span></li> 
                    </ul>'; 
                } else{
                    $button .= '
                    <ul>
                        <li><span class="indi-color inactive"></span><span class="indi-text">Pruebas</span></li> 
                    </ul>'; 
                    }
                if($entrevista == 1){ 
                    $button .= '
                    <ul>
                        <li><span class="indi-color active"></span><span class="indi-text">Entrevista</span></li> 
                    </ul>'; 
                } else{
                    $button .= '
                    <ul>
                        <li><span class="indi-color inactive"></span><span class="indi-text">Entrevista</span></li> 
                    </ul>'; 
                    }  
                if(isset($empleo->fecha_cita_candidato)){ 
                    $button .= '
                    <ul>
                        <li><span class="indi-color active"></span><span class="indi-text">Cita</span></li> 
                    </ul>'; 
                } else{
                    $button .= '
                    <ul>
                        <li><span class="indi-color inactive"></span><span class="indi-text">Cita</span></li>  
                    </ul>'; 
                    } 
                if($empleo->contratado == 1){ 
                    $button .= '
                    <ul>
                        <li><span class="indi-color active"></span><span class="indi-text">Contratado</span></li> 
                    </ul>'; 
                }else{
                    $button .= '
                    <ul>
                        <li><span class="indi-color inactive"></span><span class="indi-text">Contratado</span></li>  
                    </ul>'; 
                    }   
            }
   
            return $button;
        })
        ->addColumn('sueldo', function($empleo) {
            $sueldo = number_format($empleo->sueldo,2);
            $button = "<span>Q$sueldo</span><span></span>"; 
            return $button;
        })
        ->rawColumns(['action','proceso','sueldo'])
        ->make(true);
    }
}
