<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::prefix('candidatos')->group(function() {  
    Route::post('/registrar',              'CandidatosController@store')->name('public.candidatos.registrar');
    Route::post('/gracias',                'CandidatosController@gracias')->name('public.candidatos.gracias'); 
    Route::get('/verificar',               'CandidatosController@verificar')->name('public.candidatos.verificar');
    Route::get('/baja/{candidato}',        'CandidatosController@bajaBoletin')->name('public.baja.boletin');
    Route::patch('/update/{candidato}',    'CandidatosController@boletinUpdate')->name('public.update.boletin');

    Route::middleware(['auth:acceso','role:Candidato|Reclutamiento|Base de datos'])->group(function()
    {   
        Route::get('perfil',                                    'Privado\CandidatosController@index')->name('private.candidatos.perfil'); 
        Route::patch('personales/update/{candidato}',           'Privado\CandidatosController@personalesUpdate')->name('private.candidatos.personales.update');
        Route::get('personales',                                'Privado\CandidatosController@personales')->name('private.candidatos.personales');
        Route::patch('otros/update/{candidato}',                'Privado\CandidatosController@otrosUpdate')->name('private.candidatos.otros.update');
        Route::get('otros',                                     'Privado\CandidatosController@otros')->name('private.candidatos.otros');
        Route::patch('experiencia/update/{candidato}',          'Privado\CandidatosController@experienciaUpdate')->name('private.candidatos.experiencia.update');
        Route::get('experiencia',                               'Privado\CandidatosController@experiencia')->name('private.candidatos.experiencia');
        Route::patch('referencia/update/{candidato}',           'Privado\CandidatosController@referenciaUpdate')->name('private.candidatos.referencia.update');
        Route::delete('referencia/destroy/{referencia}',        'Privado\CandidatosController@referenciaDestroy')->name('private.candidatos.referencia.destroy');
        Route::get('referencia',                                'Privado\CandidatosController@referencia')->name('private.candidatos.referencia');
        Route::patch('estudios/update/{candidato}',             'Privado\CandidatosController@estudiosUpdate')->name('private.candidatos.estudios.update');
        Route::get('estudios',                                  'Privado\CandidatosController@estudios')->name('private.candidatos.estudios');
        Route::patch('habilidades/update/{candidato}',          'Privado\CandidatosController@habilidadesUpdate')->name('private.candidatos.habilidades.update');
        Route::get('habilidades',                               'Privado\CandidatosController@habilidades')->name('private.candidatos.habilidades');
        Route::patch('file/update/{candidato}',                 'Privado\CandidatosController@fileUpdate')->name('private.candidatos.file.update');
        Route::patch('descripcion/{candidato}',                 'Privado\CandidatosController@descripcionUpdate')->name('private.candidatos.descripcion.update'); 
        Route::delete('retirame/{empleocandidato}',             'Privado\CandidatosController@retirarmeEmpleo')->name('private.candidatos.retirarme');

        Route::get('portafolio',                                'Privado\EmpleosController@index')->name('private.candidatos.portafolio'); 
        Route::get('portafolio/empleo/{empleo}',                'Privado\EmpleosController@show')->name('private.candidatos.portafolio.show');
        Route::get('portafolio/listar',                         'Privado\EmpleosController@candidatosPortafolioList')->name('private.candidatos.portafolio.list');
        //Route::delete('/empleo/{empleocandidato}',            'Privado\EmpleosController@destroyEmpleocandidato')->name('private.empleo_candidato.destroy');
    });
});


Route::prefix('admin')->group(function() {
    Route::middleware(['auth:acceso','role:Super Admin|Admin'])->group(function()
    {
        Route::get('candidatos/listar',                    'Admin\CandidatosController@candidatosList')->name('dashboard.candidatos.list');

        Route::get('candidatos',                  'Admin\CandidatosController@index')->name('dashboard.candidatos.index');
        Route::group(['middleware' => ['permission:Crear Usuarios']], function () {
            Route::post('candidatos',                 'Admin\CandidatosController@store') ->name('dashboard.candidatos.store');
            Route::get('candidatos/crear',            'Admin\CandidatosController@create')->name('dashboard.candidatos.create');
        });
        Route::get('candidatos/{candidato}',        'Admin\CandidatosController@show')->name('dashboard.candidatos.show');
        Route::group(['middleware' => ['permission:Editar Usuarios']], function () {
            Route::get('candidatos/{candidato}/editar', 'Admin\CandidatosController@edit')->name('dashboard.candidatos.edit');
            Route::patch('candidatos/{candidato}',      'Admin\CandidatosController@update')->name('dashboard.candidatos.update');
        });
        Route::group(['middleware' => ['permission:Eliminar Usuarios']], function () {
            Route::delete('candidatos/{candidato}',     'Admin\CandidatosController@destroy')->name('dashboard.candidatos.destroy');
        });
    });
});
