<?php

namespace Modules\Configuracion\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Modules\Configuracion\Entities\Politica;
use Yajra\DataTables\DataTables;
use Illuminate\Support\Facades\Validator;
use Modules\Configuracion\Http\Requests\PoliticasRequest;

class ConfiguracionController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index()
    {
        return view('configuracion::politicas.index'); 
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        return view('configuracion::politicas.create');
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function store(PoliticasRequest $request)
    {

        $filename = '';
        $extension = $request->archivo->extension();
        $filename = sha1(time().time()).".$extension";
        $request->archivo->move(public_path('storage/uploads/politicas'),$filename); 

        Politica::create($request->except('_token','archivo')+['archivo' =>$filename]);
        return redirect()
            ->back()
            ->with('alert_success', 'La política ha sido creada.'); 
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show(Politica $politica)
    {
        return view('configuracion::politicas.show')->with(compact('politica'));
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function edit(Politica $politica)
    {
        return view('configuracion::politicas.edit')->with(compact('politica'));
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(PoliticasRequest $request, Politica $politica)
    {
        $filename = '';
        $extension = $request->archivo->extension();
        $filename = sha1(time().time()).".$extension";
        $request->archivo->move(public_path('storage/uploads/politicas'),$filename); 

        $politica->update($request->except('_token','_method','archivo')+['archivo' =>$filename]);
        return redirect()
            ->back()
            ->with('alert_success', 'La política ha sido editada.');
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Response
     */
    public function destroy(Politica $politica)
    {
        $politica->delete();
        return redirect()
            ->back()
            ->with('alert_success', 'La política ha sido eliminada.');
    }

    public function politicasList(Request $request){

        $politicas = Politica::select('politicas.*');
        $politicas = $politicas->get();
        return DataTables::of($politicas)
        ->addColumn('action', function($politica) {
            $button = '<a class="btn btn-primary btn-sm" target="_blank" href="'.asset('storage/uploads/politicas/'.$politica->archivo).'"><i class="fas fa-eye"></i></a>'; 
            $button .= '<a class="btn btn-info btn-sm"  href=\'javascript:editarPolitica('.$politica->id.',"'.$politica->descripcion.'")\'><i class="fas fa-pencil-alt"></i></a>';
            //$button .= '<a class="btn btn-danger btn-sm" href=\'javascript:borrarPolitica('.$politica->id.',"'.$politica->descripcion.'")\'  ><i class="fas fa-trash"></i></a>';
            return $button; 
        })
        ->rawColumns(['action'])
        ->make(true);
    }
}
