<?php

namespace Modules\Empleos\Entities;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Empleo extends Model
{
    use SoftDeletes;

    protected $fillable = [
        'empresa_id',
        'empresa',
        'plaza',
        'imagen',
        'fecha_publicacion',
        'descripcion',
        'profesion',
        'estudios_carrera',
        'edad_rango',
        'genero',
        'experiencia',
        'idioma',
        'porcentaje_idioma',
        'conocimientos_especiales',
        'software',
        'licencia',
        'vehiculo',
        'viajar',
        'competencias',
        'sueldo',
        'adicionales',
        'tipo_contrato',
        'jornada',
        'incentivos_adicionales',
        'pais',
        'departamento',
        'municipio',
        'zona',
        'preguntas_obligatorias',
        'hacer_preguntas',
        'pregunta_1',
        'pregunta_2',
        'pregunta_3',
        'pregunta_4',
        'pregunta_5',
        'pregunta_6',
        'empleo_confidencial',
        'logo_visible',
        'duracion',
        'promocionar',
        'estado_civil',
        'activo',
        'usuario_id',
        'fecha_asignacion',
        'categorias'
    ];

    protected $dates = [
        'fecha_publicacion',
        'fecha_asignacion',
        'deleted_at'
    ];

    public function empresa()
    {
        return $this->belongsTo(\Modules\Empresas\Entities\Empresa::class,'empresa_id','id');
    }

    public function duracion_dropdown()
    {
        return $this->hasOne(\Modules\Configuracion\Entities\Dropdown::class,'id','duracion')->first();
    }

    public function candidatos()
    {
        return $this->belongsToMany(\Modules\Candidatos\Entities\Candidato::class,'empleo_candidatos');
    }

    public function empleoCandidato()
    {
        return $this->hasMany(\Modules\Empleos\Entities\EmpleoCandidato::class,'empleo_id','id');
    }

    public function usuario()
    {
        return $this->belongsTo(\Modules\Usuarios\Entities\Usuario::class,'usuario_id','id'); 
    }

    public function terna()
    {
        return $this->hasMany(\Modules\Staff\Entities\TernaCandidatos::class,'empleo_id','id');
    }
}
