<?php

namespace Modules\Empleos\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;
use Modules\Candidatos\Entities\Candidato;
use Modules\Empleos\Http\Requests\EmpleoStoreRequest;
use Modules\Empleos\Entities\Empleo;
use Modules\Empresas\Entities\Empresa;
use Modules\Empleos\Entities\EmpleoCandidato;
use Illuminate\Support\Facades\Mail;
use Barryvdh\DomPDF\Facade as PDF;
use Modules\Candidatos\Emails\AplicarEmail;
use Modules\Candidatos\Emails\AplicarReclutamientoEmail;
use Modules\Candidatos\Emails\EntrevistaEmail;
use Modules\Candidatos\Emails\AplicarEmpresaEmail;
use Modules\Candidatos\Emails\ContratadoEmail;
use Carbon\Carbon;

class EmpleosController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index(Request $request)
    {

        if($request->get('buscar') != null && $request->get('categoria') != null){

            $buscar = $request->get('buscar');
            $categoria = $request->get('categoria');
            $empleos = Empleo::where('activo',1)->where(function($q) use ($buscar) {
                $q->where('plaza', 'like', "%$buscar%");
                $q->orWhere('descripcion', 'like', "%$buscar%");
                $q->orWhere('empresa', 'like', "%$buscar%");
            })->where('categorias', 'LIKE', '%'.$categoria.'%')->orderBy('created_at', 'desc')->paginate(10);
            

        }elseif($request->get('buscar') != null && $request->get('categoria') == ''){

            $buscar = $request->get('buscar');
            $empleos = Empleo::where('activo',1)->where(function($q) use ($buscar) {
                $q->where('plaza', 'like', "%$buscar%");
                $q->orWhere('descripcion', 'like', "%$buscar%");
                $q->orWhere('empresa', 'like', "%$buscar%");
            })->orderBy('created_at', 'desc')->paginate(10);
            

        }elseif($request->get('categoria') != null && $request->get('buscar') == ''){

            $categoria = $request->get('categoria');
            $empleos = Empleo::where('activo',1)->where('categorias', 'LIKE', '%'.$categoria.'%')->orderBy('created_at', 'desc')->paginate(10);
            

        }else{

            $empleos = Empleo::where('activo',1)->orderBy('created_at', 'desc')->paginate(10);

        }

        foreach(getDropdown('Categorías Empleos') as $key => $categoria){

            $empleos2[] = Empleo::where('activo',1)->where('categorias', 'LIKE', '%'.$key.'%')->count();

        }

        return view('empleos::empleos.index')->with(compact('empleos', 'empleos2'));
        //Por medio de whatsapp Mayra solicita el dia 10/06/2021 que los empleos NO se muestre por fecha de
        //publicacion sino por fecha de "vencimiento". Ya no que existe una fecha de vencimiento se modifico para
        //que los muestre por fecha de creacion.
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        return view('empleos::empleos.create');
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function store(EmpleoStoreRequest $request)
    {
        Empleo::create($request->except('_method','_token','id'));
        return redirect('/')->with('alert_success','Se ha enviado tu propuesta de empleo exitosamente!');
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function apply(Request $request)
    {
        $fecha_actual = Carbon::now();

        $validator = Validator::make($request->all(), [ 
            'empleo_id'         => 'required',
        ]);
        if ($validator->fails()) {
            return redirect()->back()->with('alert_error', 'No se pudo aplicar correctamente a este trabajo, intente mas tarde.');
        } 

        $candidato = Auth::user()->candidato;
        $otros = $candidato->otros()->count() == 0? 0:1;
        $experiencia = $candidato->experiencia()->count() == 0? 0:1;
        $referencia = $candidato->referencia()->count() == 0? 0:1;
        $estudios = $candidato->estudios()->count() == 0? 0:1;
        $habilidades = $candidato->habilidades()->count() == 0? 0:1;
        $fotografia = $candidato->fotografia?1:0;
        $cv = $candidato->cv?1:0;
        $fecha_nacimiento = $candidato->fecha_nacimiento?1:0;
        $dpi = $candidato->dpi?1:0;
        $igss = ( isset($candidato->igss) && $candidato->igss != null )?1:0;
        $direccion = $candidato->direccion?1:0;
        $pais = $candidato->pais?1:0;
        $departamento = $candidato->departamento?1:0;
        $municipio = $candidato->municipio?1:0;
        $zona = (isset($candidato->zona) || $candidato->zona != 0)?1:0;

        $total = $otros + $experiencia + $referencia + $estudios + $habilidades + $fotografia + $cv + $fecha_nacimiento + $dpi + $igss + $direccion + $pais + $departamento +
        $municipio + $zona;

        $porcentaje = intval(($total/15) * 100);

        if( $candidato->empleos()->where('empleo_id',$request->empleo_id)->count() == 0 ){
            if (($candidato->fotografia != null) or ($candidato->fotografia != "") ){
                if (($candidato->cv != null) or ($candidato->cv != "") ){
                    if ($porcentaje == 100) {     
                    $candidato->empleos()->attach($request->only('empleo_id'));  
                    $empleo_candidato = EmpleoCandidato::where('candidato_id',$candidato->id)->where('empleo_id',$request->empleo_id); 
                    $empleo_candidato->update(['created_at' => $fecha_actual]);
                    if($request->respuesta_1){
                        $empleo_candidato->update(['respuesta_1' => $request->respuesta_1]);
                    }
                    if($request->respuesta_2){
                        $empleo_candidato->update(['respuesta_2' => $request->respuesta_2]);
                    }
                    if($request->respuesta_3){
                        $empleo_candidato->update(['respuesta_3' => $request->respuesta_3]);
                    }
                    if($request->respuesta_4){
                        $empleo_candidato->update(['respuesta_4' => $request->respuesta_4]);
                    }
                    if($request->respuesta_5){
                        $empleo_candidato->update(['respuesta_5' => $request->respuesta_5]);
                    }
                    if($request->respuesta_6){
                        $empleo_candidato->update(['respuesta_6' => $request->respuesta_6]);
                    }
                    } else {
                        return redirect()->route('public.empleos.show',$request->empleo_id)->with('alert_error','Su perfil debe estar al 100% para poder aplicar a un empleo.');
                    }
                } else {
                    return redirect()->route('public.empleos.show',$request->empleo_id)->with('alert_error','Para aplicar a un empleo es necesario que suba un curriculum a su perfil.');
                } 
            } else {
                return redirect()->route('public.empleos.show',$request->empleo_id)->with('alert_error','Para aplicar a un empleo es necesario que suba un fotografía a su perfil.'); 
            } 
        }    

        $empleo = Empleo::where('id',$request->empleo_id);
        $empleo = $empleo->first();

        $empresa = Empresa::where('id',$empleo->empresa_id);
        $empresa = $empresa->first();

        $empleo_candidato = EmpleoCandidato::where('candidato_id',$candidato->id)->where('empleo_id',$request->empleo_id)->first();

        Mail::to($candidato->email)->send(new AplicarEmail($candidato, $empleo));

        if(isset($empleo->empresa_id)){

            Mail::to($empresa->email)->send(new AplicarEmpresaEmail($candidato, $empleo, $empresa, $empleo_candidato)); 
        }

        return redirect()->route('public.empleos.show',$request->empleo_id)->with('alert_success','Se ha enviado tu propuesta de empleo exitosamente!');
    }

    public function aplicar(Request $request)
    {
        $fecha_actual = Carbon::now();

        $validator = Validator::make($request->all(), [ 
            'empleo_id'         => 'required',
        ]);
        if ($validator->fails()) {
            return redirect()->back()->with('alert_error', 'No se pudo aplicar correctamente a esta plaza, intente mas tarde.');
        } 

        $candidato = Candidato::whereId($request->candidato_id)->first();
        $otros = $candidato->otros()->count() == 0? 0:1;
        $experiencia = $candidato->experiencia()->count() == 0? 0:1;
        $referencia = $candidato->referencia()->count() == 0? 0:1;
        $estudios = $candidato->estudios()->count() == 0? 0:1;
        $habilidades = $candidato->habilidades()->count() == 0? 0:1;
        $fotografia = $candidato->fotografia?1:0;
        $cv = $candidato->cv?1:0;
        $fecha_nacimiento = $candidato->fecha_nacimiento?1:0;
        $dpi = $candidato->dpi?1:0;
        $igss = ( isset($candidato->igss) && $candidato->igss != null )?1:0;
        $direccion = $candidato->direccion?1:0;
        $pais = $candidato->pais?1:0;
        $departamento = $candidato->departamento?1:0;
        $municipio = $candidato->municipio?1:0;
        $zona = (isset($candidato->zona) || $candidato->zona != 0)?1:0;

        $total = $otros + $experiencia + $referencia + $estudios + $habilidades + $fotografia + $cv + $fecha_nacimiento + $dpi + $igss + $direccion + $pais + $departamento +
        $municipio + $zona;

        $porcentaje = intval(($total/15) * 100);

        if( $candidato->empleos()->where('empleo_id',$request->empleo_id)->count() == 0 ){
            if (($candidato->fotografia != null) or ($candidato->fotografia != "") ){
                if (($candidato->cv != null) or ($candidato->cv != "") ){
                    if ($porcentaje == 100) {     
                    $candidato->empleos()->attach($request->only('empleo_id'));  
                    $empleo_candidato = EmpleoCandidato::where('candidato_id',$candidato->id)->where('empleo_id',$request->empleo_id); 
                    $empleo_candidato->update(['created_at' => $fecha_actual]);
                    } else {
                        return redirect()->route('public.empleos.show',$request->empleo_id)->with('alert_error','Su perfil debe estar al 100% para poder aplicar a un empleo.');
                    }
                } else {
                    return redirect()->route('public.empleos.show',$request->empleo_id)->with('alert_error','Para aplicar a un empleo es necesario que suba un curriculum a su perfil.');
                } 
            } else {
                return redirect()->route('public.empleos.show',$request->empleo_id)->with('alert_error','Para aplicar a un empleo es necesario que suba un fotografía a su perfil.'); 
            } 
        }    

        $empleo = Empleo::where('id',$request->empleo_id);
        $empleo = $empleo->first();

        $empresa = Empresa::where('id',$empleo->empresa_id);
        $empresa = $empresa->first();

        $empleo_candidato = EmpleoCandidato::where('candidato_id',$candidato->id)->where('empleo_id',$request->empleo_id)->first();

        Mail::to($candidato->email)->send(new AplicarReclutamientoEmail($candidato, $empleo));

        if(isset($empleo->empresa_id)){

            Mail::to($empresa->email)->send(new AplicarEmpresaEmail($candidato, $empleo, $empresa, $empleo_candidato)); 
        }

        return redirect()->back()->with('alert_success', '¡Exelente! Ya se le ha enviado al candidato el correo indicando que aplica a otro proceso.');
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show(Empleo $empleo)
    {
        return view('empleos::empleos.show')->with(compact('empleo'));
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
        return view('empleos::empleos.edit');
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Response
     */
    public function destroy(Request $request, EmpleoCandidato $empleocandidato)
    {
        //dd($empleocandidato);
        $empleocandidato->delete(); 
        return redirect()->route('private.candidatos.portafolio')->with('alert_success', 'Te has retirado del empleo exitosamente.');
    }

    public function empleoDestroy(Empleo $empleo)
    {
        try {
            $empleo->delete();
            return redirect()->back()
            ->with('alert_success', 'La plaza ha sido eliminada.');
            } catch (\Exception $e)  {
            return redirect()->back()
            ->with('alert_error', 'Registro relacionado, imposible de eliminar');
        }
    }
    
    public function getAjaxEmpleos(Request $request)
    {
        $term = $request->term ?: '';
        $empresa = $request->empresa ?: '';
        if($empresa == ''){
            $tags = Empleo::where('plaza', 'like', $term.'%')->whereNull('empresa_id')->where('activo',1)->pluck('plaza', 'id');
        }else{
            $tags = Empleo::where('plaza', 'like', $term.'%')->where('empresa_id',$empresa)->where('activo',1)->pluck('plaza', 'id');
        }

        $valid_tags = [];
        foreach ($tags as $id => $tag) {
            $valid_tags[] = ['id' => $id, 'text' => $tag];
        }
        return response()->json($valid_tags);
    }

    public function getAjaxEmpleosInterpretacion(Request $request)
    {
        $empleo_candidato = EmpleoCandidato::where('candidato_id',$request->candidato_id)->where('empleo_id',$request->empleo_id)->orderBy('id','desc')->first();

        $html = view('empleos::reclutamiento.interpretacion', compact('empleo_candidato'))->render();
        return response($html);
    }
    public function getAjaxEmpleosCita(Request $request)
    {
        $empleo_candidato = EmpleoCandidato::where('candidato_id',$request->candidato_id)->where('empleo_id',$request->empleo_id)->orderBy('id','desc')->first();

        $html = view('empleos::reclutamiento.cita', compact('empleo_candidato'))->render();
        return response($html);
    }
    public function getAjaxEmpleosContratacion(Request $request)
    {
        $empleo_candidato = EmpleoCandidato::where('candidato_id',$request->candidato_id)->where('empleo_id',$request->empleo_id)->orderBy('id','desc')->first();

        if(isset($empleo_candidato->fecha_contratacion)){ 
            $fecha_garantia = $empleo_candidato->fecha_contratacion->addDays($empleo_candidato->tipo_garantia)->format('d-m-Y');
        }else{
            $fecha_garantia = '';
        }

        if(isset($empleo_candidato->fecha_contratacion)){ 
            $fecha_contratacion = $empleo_candidato->fecha_contratacion->format('d-m-Y');
        }else {
            $fecha_contratacion = '';
        }

        $html = view('empleos::reclutamiento.contratacion', compact('empleo_candidato'))->render();
        return response()->json(['html' => $html, 'empleo_candidato' => $empleo_candidato, 'fecha_contratacion' => $fecha_contratacion, 'fecha_garantia' => $fecha_garantia]);
        //return response($html)->with(compact ('empleo_candidato')); 
    }
    public function getAjaxEmpleosGarantia(Request $request)
    {
        $empleo_candidato = EmpleoCandidato::where('candidato_id',$request->candidato_id)->where('empleo_id',$request->empleo_id)->orderBy('id','desc')->first();

        $html = view('empleos::reclutamiento.garantia', compact('empleo_candidato'))->render();
        return response($html);
    }

    public function setAjaxEmpleoCandidato(Request $request, EmpleoCandidato $empleo_candidato)
    {
        $validator = Validator::make($request->all(), [
            'candidato_id' => 'required',
            'empleo_id' => 'required',
            'motivo_garantia' => 'nullable|max:150',
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => false,'mensaje' => $validator->messages()->first()],200);
        }
        $data = $request->except('id','_method','_token');
        $empleo_candidato->update($data);

        $empleo = Empleo::where('id',$empleo_candidato->empleo_id);
        $empleo = $empleo->first();

        $candidato = Candidato::where('id',$empleo_candidato->candidato_id);
        $candidato = $candidato->first();

        $empresa = Empresa::where('usuario_id',$empleo->empresa_id);
        $empresa = $empresa->first();

        Mail::to($candidato->email)->send(new EntrevistaEmail($candidato, $empleo_candidato, $empresa));    


        return response()->json(['status' => true, 'mensaje' => 'Se ha programado correctamente la cita.']);
    }

    public function updateProgramarCita(Request $request, EmpleoCandidato $empleo_candidato)
    {
        $validator = Validator::make($request->all(), [
            'candidato_id' => 'required',
            'empleo_id'    => 'required',
            'fecha_cita'   => 'required|date|after_or_equal:'.date('d-m-Y')
        ]);

        //if ($validator->fails()) { 
        //    return response()->json(['status' => false,'mensaje' => $validator->messages()->first()],200);
        //}

        if ($validator->fails()) {
            return redirect()->back()->with('alert_error', $validator->messages()->first())->withInput();
        }

        $data = $request->except('id','_method','_token');
        $empleo_candidato->update($data);

        $empleo = Empleo::where('id',$empleo_candidato->empleo_id);
        $empleo = $empleo->first();

        $candidato = Candidato::where('id',$empleo_candidato->candidato_id);
        $candidato = $candidato->first();

        $empresa = Empresa::where('usuario_id',$empleo->empresa_id);
        $empresa = $empresa->first();
        
        $correos = array_diff($request->correo_cita, array($candidato->email));

        Mail::to($candidato->email)->cc($correos)->send(new EntrevistaEmail($candidato, $empleo_candidato, $empresa));    

        return redirect()->back()->with('alert_success', 'Se ha notificado al candidato exitosamente.');    
    }

    public function contratacion(Request $request, EmpleoCandidato $empleo_candidato)
    {
        $validator = Validator::make($request->all(), [
            'candidato_id' => 'required',
            'empleo_id' => 'required'
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => false,'mensaje' => $validator->messages()->first()],200);
        }

        $data = $request->except('id','_method','_token');

        $empleo_candidato->update($data + ['contratado' => 1]); 

        $candidato = Candidato::where('id',$empleo_candidato->candidato_id);
        $candidato = $candidato->first();

        $empleo = Empleo::where('id',$empleo_candidato->empleo_id);
        $empleo = $empleo->first();

        if($request->notificacion_contratado == 1){

            Mail::to($candidato->email)->send(new ContratadoEmail($candidato, $empleo));

        }else{

            $empleo_candidato->update(['notificacion_contratado' => 0]);

        }

        return redirect()->back()->with('alert_success','Se ha guardado la información correctamente');
    }
}
