<?php

namespace Modules\Empleos\Http\Controllers\Privado;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Modules\Empleos\Entities\Empleo;
use Modules\Empleos\Entities\EmpleoCandidato;
use Modules\Usuarios\Entities\Usuario;
use Modules\Candidatos\Entities\Candidato;
use Modules\Empleos\Http\Requests\EmpleoStoreRequest;
use Yajra\DataTables\DataTables;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;
use Carbon\Carbon;
use Modules\Configuracion\Entities\Dropdown;

class EmpleosController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index()
    {
        return view('empleos::index');
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        $empresa = Auth::user()->empresa;
        $competencias = Dropdown::where('parent_id',414)->get();
        $reclutadores = Usuario::selectRaw("concat(usuarios.nombre, ' ', usuarios.apellido) as nombre")
        ->addSelect('usuarios.id as id')
        ->join('model_has_roles','usuarios.id','=','model_has_roles.model_id')
        ->whereIn('model_has_roles.role_id', [4])->where('activo',1)->get();

        return view('empleos::empresas.empleos.create')->with(compact('empresa','competencias','reclutadores'));
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function store(EmpleoStoreRequest $request) 
    {  

        if(isset($request->imagen)){ 
            
            $validator = Validator::make($request->all(), [
                'imagen'         => 'max:2560',
                ]);
                if ($validator->fails()) {
                    return redirect()->back()->with('alert_error', 'La imagen no puede pesar mas de 2.5MB');
                }  
                
                //dd($request->imagen);
                $extension = $request->imagen->extension();
                $filename = sha1(time().time()).".$extension";
                $request->imagen->move(public_path('storage/uploads/images'),$filename);
                $imagen = ['imagen' => $filename];

                $competencias = $request->competencias;
                $competencias = implode(', ', $competencias);

                $categorias = $request->categorias;
                $categorias = implode(', ', $categorias);
                
                $empleo = Empleo::create($request->except('_method','_token','id','imagen','competencias','categorias',)+$imagen+['competencias' => $competencias, 'categorias' => $categorias]); 
                
            }elseif($request->imagen == null && Auth::user()->empresa){
                $empresa = Auth::user()->empresa;
                $imagen = ['imagen' => $empresa->logotipo];
                
                $competencias = $request->competencias;
                $competencias = implode(',',$competencias);

                $categorias = $request->categorias;
                $categorias = implode(', ', $categorias);
                
                $empleo = Empleo::create($request->except('_method','_token','id','imagen','competencias','categorias')+$imagen+['competencias' => $competencias, 'categorias' => $categorias]); 

        }else{

            $competencias = $request->competencias;
            $competencias = implode(', ', $competencias);

            $categorias = $request->categorias;
            $categorias = implode(', ', $categorias);

            $empleo = Empleo::create($request->except('_method','_token','id','competencias','categorias')+['competencias' => $competencias, 'categorias' => $categorias]); 
        }

        if(Auth::user()->hasRole('Admin')){
            return redirect()->route('staff.admin.index',$empleo->id)->with('alert_success','Empleo registrado exitosamente');
        }elseif(Auth::user()->hasRole('Reclutamiento')){
            return redirect()->route('staff.reclutamiento.index',$empleo->id)->with('alert_success','Empleo actualizado exitosamente');
        }
        return redirect()->route('private.empresas.perfil',$empleo->id)->with('alert_success','Empleo registrado exitosamente');
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show(Empleo $empleo)
    {
        return view('empleos::show')->with(compact('empleo'));
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function edit(Empleo $empleo)
    {
        $empresa = Auth::user()->empresa;
        $competencias = Dropdown::where('parent_id',414)->get();
        $competencias_seleccionadas = Empleo::where('id',$empleo->id)->get()->pluck('competencias')->toArray();
        $competencias_seleccionadas = implode(',', $competencias_seleccionadas);

        return view('empleos::empresas.empleos.edit')->with(compact('empresa','empleo','competencias','competencias_seleccionadas'));
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(EmpleoStoreRequest $request, Empleo $empleo)
    {
        $data = $request->except('_method','_token','id','hacer_preguntas','imagen','activo','competencias');
        if(!isset($request->hacer_preguntas)){
            $data += ['hacer_preguntas' => 0];
        }else{
            $data += ['hacer_preguntas' => 1];
        }

        if(Auth::user()->hasRole('Admin')){
            $data += ['activo' => 1];
        }

        if(isset($request->imagen)){ 

            $validator = Validator::make($request->all(), [
                'imagen'         => 'max:2560',
            ]);
            if ($validator->fails()) {
                return redirect()->back()->with('alert_error', 'La imagen no puede pesar mas de 2.5MB');
            }  

            //dd($request->imagen);
            $extension = $request->imagen->extension();
            $filename = sha1(time().time()).".$extension";
            $request->imagen->move(public_path('storage/uploads/images'),$filename);
            $data += ['imagen' => $filename];

        }

        $competencias = $request->competencias;
        $competencias = implode(',', $competencias);
        $data += ['competencias' => $competencias];
          
        $empleo->update($data);

        if(Auth::user()->hasRole('Admin')){
            return redirect()->route('staff.admin.index',$empleo->id)->with('alert_success','Empleo registrado exitosamente');
        }elseif(Auth::user()->hasRole('Reclutamiento')){
            return redirect()->route('staff.reclutamiento.index',$empleo->id)->with('alert_success','Empleo actualizado exitosamente');
        }
        return redirect()->route('private.empresas.perfil',$empleo->id)->with('alert_success','Empleo actualizado exitosamente');
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Response
     */
    public function destroy(Empleo $empleo)
    {
        $empleo->delete();
        return redirect()->route('private.empresas.empleos.edit',$empleo->id)->with('alert_success','Empleo eliminado exitosamente');
    }

    public function empleosList(Request $request)
    {
        $usuario = Auth::user(); 
        
        $empresa_id = $request->get('empresa_id','');
        
        $empleos = Empleo::select('empleos.*')
        ->addSelect(DB::raw('DATE_FORMAT(created_at, "%d/%m/%Y") as fecha'));

        if($empresa_id != ''){
            $empleos = $empleos->where('empresa_id',$empresa_id); 
        }
        
        $empleos = $empleos->get();    

        return DataTables::of($empleos)
        ->addColumn('action', function($empleo){
            $button = ' <div class="row no-gutters py-1">
                            <div class="col-12"><a class="btn btn-warning btn-block btn-sm border rounded" href="'.route('private.empresas.empleos.edit',$empleo->id).'" role="button">Editar Empleo</a></div>
                        </div>
                        <div class="row no-gutters py-1">
                            <a class="col-6 px-1" href="'.route('public.empleos.activar').'"><span class="opc opc-activo"><i class="fas fa-circle"></i>&nbsp;Activo</span></a>
                            <div class="col-6 px-1"><span class="opc opc-inactivo"><i class="fas fa-circle"></i>&nbsp;Inactivo</span></div>
                        </div>';
            return $button; 
        })->addColumn('estado',function($empleo)
        {
            if($empleo->activo){
                return '<span class="estado-activo"><i class="fas fa-circle"></i>&nbsp;activo</span>';
            }else{
                return '<span class="estado-inactivo"><i class="fas fa-circle"></i>&nbsp;inactivo</span>';
            }
        })->addColumn('candidatos',function($empleo){
            $candidatos = $empleo->candidatos()->count();
            $button = "<a class='btn btn-success text-white btn-block btn-sm border rounded' href='".route('empresa.indexCandidatosEmpresa',$empleo->id)."'>$candidatos Candidatos</a>";   
            return $button;
        })
        ->addColumn('sueldo', function($empleo) use($usuario){
            $sueldo = number_format($empleo->sueldo,2);
            $button = "<span>Q$sueldo</span><span></span>"; 
        return $button;
        })
        ->rawColumns(['action','estado','candidatos','sueldo'])
        ->make(true);
    }

    public function empleoslistContratados(Request $request)
    {
        $empresa = Auth::user()->empresa;
        
        $empleos = Empleo::selectRaw("empleos.*")
        ->leftjoin('empleo_candidatos','empleos.id','=','empleo_candidatos.empleo_id')
        ->where('empleo_candidatos.contratado',1)->where('empleos.empresa_id',$empresa->id)->groupBy('empleos.id');
        
        $empleos = $empleos->get();   

        return DataTables::of($empleos)
        ->addColumn('estado',function($empleos)
        {
            if($empleos->activo){
                return "<span class='opc opc-activo'><i class='fas fa-circle'></i>&nbsp;activo</span>";
            }else{
                return "<span class='opc opc-inactivo'><i class='fas fa-circle'></i>&nbsp;inactivo</span>";
            }
        })->addColumn('candidatos',function($empleos) {
            $candidatos = $empleos->empleoCandidato()->where('contratado',1)->count(); 
            $empleo_candidato_id = $empleos->empleoCandidato()->first();
            $button = "<a class='btn btn-warning btn-block btn-sm border rounded' href='".route('empresa.indexCandidatosContratados',$empleo_candidato_id)."'>$candidatos Candidatos</a>"; 
            return $button;
        })->addColumn('opciones',function($empleos) {
            $button = "<div class='row no-gutters py-1'>
                            <div class='col-12'><a class='btn btn-warning btn-block btn-sm border rounded' href='".route('private.empresas.empleos.edit',$empleos->id)."' role='button'>Editar Empleo</a></div>
                       </div>
                       <div class='row no-gutters py-1'>
                            <div class='col-12'><a class='btn btn-primary btn-block btn-sm border rounded' role='button'>Re publicar</a></div>
                       </div>"; 
            return $button;    
        })
        ->addColumn('sueldo', function($empleos) {
            $sueldo = number_format($empleos->sueldo,2);
            $button = "<span>Q$sueldo</span><span></span>"; 
        return $button;
        })
        ->addColumn('fecha', function($empleos) {
            $button = date_format($empleos->fecha_publicacion,"d/m/Y");
        return $button;
        })
        ->rawColumns(['estado','candidatos','opciones','sueldo','fecha'])
        ->make(true);
    }

    public function activarEmpleo()
    {
        return redirect()->back()->with('alert_success','Se ha notificado exitosamente al reclutador para activar la plaza!');
    }
}