<?php

namespace Modules\Empresas\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Modules\Empresas\Entities\Empresa;
use Modules\Empresas\Http\Requests\EmpresaRegistroStoreRequest;
use Modules\Usuarios\Entities\Usuario;
use Modules\Empresas\Http\Requests\Admin\EmpresaUpdateRequest;
use Illuminate\Support\Facades\Hash;
use Modules\Empleos\Entities\Empleo;
use Modules\Candidatos\Entities\Candidato;
use Modules\Pruebas\Entities\PruebaResultado;
use Modules\Pruebas\Entities\PruebaCandidato;
use Illuminate\Support\Facades\Auth;
use Yajra\DataTables\DataTables;
use Modules\Empleos\Entities\EmpleoCandidato;
use Illuminate\Support\Facades\Mail;
use Modules\Candidatos\Emails\ContratadoEmail;
use Illuminate\Support\Facades\Validator;

class EmpresasController extends Controller
{
    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */

    public function index()
    {
        return view('empresas::perfil.index2');
    }

    public function gracias()
    {
        return view('empresas::perfil.gracias-registro');
    }

    public function store(EmpresaRegistroStoreRequest $request)
    {
        $data = array(
            'email' => $request->email,
            'nombre' => $request->nombre,
            'apellido' => $request->nit,
            'password' => $request->password,
        );
        $usuario = Usuario::create($data);
        $usuario->assignRole('Empresa');
        session(['public.empresa.created' => true]);
        $filename = '';
        $filename2 = '';
        if(isset($request->logotipo)){
            $extension = $request->logotipo->extension();
            $filename = sha1(time().time()).".$extension";
            $request->logotipo->move(public_path('storage/uploads/images'),$filename);
        } 
        if(isset($request->rtu)){
            $extension = $request->rtu->extension();
            $filename2 = sha1(time().time()).".$extension";
            $request->rtu->move(public_path('storage/uploads/docs'),$filename2);
        }

        $empresa = $usuario->empresa()->create($request->except('_token','password_confirmation','id','password','method','logotipo','rtu')+
        ['logotipo' => $filename, 'rtu' => $filename2]);

        return view('empresas::perfil.gracias-registro')->with('alert_success', 'El usuario ha sido creado.');
    }


    public function getAjaxEmpresas(Request $request)
    {
        $term = $request->term ?: '';
        $tags = Empresa::where('nombre', 'like', $term.'%')->pluck('nombre', 'id');
        $valid_tags = [];
        foreach ($tags as $id => $tag) {
            $valid_tags[] = ['id' => $id, 'text' => $tag];
        }
        return response()->json($valid_tags);
    }

    public function update(EmpresaUpdateRequest $request, Empresa $empresa)
    {
        if (isset($request->password) ) {
            $data   = $request->only('nombre','email','activo','password');
            $data['password'] = Hash::make($data['password']);
        } else {
            $data   = $request->only('nombre','email','activo');
        }
        if(isset($request->logotipo)){
            $extension = $request->logotipo->extension();
            $filename = sha1(time().time()).".$extension";
            $request->logotipo->move(public_path('storage/uploads/images'),$filename);
            $empresa->update(['logotipo' => $filename]);
        }
        if(isset($request->rtu)){
            $extension = $request->rtu->extension();
            $filename = sha1(time().time()).".$extension";
            $request->rtu->move(public_path('storage/uploads/docs'),$filename);
            $empresa->update(['rtu' => $filename]);
        }
        $empresa->update($request->except('_method','id','usuario_id','_token','password','password_confirmation','activo','logotipo','rtu'));
        $empresa->usuario()->update($data+['apellido' => $request->nit]);
        return redirect()
            ->route('private.empresas.perfil')
            ->with('alert_success', 'El empresa ha sido actualizada.');
    }

    public function edit(Empresa $empresa)
    {
        return view('empresas::perfil.edit')->with(compact('empresa'));
    }

    public function indexCandidatosEmpresa(Empleo $empleo)
    {
        //dd($empleo->id);
        $empresa = Auth::user()->empresa;
        $empleos = Empleo::orderBy('plaza','desc')->where('empresa_id',$empresa->id)->get();
        return view('empresas::perfil.candidatos')->with(compact('empleo','empleos'));
    }

    public function indexCandidatosContratados(Request $request, EmpleoCandidato $empleocandidato)
    {
        //$empresa = Auth::user()->empresa; 
        $empleo = Empleo::select('empleos.*')->where('id',$empleocandidato->empleo_id)->first();

        $candidato = Candidato::select('candidatos.*')->where('id',$empleocandidato->candidato_id)->first();

        return view('empresas::perfil.candidatos-contratados')->with(compact('candidato','empleo'));;
    }

    public function candidatosEmpresaList(Request $request){
        $usuario = Auth::user();
        $candidatos = Candidato::selectRaw('candidatos.*')
                                ->join('empleo_candidatos','candidatos.id','=','empleo_candidatos.candidato_id')
                                ->addSelect('empleo_candidatos.fecha_cita as fecha_cita_candidato')
                                ->addSelect('empleo_candidatos.contratado as contratado');
        $empleo = $request->empleo;
        if(isset($request->empleo)){
            $candidatos = $candidatos->addSelect('empleo_candidatos.id as empleo_candidatos_id')->where('empleo_candidatos.empleo_id',$request->empleo);
        }
        if(isset($request->aplica)){
            $candidatos = $candidatos->where('empleo_candidatos.aplica',1);
        }else{
            $candidatos = $candidatos->where('empleo_candidatos.aplica',0);
        }
        $candidatos = $candidatos->get(); 

        return DataTables::of($candidatos)
        ->addColumn('candidato_info', function($candidato) use($usuario){ 
            $check_informe = $candidato->archivo_informe?'border-10':'';
            $edad = $candidato->fecha_nacimiento?$candidato->fecha_nacimiento->age.' años':'';
            $fotografia = $candidato->fotografia?asset('storage/uploads/images/'.$candidato->fotografia):asset('img/imagen-vacia.jpg');
            $button = "
            <div class='row no-gutters align-items-center'>
                <div class='col-4'><img src='".$fotografia."' class='img img-fluid $check_informe'></div>
                <div class='col-7'>
                <h5>$candidato->nombre_completo</h5> <span>$edad </span><span>No. $candidato->id</span><span>Tel. $candidato->telefono_fijo / $candidato->telefono_celular</span></div>
            </div>";
            return $button;
        })
        ->addColumn('opciones', function($candidato) use($empleo) { 
            $empleo = Empleo::whereId($empleo)->first();
            $empleo_candidato =  EmpleoCandidato::where('candidato_id',$candidato->id)->where('empleo_id',$empleo->id)->first();
            $button = '
            <div class="row no-gutters py-1">
                <div class="col-12 col-lg-4 px-1"><a class="btn btn-warning btn-block border rounded-0" href="'.route('private.empresas.perfil.candidato',$candidato->empleo_candidatos_id).'" type="button">Ver Perfil</a></div>
                <div class="col-12 col-lg-4 px-1"><a class="btn btn-secondary btn-block border rounded-0" type="button" href="#" data-toggle="modal" data-target="#video'.$candidato->id.'candidato">Ver Video</a></div>
                <div class="col-12 col-lg-4 px-1"><a class="btn btn-warning btn-block border rounded-0" type="button" href="#" data-toggle="modal" data-target="#respuestas-candidato-'.$candidato->id.'" type="button">Ver Respuestas</a></div>   
            </div> 
            <div class="row no-gutters py-1">
                <div class="col-12 col-lg-6 px-1"><a class="btn btn-primary btn-block border rounded-0" href="javascript:aplica('.$candidato->id.','.$empleo->id.',1);"><i class="fas fa-circle text-success"></i>&nbsp;Aplica</a></div>
                <div class="col-12 col-lg-6 px-1"><a class="btn btn-primary btn-block border rounded-0" type="button" href="#" data-toggle="modal" data-target="#noAplica-destroy-'.$candidato->empleo_candidatos_id.'"><i class="fas fa-circle text-danger"></i>&nbsp;No Aplica</a></div>
            </div>'; 
            $html = view('staff::reclutamiento.video_candidato_modal', compact('candidato'))->render();
            $html .= view('empresas::perfil.noAplica', compact('candidato'))->render();
            $html .= view('empresas::perfil.respuestas', compact('candidato','empleo','empleo_candidato'))->render();
            return $button.$html;
        })
        ->addColumn('opciones2', function($candidato) use($usuario){ 

            if($candidato->pruebas){
                $button = '
                <div class="row no-gutters py-1"> 
                    <div class="col-12 col-lg-6 px-1"><a class="btn btn-success btn-block border rounded-0" target="_blank" href="'.route('staff.reclutamiento.informe.plus',$candidato->empleo_candidatos_id).'" type="button">Informe Plus</a></div>
                    <div class="col-12 col-lg-6 px-1"><a class="btn btn-success btn-block border rounded-0" target="_blank" href="'.route('staff.reclutamiento.informe.standar',$candidato->empleo_candidatos_id).'" type="button">Standard</a></div>
                </div>';

                return $button;
            }else{
                $button = '
                <div class="row no-gutters py-1"> 
                    <div class="col-12 col-lg-12 px-1"><button class="btn btn-success btn-block border rounded-0" style="background:gray;">No ha realizado las pruebas</button></div>
                </div>';

                return $button;
            }
            
        })
        ->addColumn('opciones3', function($candidato) use($usuario){
            $button = '
            <div class="row no-gutters py-1">
                <div class="col-12 col-lg-12 px-1"><a class="btn btn-warning btn-block border rounded-0" href="'.route('staff.reclutamiento.programar_cita',$candidato->empleo_candidatos_id).'" type="button">Programar Cita</a></div>
            </div>
            <div class="row no-gutters py-1">
                <div class="col-12 col-lg-12 px-1"><a class="opc opc-inactivo" type="button" href="#" data-toggle="modal" data-target="#noAplica-destroy-'.$candidato->empleo_candidatos_id.'"><i class="fas fa-circle"></i>&nbsp;descartado</a></div> 
            </div>'; 
            return $button;
        })
        ->addColumn('proceso', function($candidato) use($usuario){
            $entrevista = $candidato->entrevista()->count() == 0? 0:1;
            $pruebas = $candidato->pruebas()->first(); 
            $a = '';
            if(isset($pruebas)){
                $prueba_resultado = PruebaResultado::where('prueba_candidato_id',$pruebas->id)->get();
                if($prueba_resultado->count() >= 3){
                    $a = 3;
                }
            }else{
                $a = 0;
            }

            $button = '
                <ul>
                    <li><span class="indi-color active"></span><span class="indi-text">Aplica</span></li> 
                </ul>'; 
            if($a == 3){ 
                $button .= '
                <ul>
                    <li><span class="indi-color active"></span><span class="indi-text">Pruebas</span></li> 
                </ul>'; 
            } else{
                $button .= '
                <ul>
                    <li><span class="indi-color inactive"></span><span class="indi-text">Pruebas</span></li> 
                </ul>'; 
                }
            if($entrevista == 1){ 
                $button .= '
                <ul>
                    <li><span class="indi-color active"></span><span class="indi-text">Entrevista</span></li> 
                </ul>'; 
            } else{
                $button .= '
                <ul>
                    <li><span class="indi-color inactive"></span><span class="indi-text">Entrevista</span></li> 
                </ul>'; 
                }  
            if(isset($candidato->fecha_cita_candidato)){ 
                $button .= '
                <ul>
                    <li><span class="indi-color active"></span><span class="indi-text">Cita</span></li> 
                </ul>'; 
            } else{
                $button .= '
                <ul>
                    <li><span class="indi-color inactive"></span><span class="indi-text">Cita</span></li> 
                </ul>'; 
                }  
            if($candidato->contratado == 1){ 
                $button .= '
                <ul>
                    <li><span class="indi-color active"></span><span class="indi-text">Contratado</span></li> 
                </ul>'; 
            }else{
                $button .= '
                <ul>
                    <li><span class="indi-color inactive"></span><span class="indi-text">Contratado</span></li>  
                </ul>'; 
                }
            return $button;
        })
        ->addColumn('pretension_salarial', function($candidato) use($usuario){
            $pretension_salarial = number_format($candidato->pretension_salarial,2);
            $button = "<span>Q$pretension_salarial</span><span></span>"; 
            return $button;
        })
        ->rawColumns(['opciones','candidato_info','pretension_salarial','proceso','opciones2','opciones3'])
        ->make(true);
    }

    public function candidatosEmpresaContratado(Request $request){
        
        $candidatos = Candidato::select('candidatos.*')
            ->addSelect('empleo_candidatos.id as empleo_candidatos_id')
            ->join('empleo_candidatos','candidatos.id','=','empleo_candidatos.candidato_id')
            //->where('empleo_candidatos.candidato_id',$request->candidato_id)
            ->where('empleo_candidatos.contratado',1)
            ->where('empleo_candidatos.empleo_id',$request->empleo_id);
        $candidatos = $candidatos->get();

        return DataTables::of($candidatos)
        ->addColumn('candidato_info', function($candidato) {
            $check_informe = $candidato->archivo_informe?'border-10':'';
            $edad = $candidato->fecha_nacimiento?$candidato->fecha_nacimiento->age.' años':'';
            $fotografia = $candidato->fotografia?asset('storage/uploads/images/'.$candidato->fotografia):asset('img/imagen-vacia.jpg');
            $button = "
            <div class='row no-gutters align-items-center'>
                <div class='col-4'><img src='".$fotografia."' class='img img-fluid $check_informe'></div>
                <div class='col-7'>
                <a href='".route('staff.reclutamiento.perfil.candidato',$candidato->empleo_candidatos_id)."'> <h5>$candidato->nombre_completo</h5> </a> <span>$edad </span><span>No. $candidato->id</span> <span>Tel. $candidato->telefono_fijo / $candidato->telefono_celular</span></div>
            </div>";
            return $button;
        })
        ->addColumn('opciones', function($candidato) { 
            $button = '
            <div class="row no-gutters py-1">
                <div class="col-12 col-lg-6 px-1"><a class="btn btn-warning btn-block border rounded-0" href="'.route('private.empresas.perfil.candidato',$candidato->empleo_candidatos_id).'" type="button">Ver Perfil</a></div>
                <div class="col-12 col-lg-6 px-1"><a class="btn btn-secondary btn-block border rounded-0" type="button" href="#" data-toggle="modal" data-target="#video'.$candidato->id.'candidato">Ver Video</a></div> 
            </div>'; 
            $html = view('staff::reclutamiento.video_candidato_modal', compact('candidato'))->render(); 
            return $button.$html;
        })
        ->addColumn('pretension_salarial', function($candidato) {
            $pretension_salarial = number_format($candidato->pretension_salarial,2);
            $button = "<span>Q$pretension_salarial</span><span></span>"; 
            return $button;
        })
        ->rawColumns(['opciones','candidato_info','pretension_salarial'])
        ->make(true);
    }

    public function contratado(Request $request) 
    {
        $usuario = Auth::user()->empresa;

        $empleo_candidato = EmpleoCandidato::where('candidato_id',$request->candidato_id)->where('empleo_id',$request->empleo_id)->first();
        $empleo_candidato->update(['contratado' => $request->contratado]);

        $candidato = Candidato::where('id',$request->candidato_id);
        $candidato = $candidato->first();

        $empleo = Empleo::where('id',$request->empleo_id);
        $empleo = $empleo->first();

        Mail::to($candidato->email)->send(new ContratadoEmail($candidato, $empleo));
        //return redirect()->route('empresa.indexCandidatosEmpresa',$request->empleo_id)->with('Candidato contratado para la plaza');
        return response()->json(['status' => true, 'msj' => 'Candidato contratado para la plaza']);
    }
}
