<?php

namespace Modules\Empresas\Http\Controllers\Privado;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use Modules\Empresas\Http\Requests\EmpresaRegistroStoreRequest;
use Modules\Usuarios\Entities\Usuario;
use Modules\Empresas\Http\Requests\EmpresaArchivosRequest;
use Modules\Empresas\Entities\Empresa;
use Illuminate\Support\Facades\Validator;
use Modules\Empleos\Entities\EmpleoCandidato;
use Modules\Candidatos\Entities\Candidato;
use Barryvdh\DomPDF\Facade as PDF;
use Illuminate\Support\Facades\Mail;
use Modules\Candidatos\Emails\DescartadoEmail;
use Modules\Empleos\Entities\Empleo;
use Modules\Paginas\Entities\Servicio;

class EmpresasController extends Controller
{
    public function index()
    {
        $empresa = Auth::user()->empresa;
        return view('empresas::perfil.index')->with(compact('empresa'));
    }
    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function store(EmpresaRegistroStoreRequest $request)
    {
        $data = array(
            'email' => $request->email,
            'nombre' => $request->nombre,
            'apellido' => $request->nit,
            'password' => $request->password,
        );
        $usuario = Usuario::create($data);
        $usuario->assignRole('Empresa');
        session(['public.empresa.created' => true]);
        $filename = '';
        if(isset($request->logotipo)){
            $extension = $request->logotipo->extension();
            $filename = sha1(time().time()).".$extension";
            $request->logotipo->move(public_path('storage/uploads/images'),$filename);
        }
        $empresa = $usuario->empresa()->create($request->except('_token','password_confirmation','id','password','method','logotipo')+['logotipo' => $filename]);
        return redirect()
            ->back()
            ->with('alert_success', 'El usuario ha sido creado.');
    }

    public function fileUpdate(EmpresaArchivosRequest $request, Empresa $empresa)
    {
        if(isset($request->logotipo)){ 

            $validator = Validator::make($request->all(), [
                'logotipo'         => 'max:2560',
            ]);
            if ($validator->fails()) {
                return redirect()->back()->with('alert_error', 'El logotipo no puede pesar mas de 2.5MB');
            } 

            $extension = $request->logotipo->extension();
            $filename = sha1(time().time()).".$extension";
            $request->logotipo->move(public_path('storage/uploads/images'),$filename);
            $empresa->update(['logotipo' => $filename]);

            return redirect()
            ->route('private.empresas.perfil')
            ->with('alert_success', 'El perfil ha sido actualizado correctamente.');

        }
    }

    public function destroyEmpleoCandidato(EmpleoCandidato $empleocandidato)
    { 
        try {

            $candidato = Candidato::where('id',$empleocandidato->candidato_id)->first();

            //$empleocandidato->delete();

            $empleocandidato->update(['aplica' => 2]);

            Mail::to($candidato->email)->send(new DescartadoEmail($candidato));

            return redirect()->back()->with('alert_success','Se ha notificado al candidato que ha sido descartado!');

              } catch (\Exception $e)  {
            return redirect()->back()

            ->with('alert_error', 'Registro relacionado, imposible de eliminar');
        }        
    }

    public function noAplica(EmpleoCandidato $empleocandidato)
    { 
        try {

            $candidato = Candidato::where('id',$empleocandidato->candidato_id)->first();

            //$empleocandidato->delete();

            $empleocandidato->update(['aplica' => 2]);

            Mail::to($candidato->email)->send(new DescartadoEmail($candidato));
            
            if(Auth::user()->hasRole('Empresa')){  
                return redirect()->route('empresa.indexCandidatosEmpresa',$empleocandidato->empleo_id)->with('alert_success','El candidato ha sido descartado existosamente.');
            }else{
                return redirect()->route('staff.reclutamiento.indexCandidatos',$empleocandidato->empleo_id)->with('alert_success','El candidato ha sido descartado existosamente.');
            }    
              } catch (\Exception $e)  {
            if(Auth::user()->hasRole('Empresa')){       
                return redirect()->route('empresa.indexCandidatosEmpresa',$empleocandidato->empleo_id)->with('alert_error', 'Registro relacionado, imposible de eliminar');
            }else{
                return redirect()->route('staff.reclutamiento.indexCandidatos',$empleocandidato->empleo_id)->with('alert_success','El candidato ha sido descartado existosamente.');
            }
        }        
    }

    public function programarCita(Request $request, EmpleoCandidato $empleocandidato)
    {
        $candidato = Candidato::where('id',$empleocandidato->candidato_id);
        $candidato = $candidato->first();

        $empleo = Empleo::where('id',$empleocandidato->empleo_id);
        $empleo = $empleo->first();

        return redirect()->back()->with('alert_success','Se ha programado la cita exitosamente!');
    }

    /*public function solicitudInforme(Empleocandidato $empleocandidato) 
    {
        //$data = $request->except('_token','_method','id');
        $empleo = Empleo::select('empleos.*')
        ->addSelect('empresas.persona_contacto as contacto')
        ->addSelect('empresas.telefono_contacto as telefono_contacto')
        ->addSelect('empresas.telefono as telefono')
        ->addSelect('empresas.nombre as nombre')
        ->addSelect('empresas.email as email_empresa')
        ->join('empresas','empleos.empresa_id','=','empresas.id')
        ->where('empleos.id',$empleocandidato->empleo_id)->first();

        $candidato = Candidato::where('id', $empleocandidato->candidato_id)->first();
        //dd($candidato->nombre_completo);
        
        Servicio::create(['contacto' => $empleo->contacto, 
        'celular' => $empleo->telefono_contacto, 
        'empresa' => $empleo->nombre, 
        'corporativo' => $empleo->telefono, 
        'servicio' => 'Solicitud informe standard',
        'giro' => $candidato->nombre_completo,
        'email' => $empleo->email_empresa,
        'pregunta1' => $empleo->plaza,
        'pregunta2' => $candidato->id
        ]);
        //$empleo = Empleo::create($request->except('_method','_token','id','imagen','competencias')+$imagen+['competencias' => $competencias]); 
        return redirect()->back()->with('alert_success', 'Solicitud de informe standard enviada exitosamente.');
    }*/

}
