<?php

namespace Modules\Paginas\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Modules\Empleos\Entities\Empleo;
use Modules\Empresas\Entities\Empresa;
use Modules\Paginas\Entities\Pagina;
use Modules\Paginas\Entities\Servicio;
use RealRashid\SweetAlert\Facades\Alert;
use Modules\Configuracion\Entities\Dropdown;
use Modules\Configuracion\Entities\Politica;
use Modules\Paginas\Entities\Blog;
use Illuminate\Support\Facades\DB;
use Carbon\Carbon;
use Modules\Paginas\Emails\SolicitudInformeEmail;
use Barryvdh\DomPDF\Facade as PDF;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;

class DisplayController extends Controller
{
    

    /**
     * Show the specified resource.
     * @return Response
     */
    public function show($slug)
    {
        $pagina = Pagina::where([
                'slug' => $slug, 
                'activa' => 1
            ])
            ->first();

        if (!$pagina) {
            abort(404);
        }
        
        return view('paginas::display.show')
            ->with(compact('pagina'));
    }
    public function inicio()
    {
        $posts = Blog::select('blog.*')
        ->addSelect(DB::raw('DATE_FORMAT(fecha_post, "%d/%m/%Y") as fecha'))->orderBy('created_at','desc')->get();

        foreach(getDropdown('Categorías Empleos') as $key => $categoria){

            $empleos[] = Empleo::where('activo',1)->where('categorias', 'LIKE', '%'.$key.'%')->count();

        }

        return view('paginas::display.inicio')->with(compact('posts','empleos'));
    }
    public function noticias()
    {
        $posts = Blog::select('blog.*')
        ->addSelect(DB::raw('DATE_FORMAT(fecha_post, "%d/%m/%Y") as fecha'))->get();
        
        return view('paginas::display.blog')->with(compact('posts'));
    }
    public function registroCandidato()
    {
        $politica = Politica::all();
        return view('paginas::display.registro-candidato')->with(compact('politica'));
    }
    public function registroEmpresa()
    {
        $politica = Politica::all();
        return view('paginas::display.registro-empresa')->with(compact('politica'));
    }
    public function gracias()
    {
        return view('paginas::display.gracias');
    }
    public function serviciosOutsourcing()
    {
        $servicio = getPageBySlug('outsourcing');
        $sueldo_minimo = Dropdown::where('key',478);
        $sueldo_minimo = $sueldo_minimo->get();
        //dd($sueldo_minimo);
        return view('paginas::display.outsourcing')->with(compact('servicio','sueldo_minimo'));
    }
    public function serviciosReclutamiento()
    {
        $servicio = getPageBySlug('outsourcing');
        return view('paginas::display.reclutamiento')->with(compact('servicio'));
    }
    public function serviciosPrefiltrado(Request $request)
    { 

        if($request->get('tipo') == 1){
            $informe = "Standard";
            $servicio = getPageBySlug('outsourcing');
            return view('paginas::display.prefiltrado')->with(compact('servicio','informe'));
        }elseif($request->get('tipo') == 2){
            $informe = "Plus";
            $servicio = getPageBySlug('outsourcing');
            $empleo_candidato = $request->get('empleo_candidato_id');
            return view('paginas::display.prefiltrado')->with(compact('servicio','informe','empleo_candidato'));
        }elseif($request->get('tipo') == 3){ 

            $validator = Validator::make($request->all(), [
                'empleo_candidato_id' => 'unique:servicios,empleo_candidato_id', 
            ]);
            if ($validator->fails()) {
                return redirect()->back()->with('alert_error', 'La solicitud de informe plus para este candidato y plaza ya fue solicitado anteriormente.');
            }

            $empresa_id = $request->get('empresa_id','');
            $empleo_candidato_id = $request->get('empleo_candidato_id','');

            $empresa = Empresa::whereId($empresa_id)->first();

            $servicio = Servicio::create($request->except('_token')
            +['estado' => 446]+['contacto' => $empresa->persona_contacto]+['celular' => $empresa->telefono_contacto]
            +['empresa' => $empresa->nombre]+['corporativo' => $empresa->telefono]+['email' => $empresa->email]+['giro' => $empresa->categoria]
            +['servicio' => 'Prefiltrado/Solicitud Informe Plus']+['empleo_candidato_id' => $empleo_candidato_id]);

            $asunto = 'Prefiltrado/Servicio Avanzado Informe Plus';

            Mail::to($empresa->email, $empresa->persona_contacto)->cc(getDropdown('Correo Cotizaciones'))->send(new SolicitudInformeEmail($asunto)); 

            return redirect()->back()->with('alert_success', 'Tu informe ya fue solicitado, uno de nuestros reclutadores se contactará contigo.'); 
        }else{
            $informe = "";
            $servicio = getPageBySlug('outsourcing');
            return view('paginas::display.prefiltrado')->with(compact('servicio','informe'));
        }    

    }
    public function serviciosPlanillas()
    {
        $servicio = getPageBySlug('outsourcing');
        return view('paginas::display.planillas')->with(compact('servicio'));
    }
    public function serviciosRiesgos()
    {
        $servicio = getPageBySlug('outsourcing');
        return view('paginas::display.riesgos')->with(compact('servicio'));
    }
    public function servicios()
    {
        return view('paginas::display.servicios');
    }
    public function publicar()
    {
        return view('paginas::display.publicar');
    }
    public function empleos()
    {
        $empleos = Empleo::where('activo',1)->paginate(10);
        return view('paginas::display.empleos')->with(compact('empleos'));
    }
}
