<?php

namespace Modules\Paginas\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\View;
use Modules\Paginas\Entities\Pagina;
use Modules\Paginas\Http\Requests\PaginaStoreRequest;
use Modules\Paginas\Http\Requests\PaginaUpdateRequest;
use Yajra\DataTables\DataTables;

class PaginasController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index()
    {
        return view('paginas::paginas.index');
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        return view('paginas::paginas.create');
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function store(PaginaStoreRequest $request)
    {
        $pagina = Pagina::create($request->except('_token','id'));
        return redirect()
            ->route('admin.paginas.show', $pagina->id)
            ->with('alert_success', 'La página ha sido creada.');
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show(Pagina $pagina)
    {
        return view('paginas::paginas.show')->with(compact('pagina'));
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function edit(Pagina $pagina)
    {
        return view('paginas::paginas.edit')->with(compact('pagina'));
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(PaginaUpdateRequest $request, Pagina $pagina)
    {
        $pagina->update($request->except('_token','id','method'));
        return redirect()
            ->route('admin.paginas.show', $pagina->id)
            ->with('alert_success', 'La página ha sido actualizada.');
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Response
     */
    public function destroy(Pagina $pagina)
    {
        //
    }


    public function paginasList(Request $request){
        $usuario = Auth::user();
        $paginas = Pagina::select('*')->withDepth();
        $paginas = $paginas->get()->toFlatTree();
        return DataTables::of($paginas)
        ->addColumn('action', function($pagina) use($usuario){
            $button = '<a class="btn btn-primary btn-sm" href="'.route('admin.paginas.show',$pagina->id).'"><i class="fas fa-eye"></i></a>';
            if($usuario->hasPermissionTo('Editar Dropdowns') || $usuario->hasRole('Super Admin')){
                $button .= '<a class="btn btn-info btn-sm"  href="'.route('admin.paginas.edit',$pagina->id).'"><i class="fas fa-pencil-alt"></i></a>';
            }
            if($usuario->hasPermissionTo('Eliminar Dropdowns') || $usuario->hasRole('Super Admin')){
                $button .= '<a class="btn btn-danger btn-sm" href="#" data-toggle="modal" data-target="#pagina-destroy-'.$pagina->id.'" ><i class="fas fa-trash"></i></a>';
                $button .= View::make('paginas::paginas.destroy',['pagina' => $pagina]);
            }
            return $button;
        })
        ->rawColumns(['action'])
        ->make(true);
    }
}
