<?php

namespace Modules\Paginas\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use Modules\Paginas\Entities\Servicio;
use Modules\Paginas\Entities\Seguimiento;
use Modules\Paginas\Entities\PerfilPuesto;
use Modules\Paginas\Http\Requests\ServiciosStoreRequest;
use Modules\Paginas\Http\Requests\PerfilPuestoRequest;
use Modules\Configuracion\Entities\Dropdown;
use Modules\Usuarios\Entities\Usuario;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;
use Barryvdh\DomPDF\Facade as PDF;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\URL;
use RealRashid\SweetAlert\Facades\Alert;
use Modules\Paginas\Emails\ServiciosCreatedEmail;
use Illuminate\Support\Facades\Validator;
use Carbon\Carbon;

class ServiciosController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index()
    {
        return view('paginas::index'); 
    }

    public function outsorcing(Request $request)
    {
        //dd($request);
        return view('paginas::index');
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        return view('paginas::create');
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function store(Request $request, Servicio $servicio )  
    { 

        $usuario = Auth::user();

        $validator = Validator::make($request->all(), [
            'g-recaptcha-response' => 'recaptcha'
        ]);

        if ($validator->fails()) { 
            return redirect()->back()->with('alert_error', $validator->messages()->first())->withInput();
        }

        $data = $request->except('_token','estado');
        $servicio = Servicio::create($data+['estado' => 446]);
        
        $cotizacion = Servicio::where('id',$servicio->id);
        $cotizacion = $cotizacion->first();
        $costo_unitario_socioeconomico = getDropdownValue('533');
        $costo_unit_poligrafica = getDropdownValue('535');
        $total_socioeconomico = $cotizacion->socioeconomico * $costo_unitario_socioeconomico;
        $total_socioeconomico = number_format($total_socioeconomico, 2, '.', '');
        $total_poligrafica = $cotizacion->poligrafica * $costo_unit_poligrafica;
        $total_poligrafica = number_format($total_poligrafica, 2, '.', '');
        $total = $total_socioeconomico + $total_poligrafica;
        $total = number_format($total, 2, '.', '');

        $anticipo_30_1 = $cotizacion->sueldo1 * 0.30 * $cotizacion->colaboradores1;
        $anticipo_30_1 = number_format($anticipo_30_1, 2, '.', '');
        $anticipo_30_2 = $cotizacion->sueldo2 * 0.30 * $cotizacion->colaboradores2;
        $anticipo_30_2 = number_format($anticipo_30_2, 2, '.', '');
        $anticipo_30_3 = $cotizacion->sueldo3 * 0.30 * $cotizacion->colaboradores3;
        $anticipo_30_3 = number_format($anticipo_30_3, 2, '.', '');
        $anticipo_30_4 = $cotizacion->sueldo4 * 0.30 * $cotizacion->colaboradores4;
        $anticipo_30_4 = number_format($anticipo_30_4, 2, '.', '');
        $anticipo_30_5 = $cotizacion->sueldo5 * 0.30 * $cotizacion->colaboradores5;
        $anticipo_30_4 = number_format($anticipo_30_4, 2, '.', '');

        $anticipo_70_1 = $cotizacion->sueldo1 * 0.70 * $cotizacion->colaboradores1;
        $anticipo_70_1 = number_format($anticipo_70_1, 2, '.', '');
        $anticipo_70_2 = $cotizacion->sueldo2 * 0.70 * $cotizacion->colaboradores2;
        $anticipo_70_2 = number_format($anticipo_70_2, 2, '.', '');
        $anticipo_70_3 = $cotizacion->sueldo3 * 0.70 * $cotizacion->colaboradores3;
        $anticipo_70_3 = number_format($anticipo_70_3, 2, '.', '');
        $anticipo_70_4 = $cotizacion->sueldo4 * 0.70 * $cotizacion->colaboradores4;
        $anticipo_70_4 = number_format($anticipo_70_4, 2, '.', '');
        $anticipo_70_5 = $cotizacion->sueldo5 * 0.70 * $cotizacion->colaboradores5;
        $anticipo_70_4 = number_format($anticipo_70_4, 2, '.', '');

        $total_sueldo = $cotizacion->sueldo1 + $cotizacion->sueldo2 + $cotizacion->sueldo3 + $cotizacion->sueldo4 +$cotizacion->sueldo5;
        $total_sueldo = number_format($total_sueldo, 2, '.', '');
        $total_anticipo_30 = $anticipo_30_1 + $anticipo_30_2 + $anticipo_30_3 + $anticipo_30_4 +$anticipo_30_5;
        $total_anticipo_30 = number_format($total_anticipo_30, 2, '.', '');
        $total_anticipo_70 = $anticipo_70_1 + $anticipo_70_2 + $anticipo_70_3 + $anticipo_70_4 + $anticipo_70_5;
        $total_anticipo_70 = number_format($total_anticipo_70, 2, '.', '');

        if($cotizacion->servicio == 'Reclutamiento y Seleccion de Personal'){

            $asunto = 'Reclutamiento y Selección de Personal';

            $pdf = PDF::loadView('paginas::mails.reclutamiento-seleccion',compact('cotizacion','anticipo_30_1','anticipo_30_2','anticipo_30_3','anticipo_30_4','anticipo_30_5',
            'anticipo_70_1','anticipo_70_2','anticipo_70_3','anticipo_70_4','anticipo_70_5','total_sueldo','total_anticipo_30','total_anticipo_70'));
                
            if(isset($cotizacion->puesto1)){
                PerfilPuesto::create(['servicio_id' => $cotizacion->id]+['nombre_puesto' => $cotizacion->puesto1]+['giro_negocio' => $cotizacion->giro]);
            }

            if(isset($cotizacion->puesto2)){
                PerfilPuesto::create(['servicio_id' => $cotizacion->id]+['nombre_puesto' => $cotizacion->puesto2]+['giro_negocio' => $cotizacion->giro]);
            }

            if(isset($cotizacion->puesto3)){
                PerfilPuesto::create(['servicio_id' => $cotizacion->id]+['nombre_puesto' => $cotizacion->puesto3]+['giro_negocio' => $cotizacion->giro]);
            }

            if(isset($cotizacion->puesto4)){
                PerfilPuesto::create(['servicio_id' => $cotizacion->id]+['nombre_puesto' => $cotizacion->puesto4]+['giro_negocio' => $cotizacion->giro]);
            }

            if(isset($cotizacion->puesto5)){
                PerfilPuesto::create(['servicio_id' => $cotizacion->id]+['nombre_puesto' => $cotizacion->puesto5]+['giro_negocio' => $cotizacion->giro]);
            }

            Mail::to($data["email"], $data["contacto"])->cc(getDropdown('Correo Cotizaciones'))->send(new ServiciosCreatedEmail($pdf,$asunto));
        }

        if($cotizacion->servicio == 'Minimizacion de Riesgos'){ 

            $asunto = 'Minimización de Riesgos';

            $pdf = PDF::loadView('paginas::mails.minimizacion-riesgos',compact('cotizacion','total_socioeconomico','total_poligrafica','total'));
        
            Mail::to($data["email"], $data["contacto"])->cc(getDropdown('Correo Cotizaciones'))->send(new ServiciosCreatedEmail($pdf,$asunto));

        }

        if($cotizacion->servicio == 'Prefiltrado/Servicio Avanzado Informe Standard' || $cotizacion->servicio == 'Prefiltrado/Servicio Avanzado Informe Plus' ||
        $cotizacion->servicio == 'Prefiltrado/Servicio Avanzado' ){ 

            $asunto = 'Prefiltrado/Servicio Avanzado';

            $pdf = PDF::loadView('paginas::mails.prefiltrado',compact('cotizacion'));

            Mail::to($data["email"], $data["contacto"])->cc(getDropdown('Correo Cotizaciones'))->send(new ServiciosCreatedEmail($pdf,$asunto));

        }
        
        if($cotizacion->servicio == 'Outsourcing'){ 

            $asunto = 'Outsourcing';

            $pdf = PDF::loadView('paginas::mails.outsourcing-planillas',compact('cotizacion'));

            Mail::to($data["email"], $data["contacto"])->cc(getDropdown('Correo Cotizaciones'))->send(new ServiciosCreatedEmail($pdf, $asunto));

        }   

        if($cotizacion->servicio == 'Administracion de Planillas'){ 

            $asunto = 'Administración de Planillas';

            $pdf = PDF::loadView('paginas::mails.planillas',compact('cotizacion'));

            Mail::to($data["email"], $data["contacto"])->cc(getDropdown('Correo Cotizaciones'))->send(new ServiciosCreatedEmail($pdf,$asunto));

        }   

        if($usuario && $usuario->hasRole('Empresa')){

            return redirect()->route('private.empresas.perfil')->with('alert_success','La cotización para tu informe plus ha sido enviada exitosamente.');

        }else{
            return redirect()->back()->with('alert_success', 'Hemos enviado la cotización solicitada a tu correo electrónico, favor verifica tu bandeja de entrada y/o spam. 
            De no recibirla por favor ponte en contacto con nuestros ejecutivos al 24645700 o a info@miscorpsa.com.');
        }
    }

    public function storeSeguimiento(Request $request, Servicio $servicio ) 
    {
        $data = $request->except('_token','_method','id');
        //dd($data);
        Seguimiento::create($data);
        return redirect()->back()->with('alert_success', 'Nota Creada');
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show($id)
    {
        return view('paginas::show');
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
        return view('paginas::edit');
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Response
     */
    public function destroy($id)
    {
        //
    }
    
    public function cotizacionShow(Request $request, Servicio $servicio)
    {

        $servicio = $servicio->where('id',$servicio->id)->first();
        //dd($servicio);
        return \PDF::loadView('paginas::display.show', compact('servicio'))->stream('cotizacion.pdf');
    }

    public function perfilpuestoShow(Request $request, Servicio $servicio) 
    {

        $puestos = PerfilPuesto::where('servicio_id',$servicio->id)->get();

        return \PDF::loadView('paginas::display.perfilpuesto-show', compact('puestos'))->stream('perfilpuesto.pdf');
    }

    public function perfilpuestoEdit(Servicio $servicio) 
    {
        
        $dropdowns = Dropdown::select('dropdowns.*')->where('parent_id','544')->get();

        $competencias = Dropdown::where('parent_id',414)->get();

        return view('paginas::display.perfilpuesto')->with(compact('servicio','dropdowns','competencias'));
    }

    public function perfilpuestoUpdate(PerfilPuestoRequest $request, PerfilPuesto $perfilpuesto) 
    {

        $data = $request->except('_token','habilidades','documento');

        if(isset($request->documento)){ 
            
            $extension = $request->documento->extension();
            $filename = sha1(time().time()).".$extension";
            $request->documento->move(public_path('storage/uploads/docs'),$filename);
            
            $data += ['documento' => $filename];
        }

        $habilidades = $request->habilidades; 
        $habilidades = implode(',',$habilidades);

        $perfilpuesto->update($data +['habilidades' => $habilidades]);

        if($request->siguiente == 1){
            return redirect()->back()->with('alert_success', 'Puesto guardado. Continua llenando el formulario para el siguiente puesto porfavor.');
        }

        if($request->enviar == 1){
            return redirect()->route('public.home')->with('alert_success', 'Perfil para el puesto guardado exitosamente!'); 
        }
        
    }
}
