<?php

namespace Modules\Pruebas\Http\Controllers\Admin;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use Modules\Pruebas\Entities\PreguntaPrueba;
use Modules\Pruebas\Entities\PruebaCandidato;
use Modules\Pruebas\Entities\PruebaRespuesta;
use Modules\Pruebas\Entities\PruebaResultado;
use Modules\Pruebas\Entities\Prueba;
use Modules\Pruebas\Entities\RespuestaPregunta;
use Modules\Pruebas\Http\Requests\PreguntaRequest;
use Modules\Pruebas\Http\Requests\RespuestaRequest;
use Modules\Pruebas\Http\Requests\PruebaCandidatoRequest;
use Modules\Pruebas\Http\Requests\PruebaRespuestaRequest;
use Modules\Pruebas\Http\Requests\PruebaResultadoRequest;
use Yajra\DataTables\DataTables;

class PreguntasController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index()
    {
        $pruebas = Prueba::orderBy('nombre');
        return view('pruebas::admin.preguntas.index')->with(compact('pruebas'));
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        $pruebas = Prueba::orderBy('nombre');
        return view('pruebas::admin.preguntas.create')->with(compact('pruebas'));
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function store(PreguntaRequest $request)
    {
        $pregunta = PreguntaPrueba::create($request->except('_token','_method','id'));
        return redirect()
            ->route('dashboard.pruebas.preguntas.show',$pregunta->id)
            ->with('alert_success', 'La Pregunta ha sido creada.');
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function storeRespuesta(RespuestaRequest $request) 
    {
        //dd($request->all());
        if(isset($request->id)){
            $respuesta = RespuestaPregunta::whereId($request->id)->first();
            $respuesta->update($request->except('_token','_method','id'));
            // dd($respuesta);
            //RespuestaPregunta::update($request->except('_token','_method','id'))->where('id','=',$request->id);
        }else{
            RespuestaPregunta::create($request->except('_token','_method','id'));
        } 

        return redirect()
            ->back()
            ->with('alert_success', 'La Respuesta ha sido creada.');
    }
    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show(PreguntaPrueba $pregunta)
    {
        return view('pruebas::admin.preguntas.show')->with(compact('pregunta'));
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function edit(PreguntaPrueba $pregunta)
    {
        $pruebas = Prueba::orderBy('nombre');
        return view('pruebas::admin.preguntas.edit')->with(compact('pruebas','pregunta'));
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(PreguntaRequest $request, PreguntaPrueba $pregunta)
    {
        $pregunta->update($request->except('_token','_method','id'));

        return redirect()
            ->route('dashboard.pruebas.preguntas.show',$pregunta->id)
            ->with('alert_success', 'La Pregunta ha sido actualizada.');
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Response
     */
    public function destroy(PreguntaPrueba $pregunta)
    {
        $pregunta->delete();

        return redirect()
            ->route('dashboard.pruebas.preguntas.index')
            ->with('alert_success', 'La Pregunta ha sido eliminada.');
    }
    public function preguntasList(Request $request)
    {
        $usuario = Auth::user();
        $prueba = $request->get('prueba','');
        $preguntas = PreguntaPrueba::select('pregunta_pruebas.*');

        if($prueba != ''){
            $preguntas = $preguntas->where('pregunta_pruebas.prueba_id',$prueba);
        }

        $preguntas = $preguntas->get();
        return DataTables::of($preguntas)
        ->addColumn('action', function($pregunta) use($usuario){
            $button = '<a class="btn btn-primary btn-sm" href="'.route('dashboard.pruebas.preguntas.show',$pregunta->id).'"><i class="fas fa-eye"></i></a>';
            if($usuario->hasPermissionTo('Editar Usuarios') || $usuario->hasRole('Super Admin')){
                $button .= '<a class="btn btn-info btn-sm" href="'.route('dashboard.pruebas.preguntas.edit',$pregunta->id).'"><i class="fas fa-pencil-alt"></i></a>';
            }
            if($usuario->hasPermissionTo('Eliminar Usuarios') || $usuario->hasRole('Super Admin')){
                $button .= '<a class="btn btn-danger btn-sm" href="#"   data-toggle="modal" data-target="#pregunta-destroy-'.$pregunta->id.'"><i class="fas fa-trash"></i></a>';
                $button .= view('pruebas::admin.preguntas.destroy', compact('pregunta'))->render();
            }
            return $button;
        })
        ->addColumn('respuestas', function($pregunta){
            $button = '';
            return $button;
        })
        ->addColumn('activo', function($pregunta){
            $html = ($pregunta->estado) ? '<span class="badge badge-success">Si</span>':'<span class="badge badge-danger">No</span>';
            return $html;
        })->rawColumns(['action','activo','respuestas'])
        ->make(true);
    }
}
