<?php

namespace Modules\Staff\Exports;

use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Modules\Empleos\Entities\EmpleoCandidato;
use Maatwebsite\Excel\Concerns\FromCollection;

class Contrataciones implements FromCollection, WithHeadings
{
    protected $fecha_fin;
    protected $fecha_inicio;
    protected $reclutador_id;

    public function __construct($fecha_inicio = null, $fecha_fin = null, $reclutador_id = null)
    {
        $this->fecha_fin = $fecha_fin;
        $this->fecha_inicio = $fecha_inicio;
        $this->reclutador_id = $reclutador_id;
    }
    public function headings(): array
    {
        return [
            'ID',
            'ID Candidato',
            'Nombre del candadidato',
            'ID Empleo',
            'Empresa',
            'Plaza',
            'Interpretación de resultados',
            'Verificación electrónica de Datos',
            'Fecha cita',
            'Dirección cita',
            'Hora cita',
            'Persona que entrevista',
            'Correo(s) para la cita',
            'Fecha de contratación',
            'No. Factura',
            'Fecha de facturación',
            'No. Boleta',
            'Fecha de depósito',
            'Banco',
            'Fecha inicio garantía',
            'Fecha finalización garantía',
            'Observaciones',
            'Garantía en días',
            'Fecha de modificación'
        ];
    }
    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $usuario = Auth::user();
        $contrataciones = EmpleoCandidato::select(
            'empleo_candidatos.id',  
            'empleo_candidatos.candidato_id',
            DB::raw('CONCAT(candidatos.nombre ," ", candidatos.apellido)'),
            'empleo_candidatos.empleo_id',
            'empleos.empresa',
            'empleos.plaza',
            'empleo_candidatos.interpretacion_resultados',
            'empleo_candidatos.verificacion_datos',
            DB::raw('DATE_FORMAT(empleo_candidatos.fecha_cita, "%d/%m/%Y")'),
            'empleo_candidatos.direccion_cita',
            'empleo_candidatos.hora_cita',
            'empleo_candidatos.persona_entrevista_cita',
            'empleo_candidatos.correo_cita',
            DB::raw('DATE_FORMAT(empleo_candidatos.fecha_contratacion, "%d/%m/%Y")'),
            'empleo_candidatos.no_factura_contratacion',
            DB::raw('DATE_FORMAT(empleo_candidatos.fecha_facturacion_contratacion, "%d/%m/%Y")'),
            'empleo_candidatos.no_boleta_contratacion',
            DB::raw('DATE_FORMAT(empleo_candidatos.fecha_deposito_contratacion, "%d/%m/%Y")'),
            'empleo_candidatos.banco_contratacion',
            DB::raw('DATE_FORMAT(empleo_candidatos.fecha_inicio_garantia, "%d/%m/%Y")'),
            DB::raw('DATE_FORMAT(empleo_candidatos.fecha_finalizo_garantia, "%d/%m/%Y")'),
            'empleo_candidatos.motivo_garantia',
            'empleo_candidatos.tipo_garantia',
            DB::raw('DATE_FORMAT(empleo_candidatos.updated_at, "%d/%m/%Y")')
            )
            ->leftJoin('candidatos','empleo_candidatos.candidato_id','=','candidatos.id')
            ->leftJoin('empleos','empleo_candidatos.empleo_id','=','empleos.id')
            ->where('contratado',1)
            ->where('fecha_contratacion','!=',null)
            ->orderBy('empleo_candidatos.updated_at','asc');
        if($this->fecha_inicio != NULL || $this->fecha_fin != NULL){
            $fecha_inicio = $this->fecha_inicio?$this->fecha_inicio:date('2020-01-01');
            $fecha_fin = $this->fecha_fin?$this->fecha_fin:Carbon::now()->addDay();

            $contrataciones = $contrataciones->whereBetween('empleo_candidatos.fecha_contratacion',[$fecha_inicio, $fecha_fin]);
        }
        if($usuario->hasRole(('Reclutamiento'))){
            $contrataciones = $contrataciones->where('empleos.usuario_id',$usuario->id);
        }
        if($this->reclutador_id != NULL){
            $contrataciones = $contrataciones->where('empleos.usuario_id',$this->reclutador_id);
        }
        return  $contrataciones->get();
    }
}