<?php

namespace Modules\Staff\Exports;

use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Modules\Paginas\Entities\Servicio;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\FromCollection;

class CotizacionesRechazadas implements FromCollection, WithHeadings
{
    protected $fecha_fin;
    protected $fecha_inicio;
    protected $vendedor_id;

    public function __construct($fecha_inicio = null, $fecha_fin = null, $vendedor_id = null)
    {
        $this->fecha_fin = $fecha_fin;
        $this->fecha_inicio = $fecha_inicio;
        $this->vendedor_id = $vendedor_id;
    }
    public function headings(): array
    {
        return [
            'ID',
            'Estado',
            'Contacto',
            'Celular',
            'Empresa',
            'Teléfono Corporativo',
            'Email',
            'Giro de la empresa',
            'Servicio',
            '¿Cuántos colaboradores?',
            'Sueldo asignado',
            'Beneficios extras',
            'Bonos',
            'Seguros',
            'Incentivos',
            '¿Anticipo facturado?',
            '¿Anticipo pagado',
            'Fecha garantía',
            'Descripción del puesto 1',
            'Descripción del puesto 2',
            'Descripción del puesto 3',
            'Descripción del puesto 4',
            'Descripción del puesto 5',
            'Cant. Colaboradores puesto 1',
            'Cant. Colaboradores puesto 2',
            'Cant. Colaboradores puesto 3',
            'Cant. Colaboradores puesto 4',
            'Cant. Colaboradores puesto 5',
            'Sueldo puesto 1',
            'Anticipo 30% Puesto 1',
            'Anticipo 70% Puesto 1',
            'Sueldo puesto 2',
            'Anticipo 30% Puesto 2',
            'Anticipo 70% Puesto 2',
            'Sueldo puesto 3',
            'Anticipo 30% Puesto 3',
            'Anticipo 70% Puesto 3',
            'Sueldo puesto 4',
            'Anticipo 30% Puesto 4',
            'Anticipo 70% Puesto 4',
            'Sueldo puesto 5',
            'Anticipo 30% Puesto 5',
            'Anticipo 70% Puesto 5',
            'Monto facturado'
        ];
    }
    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $usuario = Auth::user();
        $cotizaciones = Servicio::select(
            'servicios.id', 
            'estado',
            'servicios.contacto',
            'servicios.celular',
            'servicios.empresa',
            'servicios.corporativo',
            'servicios.email',
            'servicios.giro',
            'servicios.servicio',
            'servicios.colaboradores',
            'servicios.sueldo',
            DB::raw('IF(servicios.beneficios = 1 ,"Si", "No")'),
            DB::raw('IF(servicios.bonos = 1 ,"Si", "No")'),
            DB::raw('IF(servicios.seguros = 1 ,"Si", "No")'),
            DB::raw('IF(servicios.incentivos = 1 ,"Si", "No")'),
            DB::raw('IF(servicios.anti_facturado = 1 ,"Si", "No")'),
            DB::raw('IF(servicios.anti_pagado = 1 ,"Si", "No")'),
            DB::raw('DATE_FORMAT(servicios.fecha_garantia, "%d/%m/%Y")'),
            'servicios.puesto1',
            'servicios.puesto2',
            'servicios.puesto3',
            'servicios.puesto4',
            'servicios.puesto5',
            'servicios.colaboradores1',
            'servicios.colaboradores2',
            'servicios.colaboradores3',
            'servicios.colaboradores4',
            'servicios.colaboradores5',
            'servicios.sueldo1',
            DB::raw('(servicios.sueldo1)*.3'),
            DB::raw('(servicios.sueldo1)*.7'),
            'servicios.sueldo2',
            DB::raw('(servicios.sueldo2)*.3'),
            DB::raw('(servicios.sueldo2)*.7'),
            'servicios.sueldo3',
            DB::raw('(servicios.sueldo3)*.3'),
            DB::raw('(servicios.sueldo3)*.7'),
            'servicios.sueldo4',
            DB::raw('(servicios.sueldo4)*.3'),
            DB::raw('(servicios.sueldo4)*.7'),
            'servicios.sueldo5',
            DB::raw('(servicios.sueldo5)*.3'),
            DB::raw('(servicios.sueldo5)*.7'),
            'servicios.monto_facturado'
            )
            ->addSelect('dropdowns.value as estado')
            ->join('dropdowns','servicios.estado','=','dropdowns.id')
            ->where('estado',445)
            ->orderBy('servicios.created_at','asc');
        if($this->fecha_inicio != NULL || $this->fecha_fin != NULL){
            $fecha_inicio = $this->fecha_inicio?$this->fecha_inicio:date('2020-01-01');
            $fecha_fin = $this->fecha_fin?$this->fecha_fin:Carbon::now()->addDay();

            $cotizaciones = $cotizaciones->whereBetween('servicios.created_at',[$fecha_inicio, $fecha_fin]);
        }
        if($usuario->hasRole(('Ventas'))){
            $cotizaciones = $cotizaciones->where('usuario_id',$usuario->id);
        }
        if($this->vendedor_id != NULL){
            $cotizaciones = $cotizaciones->where('usuario_id',$this->vendedor_id);
        }
        return  $cotizaciones->get();
    }
}