<?php

namespace Modules\Staff\Exports;

use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Modules\Paginas\Entities\Servicio;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\FromCollection;

class InformesTerminados implements FromCollection, WithHeadings
{
    protected $fecha_fin;
    protected $fecha_inicio;
    protected $reclutador_id;

    public function __construct($fecha_inicio = null, $fecha_fin = null, $reclutador_id = null)
    {
        $this->fecha_fin = $fecha_fin;
        $this->fecha_inicio = $fecha_inicio;
        $this->reclutador_id = $reclutador_id;
    }
    public function headings(): array
    {
        return [
            'ID',
            'Estado',
            'Contacto',
            'Celular',
            'Teléfono Corporativo',
            'Email',
            'Giro de la empresa',
            'Servicio',
            '¿Anticipo facturado?',
            '¿Anticipo pagado',
            'Fecha garantía',
            'Fecha de creación',
            'Fecha de asignación'
        ];
    }
    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $usuario = Auth::user();
        $cotizaciones = Servicio::select(
            'servicios.id', 
            'estado',
            'servicios.contacto',
            'servicios.celular',
            'servicios.corporativo',
            'servicios.email',
            'servicios.giro',
            'servicios.servicio',
            DB::raw('IF(servicios.anti_facturado = 1 ,"Si", "No")'),
            DB::raw('IF(servicios.anti_pagado = 1 ,"Si", "No")'),
            DB::raw('DATE_FORMAT(servicios.fecha_garantia, "%d/%m/%Y")'),
            DB::raw('DATE_FORMAT(servicios.created_at, "%d/%m/%Y")'),
            DB::raw('DATE_FORMAT(servicios.fecha_asignacion_vendedor, "%d/%m/%Y")')
            )
            ->addSelect('dropdowns.value as estado')
            ->leftJoin('empleo_candidatos','servicios.empleo_candidato_id','=','empleo_candidatos.id')
            ->join('dropdowns','servicios.estado','=','dropdowns.id')
            ->where('servicio','Prefiltrado/Solicitud Informe Plus')
            ->where('servicios.reclutador_id','!=',null)
            ->where('empleo_candidatos.fecha_generacion_informe','!=',null);
            //->orderBy('servicios.created_at','asc');
        if( $this->fecha_inicio != NULL || $this->fecha_fin != NULL ){
            $fecha_inicio = $this->fecha_inicio?$this->fecha_inicio:date('2020-01-01');
            $fecha_fin = $this->fecha_fin?$this->fecha_fin:Carbon::now()->addDay();

            $cotizaciones = $cotizaciones->whereBetween('empleo_candidatos.fecha_generacion_informe',[$fecha_inicio, $fecha_fin]);
        }
        if($usuario->hasRole( ('Reclutamiento') ) ){
            $cotizaciones = $cotizaciones->where('servicios.reclutador_id',$usuario->id);
        }
        if($this->reclutador_id != NULL){
            $cotizaciones = $cotizaciones->where('servicios.reclutador_id',$this->reclutador_id);
        }
        return  $cotizaciones->get();
    }
}