<?php

namespace Modules\Staff\Exports;

use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Modules\Paginas\Entities\Servicio;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\FromCollection;

class MontoFacturado implements FromCollection, WithHeadings
{
    protected $fecha_fin;
    protected $fecha_inicio;
    protected $vendedor_id;

    public function __construct($fecha_inicio = null, $fecha_fin = null, $vendedor_id = null)
    {
        $this->fecha_fin = $fecha_fin;
        $this->fecha_inicio = $fecha_inicio;
        $this->vendedor_id = $vendedor_id;
    }
    public function headings(): array
    {
        return [
            'ID',
            'Estado',
            'Contacto',
            'Celular',
            'Teléfono Corporativo',
            'Email',
            'Giro de la empresa',
            'Servicio',
            '¿Anticipo facturado?',
            '¿Anticipo pagado',
            'Fecha garantía',
            'Monto facturado'
        ];
    }
    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $usuario = Auth::user();
        $cotizaciones = Servicio::select(
            'servicios.id', 
            'estado',
            'servicios.contacto',
            'servicios.celular',
            'servicios.corporativo',
            'servicios.email',
            'servicios.giro',
            'servicios.servicio',
            DB::raw('IF(servicios.anti_facturado = 1 ,"Si", "No")'),
            DB::raw('IF(servicios.anti_pagado = 1 ,"Si", "No")'),
            DB::raw('DATE_FORMAT(servicios.fecha_garantia, "%d/%m/%Y")'),
            'servicios.monto_facturado'
            )
            ->addSelect('dropdowns.value as estado')
            ->join('dropdowns','servicios.estado','=','dropdowns.id')
            ->where('monto_facturado','!=','')
            ->where('fecha_garantia','!=',null)
            ->orderBy('servicios.created_at','asc');
        if($this->fecha_inicio != NULL || $this->fecha_fin != NULL){
            $fecha_inicio = $this->fecha_inicio?$this->fecha_inicio:date('2020-01-01');
            $fecha_fin = $this->fecha_fin?$this->fecha_fin:Carbon::now()->addDay();

            $cotizaciones = $cotizaciones->whereBetween('servicios.fecha_garantia',[$fecha_inicio, $fecha_fin]);
        }
        if($usuario->hasRole(('Ventas'))){
            $cotizaciones = $cotizaciones->where('usuario_id',$usuario->id);
        }
        if($this->vendedor_id != NULL){
            $cotizaciones = $cotizaciones->where('usuario_id',$this->vendedor_id);
        }
        return  $cotizaciones->get();
    }
}