<?php

namespace Modules\Staff\Exports;

use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Modules\Empleos\Entities\Empleo;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\FromCollection;

class VacantesProceso implements FromCollection, WithHeadings
{
    protected $fecha_fin;
    protected $fecha_inicio;
    protected $reclutador_id;

    public function __construct($fecha_inicio = null, $fecha_fin = null, $reclutador_id = null)
    {
        $this->fecha_fin = $fecha_fin;
        $this->fecha_inicio = $fecha_inicio;
        $this->reclutador_id = $reclutador_id;
    }
    public function headings(): array
    {
        return [
            'ID',
            'Empresa',
            'Plaza',
            'Fecha publicación',
            'Descripción',
            '¿Activo?',
            '¿Empleo confidencial?',
            'Duración',
            '¿Promocionar en redes?',
            'Reclutador',
            'Candidatos',
            'Fecha de creación',
            'Fecha de asignación'
        ];
    }
    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $usuario = Auth::user();
        $empleos = Empleo::select(
            'empleos.id', 
            'empleos.empresa',
            'empleos.plaza',
            DB::raw('DATE_FORMAT(empleos.fecha_publicacion, "%d/%m/%Y")'),
            'empleos.descripcion',
            DB::raw('IF(empleos.activo = 1 ,"Si", "No")'),
            DB::raw('IF(empleos.empleo_confidencial = 1 ,"Si", "No")'),
            'empleos.duracion',
            DB::raw('IF(empleos.promocionar = 1 ,"Si", "No")'),
            DB::raw('CONCAT(usuarios.nombre ," ", usuarios.apellido)'),
            'terna_candidatos.candidatos',
            DB::raw('DATE_FORMAT(empleos.created_at, "%d/%m/%Y")'),
            DB::raw('DATE_FORMAT(empleos.fecha_asignacion, "%d/%m/%Y")')
            )
            ->addSelect('dropdowns.value as duracion')
            ->leftJoin('dropdowns','empleos.duracion','=','dropdowns.id')
            ->leftJoin('usuarios','empleos.usuario_id','=','usuarios.id')
            ->join('terna_candidatos','empleos.id','=','terna_candidatos.empleo_id')
            ->where('empleos.activo',1)
            ->orderBy('empleos.id','asc');
        if($this->fecha_inicio != NULL || $this->fecha_fin != NULL){
            $fecha_inicio = $this->fecha_inicio?$this->fecha_inicio:date('2020-01-01');
            $fecha_fin = $this->fecha_fin?$this->fecha_fin:Carbon::now()->addDay();

            $empleos = $empleos->whereBetween('terna_candidatos.fecha_terna',[$fecha_inicio, $fecha_fin]);
        }
        if($usuario->hasRole(('Reclutamiento'))){
            $empleos = $empleos->where('empleos.usuario_id',$usuario->id);
        }
        if($this->reclutador_id != NULL){
            $empleos = $empleos->where('empleos.usuario_id',$this->reclutador_id);
        }
        return  $empleos->get();
    }
}