<?php

namespace Modules\Staff\Exports;

use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Modules\Empleos\Entities\Empleo;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\FromCollection;

class VacantesRevision implements FromCollection, WithHeadings
{
    protected $fecha_fin;
    protected $fecha_inicio;

    public function __construct($fecha_inicio = null, $fecha_fin = null)
    {
        $this->fecha_fin = $fecha_fin;
        $this->fecha_inicio = $fecha_inicio;
    }
    public function headings(): array
    {
        return [
            'ID',
            'Empresa',
            'Plaza',
            'Fecha publicación',
            'Descripción',
            '¿Activo?',
            '¿Empleo confidencial?',
            'Duración',
            '¿Promocionar en redes?',
            'Fecha de creación'
        ];
    }
    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $empleos = Empleo::select(
            'empleos.id', 
            'empleos.empresa',
            'empleos.plaza',
            DB::raw('DATE_FORMAT(empleos.fecha_publicacion, "%d/%m/%Y")'),
            'empleos.descripcion',
            DB::raw('IF(empleos.activo = 1 ,"Si", "No")'),
            DB::raw('IF(empleos.empleo_confidencial = 1 ,"Si", "No")'),
            'empleos.duracion',
            DB::raw('IF(empleos.promocionar = 1 ,"Si", "No")'),
            DB::raw('DATE_FORMAT(empleos.created_at, "%d/%m/%Y")')
            )
            ->addSelect('dropdowns.value as duracion')
            ->leftJoin('dropdowns','empleos.duracion','=','dropdowns.id')
            ->where('empleos.activo',0)
            ->where('empleos.usuario_id',null)
            ->orderBy('empleos.id','asc');
        if($this->fecha_inicio != NULL || $this->fecha_fin != NULL){
            $fecha_inicio = $this->fecha_inicio?$this->fecha_inicio:date('2020-01-01');
            $fecha_fin = $this->fecha_fin?$this->fecha_fin:Carbon::now()->addDay();

            $empleos = $empleos->whereBetween('empleos.created_at',[$fecha_inicio, $fecha_fin]);
        }
        return  $empleos->get();
    }
}