<?php

namespace Modules\Staff\Http\Controllers;

use Carbon\Carbon;
use Illuminate\Support\Arr;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Yajra\DataTables\DataTables;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;
use Modules\Empleos\Entities\Empleo;
use Modules\Empresas\Entities\Empresa;
use Modules\Paginas\Entities\Servicio;
use Modules\Usuarios\Entities\Usuario;
use Illuminate\Support\Facades\Validator;
use Modules\Candidatos\Entities\Candidato;
use Modules\Candidatos\Emails\PruebasEmail;
use Modules\Staff\Entities\TernaCandidatos;
use Modules\Configuracion\Entities\Dropdown;
use Modules\Empleos\Entities\EmpleoCandidato;
use Modules\Pruebas\Entities\PruebaResultado;
use Modules\Staff\Http\Requests\InformeRequest;
use Modules\Candidatos\Entities\CandidatoEstudio;
use Modules\Candidatos\Entities\CandidatoEntrevista;
use Modules\Candidatos\Entities\CandidatoOtrosDatos;
use Modules\Candidatos\Entities\CandidatoReferencia;
use Modules\Candidatos\Entities\CandidatoExperiencia;
use Modules\Candidatos\Entities\CandidatoHabilidades;
use Modules\Empleos\Http\Requests\EmpleoStoreRequest;

class ReclutamientoController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index()
    {
        $usuario = Auth::user(); 
        $informes_plus_solicitados = Servicio::where('servicios.servicio','Prefiltrado/Solicitud Informe Plus')->where('servicios.fecha_asignacion_vendedor','!=',null)
        ->where('servicios.reclutador_id',$usuario->id)->count();
        $informes_plus_generados = Servicio::leftJoin('empleo_candidatos','servicios.empleo_candidato_id','=','empleo_candidatos.id')->where('servicios.servicio','Prefiltrado/Solicitud Informe Plus')->where('servicios.reclutador_id','!=',null)
        ->where('empleo_candidatos.fecha_generacion_informe','!=',null)->where('servicios.reclutador_id',$usuario->id)->count();
        $vacantes_asignadas = Empleo::where('activo',1)->where('usuario_id',$usuario->id)->count();
        $vacantes_proceso = Empleo::where('empleos.activo',1)->join('terna_candidatos','empleos.id','=','terna_candidatos.empleo_id')
        ->where('empleos.usuario_id',$usuario->id)->count();
        $contrataciones = EmpleoCandidato::where('empleo_candidatos.contratado',1)->join('empleos','empleo_candidatos.empleo_id','=','empleos.id')->where('empleos.usuario_id',$usuario->id)->count(); 
        $reclutadores = Usuario::selectRaw("concat(usuarios.nombre, ' ', usuarios.apellido) as nombre")
        ->addSelect('usuarios.id as id')
        ->join('model_has_roles','usuarios.id','=','model_has_roles.model_id')
        ->whereIn('model_has_roles.role_id', [4])->where('activo',1)->get(); 

        return view('staff::reclutamiento.index')->with(compact('vacantes_asignadas','vacantes_proceso',
        'contrataciones','reclutadores','informes_plus_solicitados','informes_plus_generados')); 
    }

    public function indicadoresStaffReclutamiento(Request $request)
    {   
        $usuario = Auth::user(); 
        $fecha_inicio = $request->get('fecha_inicio')?$request->get('fecha_inicio'):date('2020-01-01');
        $fecha_fin = $request->get('fecha_fin')?$request->get('fecha_fin'):Carbon::now()->addDay();

        $informes_plus_solicitados = Servicio::where('servicios.servicio','Prefiltrado/Solicitud Informe Plus')->where('servicios.fecha_asignacion_vendedor','!=',null)
        ->where('servicios.reclutador_id',$usuario->id)->whereBetween('servicios.fecha_asignacion_vendedor',[$fecha_inicio, $fecha_fin])->count();
        $informes_plus_generados = Servicio::leftJoin('empleo_candidatos','servicios.empleo_candidato_id','=','empleo_candidatos.id')->where('servicios.servicio','Prefiltrado/Solicitud Informe Plus')->where('servicios.reclutador_id','!=',null)
        ->where('empleo_candidatos.fecha_generacion_informe','!=',null)->whereBetween('empleo_candidatos.fecha_generacion_informe',[$fecha_inicio, $fecha_fin])->where('servicios.reclutador_id',$usuario->id)->count();
        $vacantes_asignadas = Empleo::where('activo',1)->where('usuario_id',$usuario->id)->whereBetween('created_at',[$fecha_inicio, $fecha_fin])->count();
        $contrataciones_reclutamiento = EmpleoCandidato::where('empleo_candidatos.contratado',1)->join('empleos','empleo_candidatos.empleo_id','=','empleos.id')->where('empleos.usuario_id',$usuario->id)
        ->whereBetween('empleo_candidatos.fecha_contratacion',[$fecha_inicio, $fecha_fin])->count();
        $vacantes_proceso = Empleo::where('empleos.activo',1)->join('terna_candidatos','empleos.id','=','terna_candidatos.empleo_id')
        ->where('empleos.usuario_id',$usuario->id)->whereBetween('terna_candidatos.fecha_terna',[$fecha_inicio, $fecha_fin])->count();

        echo "{\"vacantes_asignadas\":\"$vacantes_asignadas\",\"contrataciones_reclutamiento\":\"$contrataciones_reclutamiento\",
             \"vacantes_proceso\":\"$vacantes_proceso\",\"informes_plus_solicitados\":\"$informes_plus_solicitados\",
             \"informes_plus_generados\":\"$informes_plus_generados\"}";
        die(); 
    }

    public function showCandidato(Request $request, EmpleoCandidato $empleocandidato)
    {
        $usuario = Auth::user();
        $empleo_candidato = EmpleoCandidato::
        where('candidato_id',$empleocandidato->candidato_id)
        ->where('empleo_candidatos.empleo_id',$empleocandidato->empleo_id);
        $empleo_candidato = $empleo_candidato->first();

        $candidato = Candidato::where('id',$empleocandidato->candidato_id);
        $candidato = $candidato->first();

        $empleo = Empleo::where('id',$empleocandidato->empleo_id);
        $empleo = $empleo->first();

        $estudios = CandidatoEstudio::where('candidato_id',$empleocandidato->candidato_id);
        $estudios = $estudios->first();

        $otros = CandidatoOtrosDatos::where('candidato_id',$empleocandidato->candidato_id);
        $otros = $otros->first();

        $experiencias = CandidatoExperiencia::where('candidato_id',$empleocandidato->candidato_id)->limit(3);
        $experiencias = $experiencias->get(); 

        $referencias = CandidatoReferencia::where('candidato_id',$empleocandidato->candidato_id)->limit(3);
        $referencias = $referencias->get();

        $entrevista = CandidatoEntrevista::where('candidato_id',$empleocandidato->candidato_id);
        $entrevista = $entrevista->first();

        $habilidades = CandidatoHabilidades::where('candidato_id',$empleocandidato->candidato_id);
        $habilidades = $habilidades->first();

        $siguiente = Candidato::selectRaw('candidatos.*')
                                ->addSelect('empleo_candidatos.id as empleo_candidatos_id')
                                ->join('empleo_candidatos','candidatos.id','=','empleo_candidatos.candidato_id')
                                ->where('empleo_candidatos.aplica',0)
                                ->where('empleo_candidatos.empleo_id',$empleo->id)
                                ->where('empleo_candidatos.id','>',$empleocandidato->id)
                                ->oldest('empleo_candidatos.id')
                                ->first();

        $anterior = Candidato::selectRaw('candidatos.*')
                                ->addSelect('empleo_candidatos.id as empleo_candidatos_id')
                                ->join('empleo_candidatos','candidatos.id','=','empleo_candidatos.candidato_id')
                                ->where('empleo_candidatos.aplica',0)
                                ->where('empleo_candidatos.empleo_id',$empleo->id)
                                ->where('empleo_candidatos.id','<',$empleocandidato->id)
                                ->latest('empleo_candidatos.id')
                                ->first();

        //$candidato = Auth::user()->candidato; 
        $otros1 = $candidato->otros()->count() == 0? 0:1;
        $experiencia1 = $candidato->experiencia()->count() == 0? 0:1;
        $referencia1 = $candidato->referencia()->count() == 0? 0:1;
        $estudios1 = $candidato->estudios()->count() == 0? 0:1;
        $habilidades1 = $candidato->habilidades()->count() == 0? 0:1;
        $fotografia = isset($candidato->fotografia)?1:0;
        $cv = isset($candidato->cv)?1:0;
        $fecha_nacimiento = $candidato->fecha_nacimiento?1:0;
        $dpi = $candidato->dpi?1:0;
        $igss = ( isset($candidato->igss) && $candidato->igss != null )?1:0;
        $direccion = $candidato->direccion?1:0;
        $pais = $candidato->pais?1:0;
        $departamento = $candidato->departamento?1:0;
        $municipio = $candidato->municipio?1:0;
        $zona = (isset($candidato->zona) || $candidato->zona != 0)?1:0;

        $total = $otros1 + $experiencia1 + $referencia1 + $estudios1 + $habilidades1 + $fotografia + $cv + $fecha_nacimiento + $dpi + $igss + $direccion + $pais + $departamento +
        $municipio + $zona;

        $porcentaje = intval(($total/15) * 100);

        return view('staff::reclutamiento.perfil')->with(compact('empleo_candidato','candidato','empleo','estudios','otros','experiencias','referencias', 'entrevista',
        'habilidades','porcentaje','siguiente','anterior'));
    }

    public function showCandidatoDatabase(Request $request, Candidato $candidato)
    {

        $empleo_candidato = EmpleoCandidato::where('candidato_id',$candidato->candidato_id)->get();

        $estudios = CandidatoEstudio::where('candidato_id',$candidato->id);
        $estudios = $estudios->first();

        $otros = CandidatoOtrosDatos::where('candidato_id',$candidato->id);
        $otros = $otros->first();

        $experiencias = CandidatoExperiencia::where('candidato_id',$candidato->id)->limit(3);
        $experiencias = $experiencias->get(); 

        $referencias = CandidatoReferencia::where('candidato_id',$candidato->id)->limit(3);
        $referencias = $referencias->get();

        $entrevista = CandidatoEntrevista::where('candidato_id',$candidato->id);
        $entrevista = $entrevista->first();

        $habilidades = CandidatoHabilidades::where('candidato_id',$candidato->id);
        $habilidades = $habilidades->first();

        $filtros = $request->only('id','nombre','telefono','edad_inicial','edad_final','edad_final','porcentaje_perfil','genero','estado_civil',
        'tpo_licencia','licencia','vehiculo','departamento','municipio','zona','profesion','anios_experiencia_inicio','anios_experiencia_fin',
        'area_experiencia','pretencion_salarial_inicio','pretension_salarial_fin','experiencia_laboral_empresa','experiencia_laboral_puesto',
        'experiencia_laboral_funciones','estudios','carrera_tecnica','otros_conocimientos_tecnicos','otros_conocimientos_tecnicos_especifique','empleo');

        $filtros = Arr::query($filtros);

        $buscar_id = $request->get('id');
        $buscar_nombre = $request->get('nombre');
        $buscar_telefono = $request->get('telefono');
        $buscar_edad_inicial = $request->get('edad_inicial');
        $buscar_edad_final = $request->get('edad_final');
        $buscar_porcentaje_perfil = $request->get('porcentaje_perfil');
        $buscar_genero = $request->get('genero');
        $buscar_estado_civil = $request->get('estado_civil');
        $buscar_idiomas = $request->get('idiomas');
        $buscar_tipo_licencia = $request->get('tipo_licencia');
        $buscar_licencia = $request->get('licencia');
        $buscar_vehiculo = $request->get('vehiculo');
        $buscar_departamento = $request->get('departamento');
        $buscar_municipio = $request->get('municipio');
        $buscar_zona = $request->get('zona');
        $buscar_profesion = $request->get('profesion');
        $buscar_anios_experiencia_inicio = $request->get('anios_experiencia_inicio');
        $buscar_anios_experiencia_fin = $request->get('anios_experiencia_fin');
        $buscar_area_experiencia = $request->get('area_experiencia');
        $buscar_pretension_salarial_inicio = $request->get('pretension_salarial_inicio');
        $buscar_pretension_salarial_fin = $request->get('pretension_salarial_fin');
        $buscar_experiencia_laboral_empresa = $request->get('experiencia_laboral_empresa');
        $buscar_experiencia_laboral_puesto = $request->get('experiencia_laboral_puesto');
        $buscar_experiencia_laboral_funciones = $request->get('experiencia_laboral_funciones');
        $buscar_estudios = $request->get('estudios');
        $buscar_carrera_tecnica = $request->get('carrera_tecnica');
        $buscar_habilidades = $request->get('habilidades');
        $buscar_otros_conocimientos_tecnicos = $request->get('otros_conocimientos_tecnicos');
        $buscar_edad_inicial = $request->get('edad_inicial');
        $buscar_otros_conocimientos_tecnicos_especifique = $request->get('otros_conocimientos_tecnicos_especifique');
        $buscar_empleo = $request->get('empleo');

        $candidato_filtrado = Candidato::selectRaw('candidatos.*');

        if($buscar_empleo != ''){
            $candidato_filtrado->join('empleo_candidatos','candidatos.id','=','empleo_candidatos.candidato_id')
            ->where('empleo_candidatos.empleo_id',$buscar_empleo);
        }

        if($buscar_id != ''){
            $candidato_filtrado->where(function($q) use ($buscar_id) { 
                $q->where('candidatos.id','like','%'.$buscar_id.'%');
            });
        }
        if($buscar_nombre != ''){
            $candidato_filtrado->where(function($q) use ($buscar_nombre) { 
                $q->where(DB::raw("CONCAT(candidatos.nombre,' ',candidatos.apellido)"),'like','%'.$buscar_nombre.'%');
            });
        }
        if($buscar_telefono != ''){
            $candidato_filtrado->where(function($q) use ($buscar_telefono) { 
                $q->where('candidatos.telefono_fijo','like','%'.$buscar_telefono.'%');
                $q->orWhere('candidatos.telefono_celular','like','%'.$buscar_telefono.'%');
            });
        }
        if($buscar_edad_inicial != '' && $buscar_edad_final != ''){
            $candidato_filtrado->whereBetween(DB::raw('TIMESTAMPDIFF(YEAR, candidatos.fecha_nacimiento, CURDATE())'),[$buscar_edad_inicial,$buscar_edad_final]);
        }
        if($buscar_profesion != ''){
            $candidato_filtrado->where('candidatos.profesion','like','%'.$buscar_profesion.'%');
        }
        if($buscar_anios_experiencia_inicio != '' && $buscar_anios_experiencia_fin != ''){
            $candidato_filtrado->whereBetween('candidatos.anios_experiencia',[$buscar_anios_experiencia_inicio,$buscar_anios_experiencia_fin]);
        }
        if($buscar_pretension_salarial_inicio != '' && $buscar_pretension_salarial_fin != ''){
            $candidato_filtrado->whereBetween('candidatos.pretension_salarial',[$buscar_pretension_salarial_inicio, $buscar_pretension_salarial_fin]);
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 100){
                $candidato_filtrado->where('candidatos.fotografia','!=',null)
                ->where('candidatos.cv','!=',null)
                ->where('candidatos.fecha_nacimiento','!=',null)
                ->where('candidatos.dpi','!=',null)    
                ->where('candidatos.igss','!=',null)
                ->where('candidatos.direccion','!=',null)
                ->where('candidatos.pais','!=',null)
                ->where('candidatos.departamento','!=',null)
                ->where('candidatos.municipio','!=',null)
                ->where('candidatos.zona','!=',null)
                ->with(['estudios','otros','experiencia','referencia','habilidades'])
                ->whereHas('estudios')
                ->whereHas('otros')
                ->whereHas('experiencia')
                ->whereHas('referencia')
                ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 93){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv','!=',null)
            ->where('candidatos.fecha_nacimiento','!=',null)
            ->where('candidatos.dpi','!=',null)    
            ->where('candidatos.igss','!=',null)
            ->where('candidatos.direccion','!=',null)
            ->where('candidatos.pais','!=',null)
            ->where('candidatos.departamento','!=',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 86){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento','!=',null)
            ->where('candidatos.dpi','!=',null)    
            ->where('candidatos.igss','!=',null)
            ->where('candidatos.direccion','!=',null)
            ->where('candidatos.pais','!=',null)
            ->where('candidatos.departamento','!=',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 80){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi','!=',null)    
            ->where('candidatos.igss','!=',null)
            ->where('candidatos.direccion','!=',null)
            ->where('candidatos.pais','!=',null)
            ->where('candidatos.departamento','!=',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 73){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss','!=',null)
            ->where('candidatos.direccion','!=',null)
            ->where('candidatos.pais','!=',null)
            ->where('candidatos.departamento','!=',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 66){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion','!=',null)
            ->where('candidatos.pais','!=',null)
            ->where('candidatos.departamento','!=',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 60){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais','!=',null)
            ->where('candidatos.departamento','!=',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 53){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento','!=',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 46){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 40){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 33){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio',null)
            ->where('candidatos.zona',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 26){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio',null)
            ->where('candidatos.zona',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereDoesntHave('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 20){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio',null)
            ->where('candidatos.zona',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereDoesntHave('estudios')
            ->whereDoesntHave('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 13){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio',null)
            ->where('candidatos.zona',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereDoesntHave('estudios')
            ->whereDoesntHave('otros')
            ->whereDoesntHave('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 6){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio',null)
            ->where('candidatos.zona',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereDoesntHave('estudios')
            ->whereDoesntHave('otros')
            ->whereDoesntHave('experiencia')
            ->whereDoesntHave('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 0){
            $candidato_filtrado->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio',null)
            ->where('candidatos.zona',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereDoesntHave('estudios')
            ->whereDoesntHave('otros')
            ->whereDoesntHave('experiencia')
            ->whereDoesntHave('referencia')
            ->whereDoesntHave('habilidades');
        }
        if($buscar_genero != ''){
            $candidato_filtrado->where('candidatos.genero',$buscar_genero);
        }
        if($buscar_estado_civil != ''){
            $candidato_filtrado->where('candidatos.estado_civil',$buscar_estado_civil);
        }
        if($buscar_idiomas != '' ){
            $candidato_filtrado->join('candidato_habilidades','candidatos.id','=','candidato_habilidades.candidato_id');
            if(in_array('ingles', $buscar_idiomas)){
                $candidato_filtrado->where('candidato_habilidades.ingles',375);
            }if(in_array('aleman', $buscar_idiomas)){
                $candidato_filtrado->where('candidato_habilidades.aleman',375);
            }if(in_array('archivo', $buscar_idiomas)){
                $candidato_filtrado->where('candidato_habilidades.archivo',375);
            }if(in_array('otro', $buscar_idiomas)){
                $candidato_filtrado->where('candidato_habilidades.otro',375);
            }
        }
        if($buscar_licencia != '' && $buscar_licencia == 375){
            $candidato_filtrado->where('candidatos.licencia','!=',null);
        }
        if($buscar_licencia != '' && $buscar_licencia == 376){
            $candidato_filtrado->where('candidatos.licencia',null);
        }
        if($buscar_tipo_licencia != ''){
            $candidato_filtrado->where('candidatos.tipo_licencia',$buscar_tipo_licencia);
        }
        if($buscar_vehiculo != '' && $buscar_vehiculo == 375){
            $candidato_filtrado->join('candidato_otros_datos','candidatos.id','=','candidato_otros_datos.candidato_id')->where('candidato_otros_datos.posee_vehiculo',375);
        }
        if($buscar_vehiculo != '' && $buscar_vehiculo == 376){
            $candidato_filtrado->join('candidato_otros_datos','candidatos.id','=','candidato_otros_datos.candidato_id')->where('candidato_otros_datos.posee_vehiculo',376);
        }
        if($buscar_departamento != 'Seleccione Uno'){
            $candidato_filtrado->where('candidatos.departamento',$buscar_departamento);
        }
        if($buscar_municipio != 'Seleccione Uno' && $buscar_municipio != ''){
            $candidato_filtrado->where('candidatos.municipio',$buscar_municipio);
        }
        if($buscar_zona != ''){
            $candidato_filtrado->where('candidatos.zona',$buscar_zona);
        }
        if($buscar_area_experiencia != ''){
            $candidato_filtrado->where('candidatos.area_experiencia','like','%'.$buscar_area_experiencia.'%');
        }
        if($buscar_experiencia_laboral_empresa != ''){
            $candidato_filtrado->join('candidato_experiencias','candidatos.id','=','candidato_experiencias.candidato_id')->where('candidato_experiencias.empresa','like','%'.$buscar_experiencia_laboral_empresa.'%');
        }
        if($buscar_experiencia_laboral_puesto != ''){
            $candidato_filtrado->join('candidato_experiencias','candidatos.id','=','candidato_experiencias.candidato_id')->where('candidato_experiencias.puesto','like','%'.$buscar_experiencia_laboral_puesto.'%');
        }
        if($buscar_experiencia_laboral_funciones != ''){
            $candidato_filtrado->join('candidato_experiencias','candidatos.id','=','candidato_experiencias.candidato_id')->where('candidato_experiencias.funciones_principales','like','%'.$buscar_experiencia_laboral_funciones.'%');
        }
        if($buscar_estudios != '' ){
            $candidato_filtrado->join('candidato_estudios','candidatos.id','=','candidato_estudios.candidato_id');
            if($buscar_estudios == 'universitarios'){
                $candidato_filtrado->where('candidato_estudios.estudios_univeristarios',375);
            }if($buscar_estudios == 'diversificado'){
                $candidato_filtrado->where('candidato_estudios.diversificado',375);
            }if($buscar_estudios == 'basicos'){
                $candidato_filtrado->where('candidato_estudios.basicos',375);
            }if($buscar_estudios == 'primaria'){
                $candidato_filtrado->where('candidato_estudios.primaria',375);
            }
        }
        if($buscar_carrera_tecnica != ''){
            $candidato_filtrado->join('candidato_estudios','candidatos.id','=','candidato_estudios.candidato_id')->where('candidato_estudios.titulo_carrera_tecnica','like','%'.$buscar_carrera_tecnica.'%');
        }
        if($buscar_habilidades != '' ){
            $candidato_filtrado->join('candidato_habilidades','candidatos.id','=','candidato_habilidades.candidato_id');
            if(in_array('mecanografia', $buscar_habilidades)){
                $candidato_filtrado->where('candidato_habilidades.mecanografia',375);
            }if(in_array('taquigrafia', $buscar_habilidades)){
                $candidato_filtrado->where('candidato_habilidades.taquigrafia',375);
            }if(in_array('archivo', $buscar_habilidades)){
                $candidato_filtrado->where('candidato_habilidades.archivo',375);
            }if(in_array('computacion', $buscar_habilidades)){
                $candidato_filtrado->where('candidato_habilidades.computacion',375);
            }if(in_array('reposteria', $buscar_habilidades)){
                $candidato_filtrado->where('candidato_habilidades.reposteria',375);
            }if(in_array('cocina', $buscar_habilidades)){
                $candidato_filtrado->where('candidato_habilidades.cocina',375);
            }if(in_array('enfermeria', $buscar_habilidades)){
                $candidato_filtrado->where('candidato_habilidades.enfermeria',375);
            }if(in_array('programacion', $buscar_habilidades)){
                $candidato_filtrado->where('candidato_habilidades.programacion',375);
            }if(in_array('internet', $buscar_habilidades)){
                $candidato_filtrado->where('candidato_habilidades.internet',375);
            }
        }   
        if($buscar_otros_conocimientos_tecnicos != '' && $buscar_otros_conocimientos_tecnicos_especifique != ''){
            $candidato_filtrado->join('candidato_habilidades','candidatos.id','=','candidato_habilidades.candidato_id');
            if($buscar_otros_conocimientos_tecnicos == 375){
                $candidato_filtrado->where('candidato_habilidades.otros_conocimientos_tecnicos_especifique','!=',null);
            }
            if($buscar_otros_conocimientos_tecnicos == 376){
                $candidato_filtrado->where('candidato_habilidades.otros_conocimientos_tecnicos_especifique',null);
            }
            if($buscar_otros_conocimientos_tecnicos_especifique != ''){
                $candidato_filtrado->where('candidato_habilidades.otros_conocimientos_tecnicos_especifique','like','%'.$buscar_otros_conocimientos_tecnicos_especifique.'%');
            }
        }

        $siguiente = $candidato_filtrado->where('candidatos.id','>',$candidato->id)
                                ->oldest('candidatos.id')
                                ->first();


        $candidato_filtrado2 = Candidato::selectRaw('candidatos.*');

        if($buscar_empleo != ''){
            $candidato_filtrado2->join('empleo_candidatos','candidatos.id','=','empleo_candidatos.candidato_id')
            ->where('empleo_candidatos.empleo_id',$buscar_empleo);
        }

        if($buscar_id != ''){
            $candidato_filtrado2->where(function($q) use ($buscar_id) { 
                $q->where('candidatos.id','like','%'.$buscar_id.'%');
            });
        }
        if($buscar_nombre != ''){
            $candidato_filtrado2->where(function($q) use ($buscar_nombre) { 
                $q->where(DB::raw("CONCAT(candidatos.nombre,' ',candidatos.apellido)"),'like','%'.$buscar_nombre.'%');
            });
        }
        if($buscar_telefono != ''){
            $candidato_filtrado2->where(function($q) use ($buscar_telefono) { 
                $q->where('candidatos.telefono_fijo','like','%'.$buscar_telefono.'%');
                $q->orWhere('candidatos.telefono_celular','like','%'.$buscar_telefono.'%');
            });
        }
        if($buscar_edad_inicial != '' && $buscar_edad_final != ''){
            $candidato_filtrado2->whereBetween(DB::raw('TIMESTAMPDIFF(YEAR, candidatos.fecha_nacimiento, CURDATE())'),[$buscar_edad_inicial,$buscar_edad_final]);
        }
        if($buscar_profesion != ''){
            $candidato_filtrado2->where('candidatos.profesion','like','%'.$buscar_profesion.'%');
        }
        if($buscar_anios_experiencia_inicio != '' && $buscar_anios_experiencia_fin != ''){
            $candidato_filtrado2->whereBetween('candidatos.anios_experiencia',[$buscar_anios_experiencia_inicio,$buscar_anios_experiencia_fin]);
        }
        if($buscar_pretension_salarial_inicio != '' && $buscar_pretension_salarial_fin != ''){
            $candidato_filtrado2->whereBetween('candidatos.pretension_salarial',[$buscar_pretension_salarial_inicio, $buscar_pretension_salarial_fin]);
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 100){
                $candidato_filtrado2->where('candidatos.fotografia','!=',null)
                ->where('candidatos.cv','!=',null)
                ->where('candidatos.fecha_nacimiento','!=',null)
                ->where('candidatos.dpi','!=',null)    
                ->where('candidatos.igss','!=',null)
                ->where('candidatos.direccion','!=',null)
                ->where('candidatos.pais','!=',null)
                ->where('candidatos.departamento','!=',null)
                ->where('candidatos.municipio','!=',null)
                ->where('candidatos.zona','!=',null)
                ->with(['estudios','otros','experiencia','referencia','habilidades'])
                ->whereHas('estudios')
                ->whereHas('otros')
                ->whereHas('experiencia')
                ->whereHas('referencia')
                ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 93){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv','!=',null)
            ->where('candidatos.fecha_nacimiento','!=',null)
            ->where('candidatos.dpi','!=',null)    
            ->where('candidatos.igss','!=',null)
            ->where('candidatos.direccion','!=',null)
            ->where('candidatos.pais','!=',null)
            ->where('candidatos.departamento','!=',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 86){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento','!=',null)
            ->where('candidatos.dpi','!=',null)    
            ->where('candidatos.igss','!=',null)
            ->where('candidatos.direccion','!=',null)
            ->where('candidatos.pais','!=',null)
            ->where('candidatos.departamento','!=',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 80){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi','!=',null)    
            ->where('candidatos.igss','!=',null)
            ->where('candidatos.direccion','!=',null)
            ->where('candidatos.pais','!=',null)
            ->where('candidatos.departamento','!=',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 73){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss','!=',null)
            ->where('candidatos.direccion','!=',null)
            ->where('candidatos.pais','!=',null)
            ->where('candidatos.departamento','!=',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 66){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion','!=',null)
            ->where('candidatos.pais','!=',null)
            ->where('candidatos.departamento','!=',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 60){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais','!=',null)
            ->where('candidatos.departamento','!=',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 53){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento','!=',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 46){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio','!=',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 40){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio',null)
            ->where('candidatos.zona','!=',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 33){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio',null)
            ->where('candidatos.zona',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereHas('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 26){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio',null)
            ->where('candidatos.zona',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereDoesntHave('estudios')
            ->whereHas('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 20){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio',null)
            ->where('candidatos.zona',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereDoesntHave('estudios')
            ->whereDoesntHave('otros')
            ->whereHas('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 13){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio',null)
            ->where('candidatos.zona',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereDoesntHave('estudios')
            ->whereDoesntHave('otros')
            ->whereDoesntHave('experiencia')
            ->whereHas('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 6){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio',null)
            ->where('candidatos.zona',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereDoesntHave('estudios')
            ->whereDoesntHave('otros')
            ->whereDoesntHave('experiencia')
            ->whereDoesntHave('referencia')
            ->whereHas('habilidades');
        }if($buscar_porcentaje_perfil != '' && $buscar_porcentaje_perfil == 0){
            $candidato_filtrado2->where('candidatos.fotografia',null)
            ->where('candidatos.cv',null)
            ->where('candidatos.fecha_nacimiento',null)
            ->where('candidatos.dpi',null)    
            ->where('candidatos.igss',null)
            ->where('candidatos.direccion',null)
            ->where('candidatos.pais',null)
            ->where('candidatos.departamento',null)
            ->where('candidatos.municipio',null)
            ->where('candidatos.zona',null)
            ->with(['estudios','otros','experiencia','referencia','habilidades'])
            ->whereDoesntHave('estudios')
            ->whereDoesntHave('otros')
            ->whereDoesntHave('experiencia')
            ->whereDoesntHave('referencia')
            ->whereDoesntHave('habilidades');
        }
        if($buscar_genero != ''){
            $candidato_filtrado2->where('candidatos.genero',$buscar_genero);
        }
        if($buscar_estado_civil != ''){
            $candidato_filtrado2->where('candidatos.estado_civil',$buscar_estado_civil);
        }
        if($buscar_idiomas != '' ){
            $candidato_filtrado2->join('candidato_habilidades','candidatos.id','=','candidato_habilidades.candidato_id');
            if(in_array('ingles', $buscar_idiomas)){
                $candidato_filtrado2->where('candidato_habilidades.ingles',375);
            }if(in_array('aleman', $buscar_idiomas)){
                $candidato_filtrado2->where('candidato_habilidades.aleman',375);
            }if(in_array('archivo', $buscar_idiomas)){
                $candidato_filtrado2->where('candidato_habilidades.archivo',375);
            }if(in_array('otro', $buscar_idiomas)){
                $candidato_filtrado2->where('candidato_habilidades.otro',375);
            }
        }
        if($buscar_licencia != '' && $buscar_licencia == 375){
            $candidato_filtrado2->where('candidatos.licencia','!=',null);
        }
        if($buscar_licencia != '' && $buscar_licencia == 376){
            $candidato_filtrado2->where('candidatos.licencia',null);
        }
        if($buscar_tipo_licencia != ''){
            $candidato_filtrado2->where('candidatos.tipo_licencia',$buscar_tipo_licencia);
        }
        if($buscar_vehiculo != '' && $buscar_vehiculo == 375){
            $candidato_filtrado2->join('candidato_otros_datos','candidatos.id','=','candidato_otros_datos.candidato_id')->where('candidato_otros_datos.posee_vehiculo',375);
        }
        if($buscar_vehiculo != '' && $buscar_vehiculo == 376){
            $candidato_filtrado2->join('candidato_otros_datos','candidatos.id','=','candidato_otros_datos.candidato_id')->where('candidato_otros_datos.posee_vehiculo',376);
        }
        if($buscar_departamento != 'Seleccione Uno'){
            $candidato_filtrado2->where('candidatos.departamento',$buscar_departamento);
        }
        if($buscar_municipio != 'Seleccione Uno' && $buscar_municipio != ''){
            $candidato_filtrado2->where('candidatos.municipio',$buscar_municipio);
        }
        if($buscar_zona != ''){
            $candidato_filtrado2->where('candidatos.zona',$buscar_zona);
        }
        if($buscar_area_experiencia != ''){
            $candidato_filtrado2->where('candidatos.area_experiencia','like','%'.$buscar_area_experiencia.'%');
        }
        if($buscar_experiencia_laboral_empresa != ''){
            $candidato_filtrado2->join('candidato_experiencias','candidatos.id','=','candidato_experiencias.candidato_id')->where('candidato_experiencias.empresa','like','%'.$buscar_experiencia_laboral_empresa.'%');
        }
        if($buscar_experiencia_laboral_puesto != ''){
            $candidato_filtrado2->join('candidato_experiencias','candidatos.id','=','candidato_experiencias.candidato_id')->where('candidato_experiencias.puesto','like','%'.$buscar_experiencia_laboral_puesto.'%');
        }
        if($buscar_experiencia_laboral_funciones != ''){
            $candidato_filtrado2->join('candidato_experiencias','candidatos.id','=','candidato_experiencias.candidato_id')->where('candidato_experiencias.funciones_principales','like','%'.$buscar_experiencia_laboral_funciones.'%');
        }
        if($buscar_estudios != '' ){
            $candidato_filtrado2->join('candidato_estudios','candidatos.id','=','candidato_estudios.candidato_id');
            if($buscar_estudios == 'universitarios'){
                $candidato_filtrado2->where('candidato_estudios.estudios_univeristarios',375);
            }if($buscar_estudios == 'diversificado'){
                $candidato_filtrado2->where('candidato_estudios.diversificado',375);
            }if($buscar_estudios == 'basicos'){
                $candidato_filtrado2->where('candidato_estudios.basicos',375);
            }if($buscar_estudios == 'primaria'){
                $candidato_filtrado2->where('candidato_estudios.primaria',375);
            }
        }
        if($buscar_carrera_tecnica != ''){
            $candidato_filtrado2->join('candidato_estudios','candidatos.id','=','candidato_estudios.candidato_id')->where('candidato_estudios.titulo_carrera_tecnica','like','%'.$buscar_carrera_tecnica.'%');
        }
        if($buscar_habilidades != '' ){
            $candidato_filtrado2->join('candidato_habilidades','candidatos.id','=','candidato_habilidades.candidato_id');
            if(in_array('mecanografia', $buscar_habilidades)){
                $candidato_filtrado2->where('candidato_habilidades.mecanografia',375);
            }if(in_array('taquigrafia', $buscar_habilidades)){
                $candidato_filtrado2->where('candidato_habilidades.taquigrafia',375);
            }if(in_array('archivo', $buscar_habilidades)){
                $candidato_filtrado2->where('candidato_habilidades.archivo',375);
            }if(in_array('computacion', $buscar_habilidades)){
                $candidato_filtrado2->where('candidato_habilidades.computacion',375);
            }if(in_array('reposteria', $buscar_habilidades)){
                $candidato_filtrado2->where('candidato_habilidades.reposteria',375);
            }if(in_array('cocina', $buscar_habilidades)){
                $candidato_filtrado2->where('candidato_habilidades.cocina',375);
            }if(in_array('enfermeria', $buscar_habilidades)){
                $candidato_filtrado2->where('candidato_habilidades.enfermeria',375);
            }if(in_array('programacion', $buscar_habilidades)){
                $candidato_filtrado2->where('candidato_habilidades.programacion',375);
            }if(in_array('internet', $buscar_habilidades)){
                $candidato_filtrado2->where('candidato_habilidades.internet',375);
            }
        }   
        if($buscar_otros_conocimientos_tecnicos != '' && $buscar_otros_conocimientos_tecnicos_especifique != ''){
            $candidato_filtrado2->join('candidato_habilidades','candidatos.id','=','candidato_habilidades.candidato_id');
            if($buscar_otros_conocimientos_tecnicos == 375){
                $candidato_filtrado2->where('candidato_habilidades.otros_conocimientos_tecnicos_especifique','!=',null);
            }
            if($buscar_otros_conocimientos_tecnicos == 376){
                $candidato_filtrado2->where('candidato_habilidades.otros_conocimientos_tecnicos_especifique',null);
            }
            if($buscar_otros_conocimientos_tecnicos_especifique != ''){
                $candidato_filtrado2->where('candidato_habilidades.otros_conocimientos_tecnicos_especifique','like','%'.$buscar_otros_conocimientos_tecnicos_especifique.'%');
            }
        }

        $anterior = $candidato_filtrado2->where('candidatos.id','<',$candidato->id)
                                ->latest('candidatos.id')
                                ->first();
 
        $otros1 = $candidato->otros()->count() == 0? 0:1;
        $experiencia1 = $candidato->experiencia()->count() == 0? 0:1;
        $referencia1 = $candidato->referencia()->count() == 0? 0:1;
        $estudios1 = $candidato->estudios()->count() == 0? 0:1;
        $habilidades1 = $candidato->habilidades()->count() == 0? 0:1;
        $fotografia = isset($candidato->fotografia)?1:0;
        $cv = isset($candidato->cv)?1:0;
        $fecha_nacimiento = $candidato->fecha_nacimiento?1:0;
        $dpi = $candidato->dpi?1:0;
        $igss = ( isset($candidato->igss) && $candidato->igss != null )?1:0;
        $direccion = $candidato->direccion?1:0;
        $pais = $candidato->pais?1:0;
        $departamento = $candidato->departamento?1:0;
        $municipio = $candidato->municipio?1:0;
        $zona = (isset($candidato->zona) || $candidato->zona != 0)?1:0;

        $total = $otros1 + $experiencia1 + $referencia1 + $estudios1 + $habilidades1 + $fotografia + $cv + $fecha_nacimiento + $dpi + $igss + $direccion + $pais + $departamento +
        $municipio + $zona;

        $porcentaje = intval(($total/15) * 100);

        return view('staff::reclutamiento.perfil_candidato')->with(compact('empleo_candidato','candidato','estudios','otros','experiencias','referencias', 'entrevista',
        'habilidades','porcentaje','siguiente','anterior','filtros'));
    }


    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function indexCandidatos(Empleo $empleo)
    {
        $usuario = Auth::user();

        if($usuario->hasRole('Reclutamiento')){
            $empleos = Empleo::orderBy('plaza','desc')->where('usuario_id',$usuario->id)->get();
        }else{
            $empleos = Empleo::orderBy('plaza','desc')->get();
        }
        
        return view('staff::reclutamiento.candidatos')->with(compact('empleo','empleos'));
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        return view('staff::create');
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show($id)
    {
        return view('staff::reclutamiento.perfil');
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
        return view('staff::edit');
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Response
     */
    public function destroy($id)
    {
        //
    }


    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function editEmpleo(Empleo $empleo)
    {
        $empresa = Auth::user()->empresa; 
        $competencias = Dropdown::where('parent_id',414)->get();
        $competencias_seleccionadas = Empleo::where('id',$empleo->id)->get()->pluck('competencias')->toArray();
        $competencias_seleccionadas = implode(',', $competencias_seleccionadas);
        $reclutadores = Usuario::selectRaw("concat(usuarios.nombre, ' ', usuarios.apellido) as nombre")
        ->addSelect('usuarios.id as id')
        ->join('model_has_roles','usuarios.id','=','model_has_roles.model_id')
        ->whereIn('model_has_roles.role_id', [4])->where('activo',1)->get();

        return view('staff::reclutamiento.empleos.edit')->with(compact('empresa','empleo','competencias','competencias_seleccionadas','reclutadores'));
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function updateEmpleo(EmpleoStoreRequest $request, Empleo $empleo)
    {
        //dd($request->all());
        $fecha_actual = Carbon::now();

        $data = $request->except('_method','_token','id','hacer_preguntas','imagen','competencias');
        if(!isset($request->hacer_preguntas)){
            $data += ['hacer_preguntas' => 0];
        }

        if(Auth::user()->hasRole('Admin')){
            $data += ['activo' => 1];
        }


        if(isset($request->imagen)){ 

            $validator = Validator::make($request->all(), [
                'imagen'         => 'max:2560',
            ]);
            if ($validator->fails()) {
                return redirect()->back()->with('alert_error', 'La imagen no puede pesar mas de 2.5MB');
            }  

            //dd($request->imagen);
            $extension = $request->imagen->extension();
            $filename = sha1(time().time()).".$extension";
            $request->imagen->move(public_path('storage/uploads/images'),$filename);
            $data += ['imagen' => $filename];

        }

        $competencias = $request->competencias;
        $competencias = implode(',', $competencias);
        $data += ['competencias' => $competencias];

        if(isset($request->usuario_id)){
            $data += ['fecha_asignacion' => $fecha_actual];
        }

        $empleo->update($data); 
        
        if(Auth::user()->hasRole('Admin')){
            return redirect()->route('staff.admin.index',$empleo->id)->with('alert_success','Empleo autorizado exitosamente');
        }

        return redirect()->route('staff.reclutamiento.index',$empleo->id)->with('alert_success','Empleo actualizado exitosamente');
    }

    public function plazasList(Request $request){  
        $usuario = Auth::user(); 
        $empleo = Empleo::selectRaw('empleos.*')
                  ->addSelect(DB::raw('DATE_FORMAT(empleos.created_at, "%d/%m/%Y") as fecha')) 
                  ->addSelect(DB::raw('DATE_FORMAT(empleos.fecha_asignacion, "%d/%m/%Y") as fecha_asignada'))
                  ->where('empleos.usuario_id',$usuario->id); 
        if ($request->estado_vacantes_reclutamiento == 'Vacantes asignadas'){
            $empleo = $empleo->leftJoin('empleo_candidatos','empleos.id','=','empleo_candidatos.empleo_id')->leftJoin('terna_candidatos','empleos.id','=','terna_candidatos.empleo_id')->where('terna_candidatos.fecha_terna','=',null)
            ->where('empleo_candidatos.fecha_cita','=',null);
        }else if ($request->estado_vacantes_reclutamiento == 'Vacantes contratadas'){
            $empleo = $empleo->leftJoin('empleo_candidatos','empleos.id','=','empleo_candidatos.empleo_id')->where('empleo_candidatos.contratado',1);
        }else if ($request->estado_vacantes_reclutamiento == 'Vacantes en proceso'){
            $empleo = $empleo->leftJoin('empleo_candidatos','empleos.id','=','empleo_candidatos.empleo_id')->leftJoin('terna_candidatos','empleos.id','=','terna_candidatos.empleo_id')->where('terna_candidatos.fecha_terna','!=',null)
            ->where('empleo_candidatos.fecha_cita','!=',null); 
        }else if ($request->estado_vacantes_reclutamiento == 'Vacantes de otras empresas'){
            $empleo = $empleo->where('empresa_id','!=',null);
        }             
        $empleo = $empleo->get(); 
        return DataTables::of($empleo)
        ->addColumn('candidatos', function($empleo){
            $candidatos = $empleo->candidatos()->count();
            $button = "<a class='btn btn-success text-white btn-block btn-sm border rounded' href='".route('staff.reclutamiento.indexCandidatos',$empleo->id)."'>$candidatos Candidatos</a>";  
            return $button;
        })
        ->addColumn('opciones', function($empleo){

            $empleo_candidatos = $empleo->empleoCandidato()->select(DB::raw("CONCAT(candidatos.nombre,' ',candidatos.apellido) as nombre, empleo_candidatos.candidato_id, empleo_candidatos.fecha_cita"))
            ->leftjoin('candidatos','empleo_candidatos.candidato_id','=','candidatos.id')->where('empleo_candidatos.aplica',1);

            if($empleo->terna()->count() != 0){
                $button = '<a class="btn btn-warning btn-block btn-sm border rounded" href="#" type="button"  data-toggle="modal" data-target="#terna-crear-'.$empleo->id.'">Añadir terna</a>
                <a class="btn btn-warning btn-block btn-sm border rounded" href="#" type="button"  data-toggle="modal" data-target="#terna-editar-'.$empleo->id.'">Editar terna</a>
                <a class="btn btn-warning btn-block btn-sm border rounded" href="#" type="button"  data-toggle="modal" data-target="#entrevista-reclutamiento-'.$empleo->id.'">Entrevista</a>
                <a class="btn btn-warning btn-block btn-sm border rounded" href="'.route('staff.reclutamiento.empleos.edit',$empleo->id).'">Editar empleo</a>';
            }else{
                $button = '<a class="btn btn-warning btn-block btn-sm border rounded" href="#" type="button"  data-toggle="modal" data-target="#terna-crear-'.$empleo->id.'">Añadir terna</a>
                <a class="btn btn-warning btn-block btn-sm border rounded" href="#" type="button"  data-toggle="modal" data-target="#entrevista-reclutamiento-'.$empleo->id.'">Entrevista</a>
                <a class="btn btn-warning btn-block btn-sm border rounded" href="'.route('staff.reclutamiento.empleos.edit',$empleo->id).'">Editar empleo</a>';
            }  
            $button .= view('staff::reclutamiento.terna_create', ['empleo' => $empleo, 'empleo_candidatos' => $empleo_candidatos])->render();
            $button .= view('staff::reclutamiento.entrevista_modal', ['empleo' => $empleo, 'empleo_candidatos' => $empleo_candidatos])->render();
            $button .= view('staff::reclutamiento.terna_edit', ['empleo' => $empleo, 'empleo_candidatos' => $empleo_candidatos])->render();
            //<a class="btn btn-warning btn-block btn-sm border rounded" href="#" type="button" data-toggle="modal" data-target="#terna-empleo-'.$empleo->id.'">Terna enviada</a>   

            return $button;
        })
        ->addColumn('sueldo', function($empleo){
            $sueldo = number_format($empleo->sueldo,2);
            $button = "<span>Q$sueldo</span><span></span>"; 
            return $button;
        })
        ->addColumn('dias_restantes', function($empleo){
            $fecha_actual = Carbon::now();

            $fecha_asignacion = New Carbon ($empleo->fecha_asignacion);
            
            $empleo_candidatos = $empleo->empleoCandidato()->first();

            if($empleo_candidatos && $empleo_candidatos->fecha_contratacion){

                $fecha_contratacion = New Carbon ($empleo_candidatos->fecha_contratacion);

                $dias = $fecha_contratacion->diffInDays($fecha_asignacion);

            }else{

                $dias = $empleo->fecha_asignacion?$fecha_asignacion->diffInDays($fecha_actual):0;

            }
            /*if($dias == 0){
                $dias = '';
            }else{
                $dias = 10 - $dias;
                if($dias < 0){
                    $dias = '0 días';
                }else{
                    $dias = $dias.' días';
                }
            }*/  
            $button = "<span>-$dias</span>";
            return $button;
        })
        ->addColumn('terna', function($empleo){
            $terna = '';
            $fecha_actual = Carbon::now();
            $fecha_asignacion = New Carbon ($empleo->fecha_asignacion);
            $dias = $empleo->fecha_asignacion?$fecha_asignacion->diffInDays($fecha_actual):0;
            if($dias >= 1 && $dias <= 10){
                //$terna = '<div class="circulo active"></div>Plazo vigente<br>'.$empleo->fecha_asignacion->format('d-m-Y');
                $terna = '<div class="circulo active"></div>Plazo vigente '.$empleo->fecha_asignacion->format('d-m-Y');
            }else if($dias >= 11 && $dias <= 15){
                //$terna = '<div class="circulo warning"></div>Plazo intermedio<br>'.$empleo->fecha_asignacion->format('d-m-Y');
                $terna = '<div class="circulo warning"></div>Plazo intermedio '.$empleo->fecha_asignacion->format('d-m-Y');
            }else if($dias > 15){
                //$terna = '<div class="circulo danger"></div>Plazo vencido<br>'.$empleo->fecha_asignacion->format('d-m-Y');
                $terna = '<div class="circulo danger"></div>Plazo vencido '.$empleo->fecha_asignacion->format('d-m-Y');
            }            
            $button = $terna; 
            return $button;
        })
        ->addColumn('fecha_entrevista', function($empleo){
            $empleo_candidatos = EmpleoCandidato::where('empleo_id',$empleo->id);

            $fecha_entrevista = '';

            foreach($empleo_candidatos->get() as $empleo_candidato){
            
                $fecha_entrevista = $empleo_candidato->fecha_cita;

            }

            $button = $fecha_entrevista?$fecha_entrevista->format('d/m/Y'):'';
            
            return $button;
        })
        ->addColumn('fecha_contratado', function($empleo){
            $empleo_candidatos = $empleo->empleoCandidato()->addSelect(DB::raw('DATE_FORMAT(empleo_candidatos.fecha_contratacion, "%d/%m/%Y") as fecha_contratado'));

            $fecha_contratacion = '';

            foreach($empleo_candidatos->get() as $empleo_candidato){

                $fecha_contratacion .= ' '.$empleo_candidato->fecha_contratado;

            }

            $button = strip_tags($fecha_contratacion);
            
            return $button;
        })
        ->rawColumns(['opciones','candidatos','sueldo','dias_restantes','terna','fecha_entrevista','fecha_contratado'])
        ->make(true);
    }

    public function plazasReclutamientoList(Request $request){

        $usuario = Auth::user();
        $candidato_id = $request->get('candidato_id');

        $empleos_aplicados = EmpleoCandidato::selectRaw('empleo_candidatos.*')
        ->leftJoin('empleos','empleo_candidatos.empleo_id','=','empleos.id')
        ->where('empleo_candidatos.candidato_id',$candidato_id)->get()->pluck('empleo_id')->toArray();          

        $empleo = Empleo::selectRaw('empleos.*')->whereNotIn('empleos.id',$empleos_aplicados);

        if(Auth::user()->hasRole('Empresa')){
            $empleo->where('empresa_id',$usuario->empresa->id);
        }

        $empleo = $empleo->get(); 
        return DataTables::of($empleo)
        ->addColumn('action', function($empleo) use($candidato_id){

            $button = "<a class='btn btn-success text-white btn-block btn-sm border rounded' href='".route('public.empleos.aplicar',['empleo_id' => $empleo->id, 'candidato_id' => $candidato_id])."'>Enviar</a>";  

            return $button;
        })
        ->rawColumns(['action'])
        ->make(true);
    }

    public function candidatosList(Request $request){ 
        //dd($request->all());
        $usuario = Auth::user();
        $candidatos = Candidato::selectRaw('candidatos.*')
                                ->join('empleo_candidatos','candidatos.id','=','empleo_candidatos.candidato_id')
                                ->whereIn('empleo_candidatos.contratado',[0,1])
                                ->addSelect('empleo_candidatos.fecha_cita as fecha_cita_candidato')
                                ->addSelect('empleo_candidatos.hora_cita as hora_cita_candidato')
                                ->addSelect('empleo_candidatos.direccion_cita as direccion_cita_candidato')
                                ->addSelect('empleo_candidatos.persona_entrevista_cita as persona_entrevista_cita_candidato')
                                ->addSelect('empleo_candidatos.interpretacion_resultados as interpretacion_resultados')
                                ->addSelect('empleo_candidatos.verificacion_datos as verificacion_datos')
                                ->addSelect('empleo_candidatos.contratado as contratado')
                                ->addSelect('empleo_candidatos.aplica as aplica')
                                ->addSelect('empleo_candidatos.fecha_generacion_informe');
        $empleo = $request->empleo;
        $puesto  = $request->puesto;
        if(isset($request->empleo)){
            //$candidatos = $candidatos->where('empleo_candidatos.empleo_id',$request->empleo);
            $candidatos = $candidatos->addSelect('empleo_candidatos.id as empleo_candidatos_id')->where('empleo_candidatos.empleo_id',$request->empleo);
        }
        if(isset($request->aplica)){
            $candidatos = $candidatos->whereIn('empleo_candidatos.aplica',[1,2]);
        }/*else{
            $candidatos = $candidatos->where('empleo_candidatos.aplica',0);
        }*/
        if(isset($request->check_descartados)){
            $candidatos = $candidatos->where('empleo_candidatos.aplica',2);
        }
        if(isset($request->check_contratados)){
            $candidatos = $candidatos->where('empleo_candidatos.contratado',1);
        }
        if(isset($request->check_en_proceso)){
            $candidatos = $candidatos->where('empleo_candidatos.contratado',0)->where('empleo_candidatos.aplica',1);
        }
        $candidatos = $candidatos->get();
        return DataTables::of($candidatos)
        ->addColumn('candidato_info', function($candidato) use($usuario){ 
            $check_informe = $candidato->fecha_generacion_informe?'border-10':'';
            $edad = $candidato->fecha_nacimiento?$candidato->fecha_nacimiento->age.' años':'';
            $fotografia = $candidato->fotografia?asset('storage/uploads/images/'.$candidato->fotografia):asset('img/imagen-vacia.jpg');
            $button = "
            <div class='row no-gutters align-items-center'>
                <div class='col-4'><img src='".$fotografia."' class='img img-fluid $check_informe'></div>
                <div class='col-7'>
                <a href='".route('staff.reclutamiento.perfil.candidato',$candidato->empleo_candidatos_id)."'> <h5>$candidato->nombre_completo</h5> </a> <span>$edad </span><span>No. $candidato->id</span><span>Tel. $candidato->telefono_fijo / $candidato->telefono_celular</span></div>
            </div>";
            return $button;
        })
        ->addColumn('opciones', function($candidato) use($empleo){
            $button = '
            <div class="row no-gutters py-1">
                <div class="col-12 col-lg-6 px-1"><a class="btn btn-warning btn-block border rounded-0" href="'.route('staff.reclutamiento.perfil.candidato',$candidato->empleo_candidatos_id).'" type="button">Ver Perfil</a></div>  
                <div class="col-12 col-lg-6 px-1"><a class="btn btn-secondary btn-block border rounded-0" type="button" href="#" data-toggle="modal" data-target="#video'.$candidato->id.'candidato">Ver Video</a></div> 
            </div> 
            <div class="row no-gutters py-1">
                <div class="col-12 col-lg-6 px-1"><a class="btn btn-primary btn-block border rounded-0" href="javascript:aplica('.$candidato->id.','.$empleo.',1);"><i class="fas fa-circle text-success"></i>&nbsp;Aplica</a></div>
                <div class="col-12 col-lg-6 px-1"><a class="btn btn-primary btn-block border rounded-0" type="button" href="#" data-toggle="modal" data-target="#noAplica-destroy-'.$candidato->empleo_candidatos_id.'"><i class="fas fa-circle text-danger"></i>&nbsp;No Aplica</a></div>
            </div>'; 
            $html = view('staff::reclutamiento.video_candidato_modal', compact('candidato'))->render();
            $html .= view('empresas::perfil.noAplica', compact('candidato'))->render();
            return $button.$html;
        })
        ->addColumn('opciones2', function($candidato) { 

            if($candidato->pruebas){

                $empleo_candidato = EmpleoCandidato::select('empleo_candidatos.*')
                                                    ->addSelect('empleos.empresa as empresa')
                                                    ->addSelect('empleos.plaza as plaza')
                                                    ->join('empleos','empleo_candidatos.empleo_id','=','empleos.id')
                                                    ->where('empleo_candidatos.id',$candidato->empleo_candidatos_id)->first();

                if($candidato->aplica == 2){
                    $button = '
                    <div class="row no-gutters py-1"> 
                        <div class="col-12 col-lg-6 px-1"><a class="btn btn-default btn-block border rounded-0" style="background:gray;" type="button">Informe Plus</a></div>
                        <div class="col-12 col-lg-6 px-1"><a class="btn btn-default btn-block border rounded-0" style="background:gray;" type="button">Standard</a></div>  
                    </div>
                    <div class="row no-gutters py-1">
                        <div class="col-12 col-lg-12 px-1"><a class="opc" style="text-decoration:none;" type="button">&nbsp;Contratado</a></div>
                    </div>'; 
                }else{
                    if($candidato->interpretacion_informe != '' && $candidato->verificacion_informe != '' && $candidato->pruebas){
                    $button =  
                    "<div>
                        <div class='row no-gutters py-1'>               
                            <a class='btn btn-success btn-block btn-sm border rounded' target='_blank' href='".route('staff.reclutamiento.informe.plus',$candidato->empleo_candidatos_id)."'><small>GENERAR INFORME PLUS</small></a> 
                        </div>
                    </div>";
                    }else{
                    $button = 
                    '<div>
                        <div class="row no-gutters py-1">               
                            <a class="btn btn-danger btn-block btn-sm border rounded"><small>FALTAN DATOS DEL INFORME</small></a> 
                        </div>
                    </div>'; 
                    }
                    $button .=
                    '<div class="row no-gutters py-1">  
                        <div class="col-12 col-lg-6 px-1"><a class="btn btn-success btn-block border rounded-0" href="'.route('staff.reclutamiento.index').'#generar-informe-plus">Plus</a></div>
                        <div class="col-12 col-lg-6 px-1"><a class="btn btn-success btn-block border rounded-0" target="_blank" href="'.route('staff.reclutamiento.informe.standar',$candidato->empleo_candidatos_id).'" type="button">Standard</a></div>
                    </div>
                    <div class="row no-gutters py-1">
                        <a class="btn btn-warning btn-block btn-sm border rounded" href="#" type="button"  data-toggle="modal" data-target="#contratado-reclutamiento-'.$candidato->empleo_candidatos_id.'">Contratado</a>
                    </div>';
                    //<div class="col-12 col-lg-12 px-1"><a class="opc" type="button" href="'.route('staff.reclutamiento.contratado',$candidato->empleo_candidatos_id).'">&nbsp;Contratado</a></div>
                    
        
                    $button .= view('empresas::admin.empresas.empleocandidato-destroy',['candidato' => $candidato])->render();
                    $button .= view('staff::reclutamiento.subir_informe_modal',['candidato' => $candidato])->render();
                    $button .= view('staff::reclutamiento.contratado_modal', ['candidato' => $candidato, 'empleo_candidato' => $empleo_candidato])->render();
                }

                return $button;

            }else{

                $button = '
                <div class="row no-gutters py-1"> 
                    <div class="col-12 col-lg-12 px-1"><button class="btn btn-success btn-block border rounded-0" style="background:gray;">No ha realizado las pruebas</button></div>
                </div>';

                return $button;
            }
        })
        ->addColumn('opciones3', function($candidato) use($empleo){
            $vacante = Empleo::where('id',$empleo)->first();
            $empresa = Empresa::where('id',$vacante->empresa_id)->first();
            if($candidato->aplica == 2){
                $button = '
                <div class="row no-gutters py-1">
                    <div class="col-12 col-lg-12 px-1"><a class="btn btn-default btn-block border rounded-0" style="background:gray;" type="button">Programar Cita</a></div> 
                </div>
                <div class="row no-gutters py-1">
                    <div class="col-12 col-lg-12 px-1"><a class="opc opc-inactivo" type="button"><i class="fas fa-circle"></i>&nbsp;Descartado</a></div>  
                </div>'; 
            }else{
                $button = '
                <div class="row no-gutters py-1">
                    <div class="col-12 col-lg-12 px-1"><a class="btn btn-warning btn-block border rounded-0" data-toggle="modal" data-target="#exampleModalCita-'.$candidato->empleo_candidatos_id.'" type="button">Programar Cita</a></div> 
                </div>
                <div class="row no-gutters py-1">
                    <div class="col-12 col-lg-12 px-1"><a class="opc opc-inactivo" type="button" data-toggle="modal" data-target="#noAplica-destroy-'.$candidato->empleo_candidatos_id.'"><i class="fas fa-circle"></i>&nbsp;Descartado</a></div>  
                </div>'; 
                $button .= view('empresas::admin.empresas.empleocandidato-destroy',['candidato' => $candidato])->render(); 
                $button .= view('empresas::perfil.programar-cita',['candidato' => $candidato, 'vacante' => $vacante, 'empresa' => $empresa])->render();
            }
            return $button;
        })
        ->addColumn('opciones4', function($candidato) use($usuario){ 

            $empresa = Empresa::where('usuario_id',$usuario->id)->first();

            $empleo_candidato = EmpleoCandidato::select('empleo_candidatos.*')
                                                ->addSelect('empleos.empresa as empresa')
                                                ->addSelect('empleos.plaza as plaza')
                                                ->join('empleos','empleo_candidatos.empleo_id','=','empleos.id')
                                                ->where('empleo_candidatos.id',$candidato->empleo_candidatos_id)->first();

            if($candidato->aplica == 2){

                $button = '
                <div class="row no-gutters py-1"> 
                    <div class="col-12 col-lg-6 px-1"><a class="btn btn-default btn-block border rounded-0" style="background:gray;" type="button">Informe Plus</a></div>
                    <div class="col-12 col-lg-6 px-1"><a class="btn btn-default btn-block border rounded-0" style="background:gray;" type="button">Standard</a></div>  
                </div>
                <div class="row no-gutters py-1">
                    <div class="col-12 col-lg-12 px-1"><a class="opc" style="text-decoration:none;" type="button">&nbsp;Contratado</a></div>
                </div>'; 

            }else{

                if($candidato->archivo_informe){
                    $button =
                    '<div>
                        <div class="row no-gutters py-1">              
                            <a class="btn btn-success btn-block btn-sm border rounded" target="_blank" href="'.asset('storage/uploads/informes_candidatos/'.$candidato->archivo_informe).'"><small>DESCARGAR INFORME PLUS</small></a> 
                        </div>
                    </div>
                    <div class="row no-gutters py-1"> 
                        <div class="col-12 col-lg-6 px-1"><a class="btn btn-success btn-block border rounded-0" target="_blank" href="#" data-toggle="modal" data-target="#exampleModalInforme-'.$candidato->empleo_candidatos_id.'" type="button">Informe Plus</a></div>
                        <div class="col-12 col-lg-6 px-1"><a class="btn btn-success btn-block border rounded-0" htarget="_blank" href="#" data-toggle="modal" data-target="#exampleModalInforme-'.$candidato->empleo_candidatos_id.'" type="button">Standard</a></div>  
                    </div>
                    <div class="row no-gutters py-1">
                        <a class="btn btn-warning btn-block btn-sm border rounded" href="#" type="button"  data-toggle="modal" data-target="#contratado-reclutamiento-'.$candidato->empleo_candidatos_id.'">Contratado</a>
                    </div>';
                    $button .= view('empresas::perfil.detalles-informes',['candidato' => $candidato])->with(compact('empresa'))->render();
                    $button .= view('staff::reclutamiento.contratado_modal', ['candidato' => $candidato, 'empleo_candidato' => $empleo_candidato])->render();
                }else{
                    $button = '
                    <div class="row no-gutters py-1"> 
                        <div class="col-12 col-lg-6 px-1"><a class="btn btn-success btn-block border rounded-0" target="_blank" href="#" data-toggle="modal" data-target="#exampleModalInforme-'.$candidato->empleo_candidatos_id.'" type="button">Informe Plus</a></div>
                        <div class="col-12 col-lg-6 px-1"><a class="btn btn-success btn-block border rounded-0" htarget="_blank" href="#" data-toggle="modal" data-target="#exampleModalInforme-'.$candidato->empleo_candidatos_id.'" type="button">Standard</a></div>  
                    </div>
                    <div class="row no-gutters py-1">
                        <a class="btn btn-warning btn-block btn-sm border rounded" href="#" type="button"  data-toggle="modal" data-target="#contratado-reclutamiento-'.$candidato->empleo_candidatos_id.'">Contratado</a>
                    </div>'; 
                    $button .= view('empresas::perfil.detalles-informes',['candidato' => $candidato])->with(compact('empresa'))->render();
                    $button .= view('staff::reclutamiento.contratado_modal', ['candidato' => $candidato, 'empleo_candidato' => $empleo_candidato])->render();
                }
                
            }

            return $button;
        })
        ->addColumn('proceso', function($candidato) use($usuario){
            $entrevista = $candidato->entrevista()->count() == 0? 0:1;
            $pruebas = $candidato->pruebas()->first(); 
            $a = '';
            if(isset($pruebas)){
                $prueba_resultado = PruebaResultado::where('prueba_candidato_id',$pruebas->id)->get();
                if($prueba_resultado->count() >= 3){
                    $a = 3;
                }
            }else{
                $a = 0;
            }
                     
            $button = '
                <ul>
                    <li><span class="indi-color active"></span><span class="indi-text">Aplica</span></li> 
                </ul>'; 
            if($a == 3){ 
                $button .= '
                <ul>
                    <li><span class="indi-color active"></span><span class="indi-text">Pruebas</span></li> 
                </ul>'; 
            } else{
                $button .= '
                <ul>
                    <li><span class="indi-color inactive"></span><span class="indi-text">Pruebas</span></li> 
                </ul>'; 
                }
            if($entrevista == 1){ 
                $button .= '
                <ul>
                    <li><span class="indi-color active"></span><span class="indi-text">Entrevista</span></li> 
                </ul>'; 
            } else{
                $button .= '
                <ul>
                    <li><span class="indi-color inactive"></span><span class="indi-text">Entrevista</span></li> 
                </ul>'; 
                }  
            if(isset($candidato->fecha_cita_candidato)){ 
                $button .= '
                <ul>
                    <li><span class="indi-color active"></span><span class="indi-text">Cita</span></li> 
                </ul>'; 
            } else{
                $button .= '
                <ul>
                    <li><span class="indi-color inactive"></span><span class="indi-text">Cita</span></li> 
                </ul>'; 
                }  
            if($candidato->contratado == 1){ 
                $button .= '
                <ul>
                    <li><span class="indi-color active"></span><span class="indi-text">Contratado</span></li> 
                </ul>'; 
            }else{
                $button .= '
                <ul>
                    <li><span class="indi-color inactive"></span><span class="indi-text">Contratado</span></li>  
                </ul>'; 
                }
            return $button;
        })
        ->addColumn('pretension_salarial', function($candidato) use($usuario){
            $pretension_salarial = number_format($candidato->pretension_salarial,2);
            $button = "<span>Q$pretension_salarial</span><span></span>"; 
            return $button;
        })
        ->rawColumns(['opciones','candidato_info','pretension_salarial','proceso','opciones2','opciones3','opciones4'])
        ->make(true);
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function aplica(Request $request) 
    {
        //dd($request->all());
        $candidato_empleo = EmpleoCandidato::where('candidato_id',$request->candidato_id)->where('empleo_id',$request->empleo_id)->first();
        $candidato_empleo->update(['aplica' => $request->aplica]);
        return response()->json(['status' => true, 'msj' => 'Se ha notificado al candidato correctamente.']);  
    }

    public function aplicaPruebas(Request $request)
    {
        //$empleocandidato = EmpleoCandidato::where('candidato_id',$request->candidato_id)->where('empleo_id',$request->empleo_id)->first();
        $candidato = Candidato::where('id',$request->candidato_id)->first();
        $candidato->update(['estado_pruebas' => $request->aplica]);

        $empleo = Empleo::where('id',$request->empleo_id);
        $empleo = $empleo->first();

        if($candidato->estado_pruebas == 1 ){
        Mail::to($candidato->email)->send(new PruebasEmail($candidato, $empleo));
        }

        return response()->json(['status' => true, 'msj' => 'Se han activado las pruebas para el candidato']);
        //return redirect()->back()->with('alert_success','Se han activado las pruebas para el candidato');
        //return redirect()->route('staff.reclutamiento.perfil.candidato',$empleocandidato)->with('alert_success', 'Se han activado las pruebas para el candidato');
    }

    public function aplicaEntrevista(Request $request)
    {
        $candidato = Candidato::where('id',$request->candidato_id)->first();
        $candidato->update(['estado_entrevista' => $request->aplica]);
        return response()->json(['status' => true, 'msj' => 'Se ha activado la entrevista para el candidato']);
    }

    public function subirInforme(InformeRequest $request, Candidato $candidato) 
    {

        $validator = Validator::make($request->all(), [
            'archivo_informe'  => 'max:2560', 
        ]);
        if ($validator->fails()) {
            return redirect()->back()->with('alert_error', 'El archivo no puede pesar mas de 2.5MB');
        }

        $extension = $request->archivo_informe->extension();
        $filename = sha1(time().time()).".$extension";
        $request->archivo_informe->move(public_path('storage/uploads/informes_candidatos'),$filename);
        $candidato->update(['archivo_informe' => $filename]); 

        return redirect()->back()->with('alert_success', 'El informe ha sido cargado exitosamente.');
        
    } 

    public function getCandidatoNombre(Request $request)
    {
        $candidato = Candidato::find($request->candidato_id);

        echo "{\"candidato_nombre\":\"$candidato->nombre_completo\"}";
        die();
    }

}
