<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::prefix('staff')->group(function() {

    Route::get('/habilitar',                                 'StaffController@habilitar')->name('public.empleos.habilitar');
    Route::get('informe/plus/{empleocandidato}/generar',     'InformeController@generarGrafica')->name('staff.reclutamiento.informe.generar');
    Route::post('informe/plus/{empleocandidato}/guardar',    'InformeController@guardarGrafica')->name('staff.reclutamiento.informe.guardar');
    
    Route::middleware(['auth:acceso','role:Reclutamiento|Empresa|Admin|Base de datos'])->prefix('reclutamiento')->group(function()
    {
        Route::get('plazas/listar',                      'ReclutamientoController@plazasList')->name('staff.reclutamiento.plazas.list');
        Route::get('plazas/reclutamiento/listar',        'ReclutamientoController@plazasReclutamientoList')->name('staff.plazas.list');  
        Route::get('candidatos/listar',                  'ReclutamientoController@candidatosList')->name('staff.reclutamiento.candidatos.list'); 
        Route::get('candidatos/aplica',                  'ReclutamientoController@aplica')->name('staff.reclutamiento.candidatos.aplica'); 
        Route::get('candidatos/aplica_pruebas',          'ReclutamientoController@aplicaPruebas')->name('staff.reclutamiento.candidatos.aplica.pruebas'); 
        Route::get('candidatos/aplica_entrevista',       'ReclutamientoController@aplicaEntrevista')->name('staff.reclutamiento.candidatos.aplica.entrevista'); 
        Route::get('',                                   'ReclutamientoController@index')->name('staff.reclutamiento.index');  
        Route::get('candidatos/{empleo}',                'ReclutamientoController@indexCandidatos')->name('staff.reclutamiento.indexCandidatos');
        Route::get('perfil',                             'ReclutamientoController@show')->name('staff.reclutamiento.perfil');
        Route::get('perfil/{empleocandidato}',           'ReclutamientoController@showCandidato')->name('staff.reclutamiento.perfil.candidato');
        Route::get('empleos/editar/{empleo}',            'ReclutamientoController@editEmpleo')->name('staff.reclutamiento.empleos.edit');
        Route::patch('empleos/actualizar/{empleo}',      'ReclutamientoController@updateEmpleo')->name('staff.reclutamiento.empleos.update');
        Route::get('informe/plus/{empleocandidato}/web', 'InformeController@indexInformePlusWeb')->name('staff.reclutamiento.informe.plus.web');
        Route::get('informe/plus/{empleocandidato}',     'InformeController@indexInformePlus')->name('staff.reclutamiento.informe.plus');
        Route::get('informe/standar/{empleocandidato}',  'InformeController@indexInformeStandar')->name('staff.reclutamiento.informe.standar');
        Route::get('informe/inicial/{empleocandidato}',  'InformeController@indexInformeInicial')->name('staff.reclutamiento.informe.inicial');
        Route::get('cita/{empleocandidato}',             'InformeController@programarCita')->name('staff.reclutamiento.programar_cita');
        //Route::get('contratado/{empleocandidato}',       'InformeController@contratado')->name('staff.reclutamiento.contratado'); 
        Route::get('video/{empleocandidato}',            'InformeController@video')->name('staff.reclutamiento.video');
        Route::patch('informe/subir/{candidato}',        'ReclutamientoController@subirInforme')->name('staff.reclutamiento.subirInforme');
        //Route::get('informe/reclutador',                 'StaffController@getIndicadoresReclutamiento')->name('staff.reclutamiento.indicadores');
    });

    Route::middleware(['auth:acceso','role:Admin|Ventas|Base de datos'])->group(function()
    {
        Route::get('administrador',                                                      'StaffController@index')->name('staff.admin.index');
        Route::get('administrador/listar',                                               'StaffController@vacantesList')->name('staff.reclutamiento.list'); 
        Route::get('administrador/cotizaciones',                                         'StaffController@cotizacionesAdminList')->name('staff.cotizaciones.list'); 
        Route::get('vacante/perfil',                                                     'StaffController@vacanteperfil')->name('staff.perfil.index');
        Route::post('usuarios/crear',                                                    'StaffController@storeStaffAdministrador')->name('staff.usuarios.create');
        Route::patch('vendedor/asignar/{servicio}',                                      'StaffController@storeVendedor')->name('staff.vendedores.create');
        Route::get('empleos/editar/{empleo}',                                            'ReclutamientoController@editEmpleo')->name('staff.admin.empleos.edit');
        Route::post('blog/crear',                                                        'StaffController@storeBlog')->name('staff.blog.create');
        Route::delete('blog/eliminar/{blog}',                                            'StaffController@destroyBlog')->name('staff.blog.destroy');
        Route::get('blog/{blog}/editar',                                                 'StaffController@editBlog')->name('staff.blog.edit');
        Route::patch('blog/{blog}',                                                      'StaffController@updateBlog')->name('staff.blog.update');
        Route::get('blog',                                                               'StaffController@indexBlog')->name('staff.blog.index');
        Route::delete('cotizacion/eliminar/{servicio}',                                  'StaffController@destroyCotizacion')->name('staff.cotizacion.destroy');
        Route::get('candidatos/listar',                                                  'StaffController@candidatosAdminList')->name('staff.candidatos.list');
        Route::get('perfil/{candidato}',                                                 'StaffController@showCandidatoAdmin')->name('staff.admin.perfil.candidato');
        Route::get('administrador/empresas',                                             'StaffController@empresasAdminList')->name('staff.empresas.list');
        Route::post('administrador/facturacion_informes/crear',                          'StaffController@facturacionInformes')->name('staff.facturacion_informes.store');
        Route::patch('administrador/facturacion_informes/{serviciofacturacion}/editar',  'StaffController@facturacionInformesUpdate')->name('staff.facturacion_informes.update');
        Route::post('indicadores/reclutamiento/obtener',                                 'StaffController@indicadoresReclutamiento')->name('staff.indicadores.reclutamiento');
        Route::post('indicadores/vendedor/obtener',                                      'StaffController@indicadoresVendedor')->name('staff.indicadores.vendedor');
        Route::post('indicadores/generales/obtener',                                     'StaffController@indicadoresGenerales')->name('staff.indicadores.generales');
    });

    Route::middleware(['auth:acceso','role:Admin|Reclutamiento|Ventas'])->prefix('reportes')->group(function()
    {
        Route::get('vacantes_asignadas/descargar',                         'StaffController@reporteVacantesAsignadas')->name('staff.admin.vacantesAsignadas');
        Route::get('vacantes_revision/descargar',                          'StaffController@reporteVacantesRevision')->name('staff.admin.vacantesRevision');
        Route::get('vacantes_proceso/descargar',                           'StaffController@reporteVacantesProceso')->name('staff.admin.vacantesProceso');
        Route::get('vacantes_publicadas/descargar',                        'StaffController@reporteVacantesPublicadas')->name('staff.admin.vacantesPublicadas');
        Route::get('cotizaciones_enviadas/descargar',                      'StaffController@reporteCotizacionesEnviadas')->name('staff.admin.CotizacionesEnviadas');
        Route::get('cotizaciones_aprobadas/descargar',                     'StaffController@reporteCotizacionesAprobadas')->name('staff.admin.CotizacionesAprobadas');
        Route::get('cotizaciones_rechazadas/descargar',                    'StaffController@reporteCotizacionesRechazadas')->name('staff.admin.CotizacionesRechazadas');
        Route::get('contrataciones/descargar',                             'StaffController@reporteContrataciones')->name('staff.admin.Contrataciones');
        Route::get('informes_solicitados/descargar',                       'StaffController@reporteInformesSolicitados')->name('staff.admin.InformesSolicitados');
        Route::get('informes_terminados/descargar',                        'StaffController@reporteInformesTerminados')->name('staff.admin.InformesTerminados');
        Route::get('contrataciones_ventas/descargar',                      'StaffController@reporteContrataciones_ventas')->name('staff.admin.Contrataciones_ventas');
        Route::get('vacantes_publicadas',                                  'StaffController@vacantesPublicadasList')->name('staff.vacantes_publicadas.list');
        Route::get('informes_solicitados',                                 'StaffController@informesSolicitados')->name('staff.informes_solicitados.list');
        Route::get('monto_facturado',                                      'StaffController@reporteMontoFacturado')->name('staff.admin.montoFacturado');
        Route::post('terna_enviada/crear',                                 'StaffController@storeTerna')->name('staff.reclutamiento.terna.store');
        Route::patch('terna_enviada/editar/{terna_candidatos}',            'StaffController@updateTerna')->name('staff.reclutamiento.terna.update');
        Route::post('indicadores/staff_reclutamiento/obtener',             'ReclutamientoController@indicadoresStaffReclutamiento')->name('indicadores.staff.reclutamiento');
        Route::post('indicadores/staff_vendedor/obtener',                  'StaffController@indicadoresStaffVendedor')->name('indicadores.staff.vendedor');
        Route::post('candidato_nombre/obtener',                            'ReclutamientoController@getCandidatoNombre') ->name('staff.reclutamiento.terna.candidatoNombre.obtener');
    });

    Route::middleware(['auth:acceso','role:Ventas'])->group(function()
    {
        Route::get('ventas',                        'StaffController@ventasindex')->name('staff.ventas.index');
        //Route::get('ventas/cotizaciones',          'StaffController@cotizacionesVentasList')->name('ventas.cotizaciones.list'); 
        Route::get('ventas/ficha',                  'StaffController@cotizacionesForm')->name('ventas.cotizacionesform.list');
        Route::get('ventas/seguimiento',            'StaffController@seguimientoVentasList')->name('ventas.seguimiento.list'); 
        Route::patch('ventas/{servicio}',           'StaffController@citaupdate')->name('ventas.cita.update');
        Route::patch('ventas/contrato/{servicio}',  'StaffController@cierreContratoUpdate')->name('ventas.contrato.update');
        //Route::patch('ventas/{garantia}',         'StaffController@garantiaupdate')->name('ventas.garantia.update');
    });

    Route::get('informe/',                          'InformeController@createPDF')->name('informe.pdf.imprimir');

    Route::middleware(['auth:acceso','role:Base de datos'])->prefix('database')->group(function()
    { 
        Route::get('',                        'StaffController@databaseindex')->name('staff.database.index'); 
        Route::get('database_table',          'StaffController@databaseTable')->name('staff.database.datatable');
        Route::get('perfil/{candidato}',      'ReclutamientoController@showCandidatoDatabase')->name('staff.database.perfil.candidato');  
    });
});
