<?php

namespace Modules\Usuarios\Entities;

use Illuminate\Contracts\Auth\MustVerifyEmail;
use Carbon\Carbon;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Modules\Usuarios\Notifications\ResetPasswordNotification;
use Spatie\Permission\Traits\HasRoles;

class Usuario extends Authenticatable
{
    use Notifiable;
    use HasRoles;
    protected $guard_name = 'acceso';
    protected $table = 'usuarios';
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'nombre', 
        'apellido', 
        'email', 
        'password',
        'activo',
        'descripcion',
        'logged_at',
        'email_verified_at',
        'fecha_inicio_labores',
        'jefe_inmediato',
        'dpi',
        'fotografia'
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'activo' => 'boolean'
    ];

    /**
     * The attributes that should be mutated to dates.
     *
     * @var array
     */
    protected $dates = [
        'created_at',
        'updated_at',
        'logged_at',
        'approval_at',
        'email_verified_at',
        'fecha_inicio_labores'
    ];

    /**
     * Hash the password given
     *
     * @param string $password
     */
    public function setPasswordAttribute($password)
    {
        $this->attributes['password'] = bcrypt($password);
    }

    public function getNombreCompletoAttribute()
    {
        return $this->nombre . ' ' . $this->apellido;
    }
    /**
     * Send the password reset notification.
     *
     * @param  string  $token
     * @return void
     */
    public function sendPasswordResetNotification($token)
    {
        $this->notify(new ResetPasswordNotification($token));
    }

    public function candidato()
    {
        return $this->hasOne(\Modules\Candidatos\Entities\Candidato::class,'usuario_id','id');
    }

    public function empresa()
    {
        return $this->hasOne(\Modules\Empresas\Entities\Empresa::class,'usuario_id','id');
    }

    // this is a recommended way to declare event handlers
    public static function boot() {
        parent::boot();

        static::deleting(function($usuario) { 
             $usuario->candidato()->delete();
             $usuario->empresa()->delete();
        });
    }
}
