<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Carbon\Carbon;
use Modules\Candidatos\Entities\Candidato;
use Modules\Candidatos\Emails\BoletinBajasEmail;
use Illuminate\Support\Facades\Mail;

class BoletinBajas extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'boletin:bajas';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Comando para enviar un correo mensual con el listado de los candidatos que se dieron de baja al boletín semanal de vacantes.';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $candidatos = Candidato::whereMonth(
            'fecha_baja_boletin', '=', Carbon::now()->subMonth()->month
        )->get();

        Mail::to(getDropdownValue('618'))->send(new BoletinBajasEmail($candidatos));

        foreach($candidatos as $candidato){
            $this->info(date('Y-m-d H:i:s').' Info bajas boletin del mes: Id:'.$candidato->id." Nombre: ".$candidato->nombre_completo." Fecha de baja: ".
            $candidato->fecha_baja_boletin->format('d-m-Y')." Motivo de baja: ".$candidato->motivo_baja_boletin);
        } 
        
    }
}