<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Carbon\Carbon;
use Modules\Candidatos\Entities\Candidato;
use Modules\Candidatos\Emails\PerfilIncompletoEmail;
use Illuminate\Support\Facades\Mail;

class PerfilIncompleto extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'perfil:incompleto';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Comando para enviar un correo a cada candidato que no tenga completado su perfil al 100%';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        //$currentTime = Carbon::now();
        $candidatos = Candidato::all();

        foreach($candidatos as $candidato){

            $otros = $candidato->otros()->count() == 0? 0:1;
            $experiencia = $candidato->experiencia()->count() == 0? 0:1;
            $referencia = $candidato->referencia()->count() == 0? 0:1;
            $estudios = $candidato->estudios()->count() == 0? 0:1;
            $habilidades = $candidato->habilidades()->count() == 0? 0:1;
            $fotografia = $candidato->fotografia?1:0;
            $cv = $candidato->cv?1:0;
            $fecha_nacimiento = $candidato->fecha_nacimiento?1:0;
            $dpi = $candidato->dpi?1:0;
            $igss = ( isset($candidato->igss) && $candidato->igss != null )?1:0;
            $direccion = $candidato->direccion?1:0;
            $pais = $candidato->pais?1:0;
            $departamento = $candidato->departamento?1:0;
            $municipio = $candidato->municipio?1:0;
            $zona = (isset($candidato->zona) || $candidato->zona != 0)?1:0;
    
            $total = $otros + $experiencia + $referencia + $estudios + $habilidades + $fotografia + $cv + $fecha_nacimiento + $dpi + $igss + $direccion + $pais + $departamento +
            $municipio + $zona;
    
            $porcentaje = intval(($total/15) * 100);

            if($porcentaje != 100){

                Mail::to($candidato->email)->send(new PerfilIncompletoEmail($candidato, $porcentaje));
                $this->info(date('Y-m-d H:i:s').' Candidatos con perfil incompleto: ID:'.$candidato->id." Nombre: ".$candidato->nombre." Apellido: ".$candidato->apellido); 

            }

        }
        
    }
}